import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * API Gateway.
 *
 * @stability stable
 */
export interface ApiGatewayMethodConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#api_key_required ApiGatewayMethod#api_key_required}.
     *
     * @stability stable
     */
    readonly apiKeyRequired?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#authorization ApiGatewayMethod#authorization}.
     *
     * @stability stable
     */
    readonly authorization: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#authorization_scopes ApiGatewayMethod#authorization_scopes}.
     *
     * @stability stable
     */
    readonly authorizationScopes?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#authorizer_id ApiGatewayMethod#authorizer_id}.
     *
     * @stability stable
     */
    readonly authorizerId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#http_method ApiGatewayMethod#http_method}.
     *
     * @stability stable
     */
    readonly httpMethod: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#operation_name ApiGatewayMethod#operation_name}.
     *
     * @stability stable
     */
    readonly operationName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#request_models ApiGatewayMethod#request_models}.
     *
     * @stability stable
     */
    readonly requestModels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#request_parameters ApiGatewayMethod#request_parameters}.
     *
     * @stability stable
     */
    readonly requestParameters?: {
        [key: string]: boolean;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#request_validator_id ApiGatewayMethod#request_validator_id}.
     *
     * @stability stable
     */
    readonly requestValidatorId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#resource_id ApiGatewayMethod#resource_id}.
     *
     * @stability stable
     */
    readonly resourceId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#rest_api_id ApiGatewayMethod#rest_api_id}.
     *
     * @stability stable
     */
    readonly restApiId: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method aws_api_gateway_method}.
 *
 * @stability stable
 */
export declare class ApiGatewayMethod extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method aws_api_gateway_method} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ApiGatewayMethodConfig);
    private _apiKeyRequired?;
    /**
     * @stability stable
     */
    get apiKeyRequired(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set apiKeyRequired(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetApiKeyRequired(): void;
    /**
     * @stability stable
     */
    get apiKeyRequiredInput(): boolean | cdktf.IResolvable | undefined;
    private _authorization?;
    /**
     * @stability stable
     */
    get authorization(): string;
    /**
     * @stability stable
     */
    set authorization(value: string);
    /**
     * @stability stable
     */
    get authorizationInput(): string | undefined;
    private _authorizationScopes?;
    /**
     * @stability stable
     */
    get authorizationScopes(): string[];
    /**
     * @stability stable
     */
    set authorizationScopes(value: string[]);
    /**
     * @stability stable
     */
    resetAuthorizationScopes(): void;
    /**
     * @stability stable
     */
    get authorizationScopesInput(): string[] | undefined;
    private _authorizerId?;
    /**
     * @stability stable
     */
    get authorizerId(): string;
    /**
     * @stability stable
     */
    set authorizerId(value: string);
    /**
     * @stability stable
     */
    resetAuthorizerId(): void;
    /**
     * @stability stable
     */
    get authorizerIdInput(): string | undefined;
    private _httpMethod?;
    /**
     * @stability stable
     */
    get httpMethod(): string;
    /**
     * @stability stable
     */
    set httpMethod(value: string);
    /**
     * @stability stable
     */
    get httpMethodInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _operationName?;
    /**
     * @stability stable
     */
    get operationName(): string;
    /**
     * @stability stable
     */
    set operationName(value: string);
    /**
     * @stability stable
     */
    resetOperationName(): void;
    /**
     * @stability stable
     */
    get operationNameInput(): string | undefined;
    private _requestModels?;
    /**
     * @stability stable
     */
    get requestModels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set requestModels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRequestModels(): void;
    /**
     * @stability stable
     */
    get requestModelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _requestParameters?;
    /**
     * @stability stable
     */
    get requestParameters(): {
        [key: string]: boolean;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set requestParameters(value: {
        [key: string]: boolean;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRequestParameters(): void;
    /**
     * @stability stable
     */
    get requestParametersInput(): cdktf.IResolvable | {
        [key: string]: boolean;
    } | undefined;
    private _requestValidatorId?;
    /**
     * @stability stable
     */
    get requestValidatorId(): string;
    /**
     * @stability stable
     */
    set requestValidatorId(value: string);
    /**
     * @stability stable
     */
    resetRequestValidatorId(): void;
    /**
     * @stability stable
     */
    get requestValidatorIdInput(): string | undefined;
    private _resourceId?;
    /**
     * @stability stable
     */
    get resourceId(): string;
    /**
     * @stability stable
     */
    set resourceId(value: string);
    /**
     * @stability stable
     */
    get resourceIdInput(): string | undefined;
    private _restApiId?;
    /**
     * @stability stable
     */
    get restApiId(): string;
    /**
     * @stability stable
     */
    set restApiId(value: string);
    /**
     * @stability stable
     */
    get restApiIdInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
