import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * Amazon API Gateway Websocket and HTTP APIs.
 *
 * @stability stable
 */
export interface Apigatewayv2AuthorizerConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_authorizer#api_id Apigatewayv2Authorizer#api_id}.
     *
     * @stability stable
     */
    readonly apiId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_authorizer#authorizer_credentials_arn Apigatewayv2Authorizer#authorizer_credentials_arn}.
     *
     * @stability stable
     */
    readonly authorizerCredentialsArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_authorizer#authorizer_payload_format_version Apigatewayv2Authorizer#authorizer_payload_format_version}.
     *
     * @stability stable
     */
    readonly authorizerPayloadFormatVersion?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_authorizer#authorizer_result_ttl_in_seconds Apigatewayv2Authorizer#authorizer_result_ttl_in_seconds}.
     *
     * @stability stable
     */
    readonly authorizerResultTtlInSeconds?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_authorizer#authorizer_type Apigatewayv2Authorizer#authorizer_type}.
     *
     * @stability stable
     */
    readonly authorizerType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_authorizer#authorizer_uri Apigatewayv2Authorizer#authorizer_uri}.
     *
     * @stability stable
     */
    readonly authorizerUri?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_authorizer#enable_simple_responses Apigatewayv2Authorizer#enable_simple_responses}.
     *
     * @stability stable
     */
    readonly enableSimpleResponses?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_authorizer#identity_sources Apigatewayv2Authorizer#identity_sources}.
     *
     * @stability stable
     */
    readonly identitySources?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_authorizer#name Apigatewayv2Authorizer#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * jwt_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_authorizer#jwt_configuration Apigatewayv2Authorizer#jwt_configuration}
     *
     * @stability stable
     */
    readonly jwtConfiguration?: Apigatewayv2AuthorizerJwtConfiguration;
}
/**
 * @stability stable
 */
export interface Apigatewayv2AuthorizerJwtConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_authorizer#audience Apigatewayv2Authorizer#audience}.
     *
     * @stability stable
     */
    readonly audience?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_authorizer#issuer Apigatewayv2Authorizer#issuer}.
     *
     * @stability stable
     */
    readonly issuer?: string;
}
export declare function apigatewayv2AuthorizerJwtConfigurationToTerraform(struct?: Apigatewayv2AuthorizerJwtConfigurationOutputReference | Apigatewayv2AuthorizerJwtConfiguration): any;
/**
 * @stability stable
 */
export declare class Apigatewayv2AuthorizerJwtConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): Apigatewayv2AuthorizerJwtConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: Apigatewayv2AuthorizerJwtConfiguration | undefined);
    private _audience?;
    /**
     * @stability stable
     */
    get audience(): string[];
    /**
     * @stability stable
     */
    set audience(value: string[]);
    /**
     * @stability stable
     */
    resetAudience(): void;
    /**
     * @stability stable
     */
    get audienceInput(): string[] | undefined;
    private _issuer?;
    /**
     * @stability stable
     */
    get issuer(): string;
    /**
     * @stability stable
     */
    set issuer(value: string);
    /**
     * @stability stable
     */
    resetIssuer(): void;
    /**
     * @stability stable
     */
    get issuerInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_authorizer aws_apigatewayv2_authorizer}.
 *
 * @stability stable
 */
export declare class Apigatewayv2Authorizer extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_authorizer aws_apigatewayv2_authorizer} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: Apigatewayv2AuthorizerConfig);
    private _apiId?;
    /**
     * @stability stable
     */
    get apiId(): string;
    /**
     * @stability stable
     */
    set apiId(value: string);
    /**
     * @stability stable
     */
    get apiIdInput(): string | undefined;
    private _authorizerCredentialsArn?;
    /**
     * @stability stable
     */
    get authorizerCredentialsArn(): string;
    /**
     * @stability stable
     */
    set authorizerCredentialsArn(value: string);
    /**
     * @stability stable
     */
    resetAuthorizerCredentialsArn(): void;
    /**
     * @stability stable
     */
    get authorizerCredentialsArnInput(): string | undefined;
    private _authorizerPayloadFormatVersion?;
    /**
     * @stability stable
     */
    get authorizerPayloadFormatVersion(): string;
    /**
     * @stability stable
     */
    set authorizerPayloadFormatVersion(value: string);
    /**
     * @stability stable
     */
    resetAuthorizerPayloadFormatVersion(): void;
    /**
     * @stability stable
     */
    get authorizerPayloadFormatVersionInput(): string | undefined;
    private _authorizerResultTtlInSeconds?;
    /**
     * @stability stable
     */
    get authorizerResultTtlInSeconds(): number;
    /**
     * @stability stable
     */
    set authorizerResultTtlInSeconds(value: number);
    /**
     * @stability stable
     */
    resetAuthorizerResultTtlInSeconds(): void;
    /**
     * @stability stable
     */
    get authorizerResultTtlInSecondsInput(): number | undefined;
    private _authorizerType?;
    /**
     * @stability stable
     */
    get authorizerType(): string;
    /**
     * @stability stable
     */
    set authorizerType(value: string);
    /**
     * @stability stable
     */
    get authorizerTypeInput(): string | undefined;
    private _authorizerUri?;
    /**
     * @stability stable
     */
    get authorizerUri(): string;
    /**
     * @stability stable
     */
    set authorizerUri(value: string);
    /**
     * @stability stable
     */
    resetAuthorizerUri(): void;
    /**
     * @stability stable
     */
    get authorizerUriInput(): string | undefined;
    private _enableSimpleResponses?;
    /**
     * @stability stable
     */
    get enableSimpleResponses(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableSimpleResponses(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableSimpleResponses(): void;
    /**
     * @stability stable
     */
    get enableSimpleResponsesInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _identitySources?;
    /**
     * @stability stable
     */
    get identitySources(): string[];
    /**
     * @stability stable
     */
    set identitySources(value: string[]);
    /**
     * @stability stable
     */
    resetIdentitySources(): void;
    /**
     * @stability stable
     */
    get identitySourcesInput(): string[] | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _jwtConfiguration;
    /**
     * @stability stable
     */
    get jwtConfiguration(): Apigatewayv2AuthorizerJwtConfigurationOutputReference;
    /**
     * @stability stable
     */
    putJwtConfiguration(value: Apigatewayv2AuthorizerJwtConfiguration): void;
    /**
     * @stability stable
     */
    resetJwtConfiguration(): void;
    /**
     * @stability stable
     */
    get jwtConfigurationInput(): Apigatewayv2AuthorizerJwtConfiguration | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
