import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS CloudFormation.
 *
 * @stability stable
 */
export interface CloudformationStackSetInstanceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance#account_id CloudformationStackSetInstance#account_id}.
     *
     * @stability stable
     */
    readonly accountId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance#parameter_overrides CloudformationStackSetInstance#parameter_overrides}.
     *
     * @stability stable
     */
    readonly parameterOverrides?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance#region CloudformationStackSetInstance#region}.
     *
     * @stability stable
     */
    readonly region?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance#retain_stack CloudformationStackSetInstance#retain_stack}.
     *
     * @stability stable
     */
    readonly retainStack?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance#stack_set_name CloudformationStackSetInstance#stack_set_name}.
     *
     * @stability stable
     */
    readonly stackSetName: string;
    /**
     * deployment_targets block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance#deployment_targets CloudformationStackSetInstance#deployment_targets}
     *
     * @stability stable
     */
    readonly deploymentTargets?: CloudformationStackSetInstanceDeploymentTargets;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance#timeouts CloudformationStackSetInstance#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: CloudformationStackSetInstanceTimeouts;
}
/**
 * @stability stable
 */
export interface CloudformationStackSetInstanceDeploymentTargets {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance#organizational_unit_ids CloudformationStackSetInstance#organizational_unit_ids}.
     *
     * @stability stable
     */
    readonly organizationalUnitIds?: string[];
}
export declare function cloudformationStackSetInstanceDeploymentTargetsToTerraform(struct?: CloudformationStackSetInstanceDeploymentTargetsOutputReference | CloudformationStackSetInstanceDeploymentTargets): any;
/**
 * @stability stable
 */
export declare class CloudformationStackSetInstanceDeploymentTargetsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudformationStackSetInstanceDeploymentTargets | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudformationStackSetInstanceDeploymentTargets | undefined);
    private _organizationalUnitIds?;
    /**
     * @stability stable
     */
    get organizationalUnitIds(): string[];
    /**
     * @stability stable
     */
    set organizationalUnitIds(value: string[]);
    /**
     * @stability stable
     */
    resetOrganizationalUnitIds(): void;
    /**
     * @stability stable
     */
    get organizationalUnitIdsInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface CloudformationStackSetInstanceTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance#create CloudformationStackSetInstance#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance#delete CloudformationStackSetInstance#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance#update CloudformationStackSetInstance#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function cloudformationStackSetInstanceTimeoutsToTerraform(struct?: CloudformationStackSetInstanceTimeoutsOutputReference | CloudformationStackSetInstanceTimeouts): any;
/**
 * @stability stable
 */
export declare class CloudformationStackSetInstanceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudformationStackSetInstanceTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudformationStackSetInstanceTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance aws_cloudformation_stack_set_instance}.
 *
 * @stability stable
 */
export declare class CloudformationStackSetInstance extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance aws_cloudformation_stack_set_instance} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CloudformationStackSetInstanceConfig);
    private _accountId?;
    /**
     * @stability stable
     */
    get accountId(): string;
    /**
     * @stability stable
     */
    set accountId(value: string);
    /**
     * @stability stable
     */
    resetAccountId(): void;
    /**
     * @stability stable
     */
    get accountIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get organizationalUnitId(): string;
    private _parameterOverrides?;
    /**
     * @stability stable
     */
    get parameterOverrides(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set parameterOverrides(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetParameterOverrides(): void;
    /**
     * @stability stable
     */
    get parameterOverridesInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _region?;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    set region(value: string);
    /**
     * @stability stable
     */
    resetRegion(): void;
    /**
     * @stability stable
     */
    get regionInput(): string | undefined;
    private _retainStack?;
    /**
     * @stability stable
     */
    get retainStack(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set retainStack(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRetainStack(): void;
    /**
     * @stability stable
     */
    get retainStackInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get stackId(): string;
    private _stackSetName?;
    /**
     * @stability stable
     */
    get stackSetName(): string;
    /**
     * @stability stable
     */
    set stackSetName(value: string);
    /**
     * @stability stable
     */
    get stackSetNameInput(): string | undefined;
    private _deploymentTargets;
    /**
     * @stability stable
     */
    get deploymentTargets(): CloudformationStackSetInstanceDeploymentTargetsOutputReference;
    /**
     * @stability stable
     */
    putDeploymentTargets(value: CloudformationStackSetInstanceDeploymentTargets): void;
    /**
     * @stability stable
     */
    resetDeploymentTargets(): void;
    /**
     * @stability stable
     */
    get deploymentTargetsInput(): CloudformationStackSetInstanceDeploymentTargets | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): CloudformationStackSetInstanceTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: CloudformationStackSetInstanceTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): CloudformationStackSetInstanceTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
