import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS CloudFormation.
 *
 * @stability stable
 */
export interface CloudformationStackSetConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set#administration_role_arn CloudformationStackSet#administration_role_arn}.
     *
     * @stability stable
     */
    readonly administrationRoleArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set#capabilities CloudformationStackSet#capabilities}.
     *
     * @stability stable
     */
    readonly capabilities?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set#description CloudformationStackSet#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set#execution_role_name CloudformationStackSet#execution_role_name}.
     *
     * @stability stable
     */
    readonly executionRoleName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set#name CloudformationStackSet#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set#parameters CloudformationStackSet#parameters}.
     *
     * @stability stable
     */
    readonly parameters?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set#permission_model CloudformationStackSet#permission_model}.
     *
     * @stability stable
     */
    readonly permissionModel?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set#tags CloudformationStackSet#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set#tags_all CloudformationStackSet#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set#template_body CloudformationStackSet#template_body}.
     *
     * @stability stable
     */
    readonly templateBody?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set#template_url CloudformationStackSet#template_url}.
     *
     * @stability stable
     */
    readonly templateUrl?: string;
    /**
     * auto_deployment block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set#auto_deployment CloudformationStackSet#auto_deployment}
     *
     * @stability stable
     */
    readonly autoDeployment?: CloudformationStackSetAutoDeployment;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set#timeouts CloudformationStackSet#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: CloudformationStackSetTimeouts;
}
/**
 * @stability stable
 */
export interface CloudformationStackSetAutoDeployment {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set#enabled CloudformationStackSet#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set#retain_stacks_on_account_removal CloudformationStackSet#retain_stacks_on_account_removal}.
     *
     * @stability stable
     */
    readonly retainStacksOnAccountRemoval?: boolean | cdktf.IResolvable;
}
export declare function cloudformationStackSetAutoDeploymentToTerraform(struct?: CloudformationStackSetAutoDeploymentOutputReference | CloudformationStackSetAutoDeployment): any;
/**
 * @stability stable
 */
export declare class CloudformationStackSetAutoDeploymentOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudformationStackSetAutoDeployment | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudformationStackSetAutoDeployment | undefined);
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _retainStacksOnAccountRemoval?;
    /**
     * @stability stable
     */
    get retainStacksOnAccountRemoval(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set retainStacksOnAccountRemoval(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRetainStacksOnAccountRemoval(): void;
    /**
     * @stability stable
     */
    get retainStacksOnAccountRemovalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface CloudformationStackSetTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set#update CloudformationStackSet#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function cloudformationStackSetTimeoutsToTerraform(struct?: CloudformationStackSetTimeoutsOutputReference | CloudformationStackSetTimeouts): any;
/**
 * @stability stable
 */
export declare class CloudformationStackSetTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudformationStackSetTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudformationStackSetTimeouts | undefined);
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set aws_cloudformation_stack_set}.
 *
 * @stability stable
 */
export declare class CloudformationStackSet extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set aws_cloudformation_stack_set} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CloudformationStackSetConfig);
    private _administrationRoleArn?;
    /**
     * @stability stable
     */
    get administrationRoleArn(): string;
    /**
     * @stability stable
     */
    set administrationRoleArn(value: string);
    /**
     * @stability stable
     */
    resetAdministrationRoleArn(): void;
    /**
     * @stability stable
     */
    get administrationRoleArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    private _capabilities?;
    /**
     * @stability stable
     */
    get capabilities(): string[];
    /**
     * @stability stable
     */
    set capabilities(value: string[]);
    /**
     * @stability stable
     */
    resetCapabilities(): void;
    /**
     * @stability stable
     */
    get capabilitiesInput(): string[] | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _executionRoleName?;
    /**
     * @stability stable
     */
    get executionRoleName(): string;
    /**
     * @stability stable
     */
    set executionRoleName(value: string);
    /**
     * @stability stable
     */
    resetExecutionRoleName(): void;
    /**
     * @stability stable
     */
    get executionRoleNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _parameters?;
    /**
     * @stability stable
     */
    get parameters(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set parameters(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetParameters(): void;
    /**
     * @stability stable
     */
    get parametersInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _permissionModel?;
    /**
     * @stability stable
     */
    get permissionModel(): string;
    /**
     * @stability stable
     */
    set permissionModel(value: string);
    /**
     * @stability stable
     */
    resetPermissionModel(): void;
    /**
     * @stability stable
     */
    get permissionModelInput(): string | undefined;
    /**
     * @stability stable
     */
    get stackSetId(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _templateBody?;
    /**
     * @stability stable
     */
    get templateBody(): string;
    /**
     * @stability stable
     */
    set templateBody(value: string);
    /**
     * @stability stable
     */
    resetTemplateBody(): void;
    /**
     * @stability stable
     */
    get templateBodyInput(): string | undefined;
    private _templateUrl?;
    /**
     * @stability stable
     */
    get templateUrl(): string;
    /**
     * @stability stable
     */
    set templateUrl(value: string);
    /**
     * @stability stable
     */
    resetTemplateUrl(): void;
    /**
     * @stability stable
     */
    get templateUrlInput(): string | undefined;
    private _autoDeployment;
    /**
     * @stability stable
     */
    get autoDeployment(): CloudformationStackSetAutoDeploymentOutputReference;
    /**
     * @stability stable
     */
    putAutoDeployment(value: CloudformationStackSetAutoDeployment): void;
    /**
     * @stability stable
     */
    resetAutoDeployment(): void;
    /**
     * @stability stable
     */
    get autoDeploymentInput(): CloudformationStackSetAutoDeployment | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): CloudformationStackSetTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: CloudformationStackSetTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): CloudformationStackSetTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
