import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS CloudFront.
 *
 * @stability stable
 */
export interface CloudfrontDistributionConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#aliases CloudfrontDistribution#aliases}.
     *
     * @stability stable
     */
    readonly aliases?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#comment CloudfrontDistribution#comment}.
     *
     * @stability stable
     */
    readonly comment?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#default_root_object CloudfrontDistribution#default_root_object}.
     *
     * @stability stable
     */
    readonly defaultRootObject?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#enabled CloudfrontDistribution#enabled}.
     *
     * @stability stable
     */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#http_version CloudfrontDistribution#http_version}.
     *
     * @stability stable
     */
    readonly httpVersion?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#is_ipv6_enabled CloudfrontDistribution#is_ipv6_enabled}.
     *
     * @stability stable
     */
    readonly isIpv6Enabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#price_class CloudfrontDistribution#price_class}.
     *
     * @stability stable
     */
    readonly priceClass?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#retain_on_delete CloudfrontDistribution#retain_on_delete}.
     *
     * @stability stable
     */
    readonly retainOnDelete?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#tags CloudfrontDistribution#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#tags_all CloudfrontDistribution#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#wait_for_deployment CloudfrontDistribution#wait_for_deployment}.
     *
     * @stability stable
     */
    readonly waitForDeployment?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#web_acl_id CloudfrontDistribution#web_acl_id}.
     *
     * @stability stable
     */
    readonly webAclId?: string;
    /**
     * custom_error_response block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#custom_error_response CloudfrontDistribution#custom_error_response}
     *
     * @stability stable
     */
    readonly customErrorResponse?: CloudfrontDistributionCustomErrorResponse[];
    /**
     * default_cache_behavior block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#default_cache_behavior CloudfrontDistribution#default_cache_behavior}
     *
     * @stability stable
     */
    readonly defaultCacheBehavior: CloudfrontDistributionDefaultCacheBehavior;
    /**
     * logging_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#logging_config CloudfrontDistribution#logging_config}
     *
     * @stability stable
     */
    readonly loggingConfig?: CloudfrontDistributionLoggingConfig;
    /**
     * ordered_cache_behavior block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#ordered_cache_behavior CloudfrontDistribution#ordered_cache_behavior}
     *
     * @stability stable
     */
    readonly orderedCacheBehavior?: CloudfrontDistributionOrderedCacheBehavior[];
    /**
     * origin block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#origin CloudfrontDistribution#origin}
     *
     * @stability stable
     */
    readonly origin: CloudfrontDistributionOrigin[];
    /**
     * origin_group block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#origin_group CloudfrontDistribution#origin_group}
     *
     * @stability stable
     */
    readonly originGroup?: CloudfrontDistributionOriginGroup[];
    /**
     * restrictions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#restrictions CloudfrontDistribution#restrictions}
     *
     * @stability stable
     */
    readonly restrictions: CloudfrontDistributionRestrictions;
    /**
     * viewer_certificate block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#viewer_certificate CloudfrontDistribution#viewer_certificate}
     *
     * @stability stable
     */
    readonly viewerCertificate: CloudfrontDistributionViewerCertificate;
}
/**
 * @stability stable
 */
export declare class CloudfrontDistributionTrustedKeyGroupsItems extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get keyGroupId(): string;
    /**
     * @stability stable
     */
    get keyPairIds(): string[];
}
/**
 * @stability stable
 */
export declare class CloudfrontDistributionTrustedKeyGroups extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get enabled(): any;
    /**
     * @stability stable
     */
    get items(): any;
}
/**
 * @stability stable
 */
export declare class CloudfrontDistributionTrustedSignersItems extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get awsAccountNumber(): string;
    /**
     * @stability stable
     */
    get keyPairIds(): string[];
}
/**
 * @stability stable
 */
export declare class CloudfrontDistributionTrustedSigners extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get enabled(): any;
    /**
     * @stability stable
     */
    get items(): any;
}
/**
 * @stability stable
 */
export interface CloudfrontDistributionCustomErrorResponse {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#error_caching_min_ttl CloudfrontDistribution#error_caching_min_ttl}.
     *
     * @stability stable
     */
    readonly errorCachingMinTtl?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#error_code CloudfrontDistribution#error_code}.
     *
     * @stability stable
     */
    readonly errorCode: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#response_code CloudfrontDistribution#response_code}.
     *
     * @stability stable
     */
    readonly responseCode?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#response_page_path CloudfrontDistribution#response_page_path}.
     *
     * @stability stable
     */
    readonly responsePagePath?: string;
}
export declare function cloudfrontDistributionCustomErrorResponseToTerraform(struct?: CloudfrontDistributionCustomErrorResponse): any;
/**
 * @stability stable
 */
export interface CloudfrontDistributionDefaultCacheBehaviorForwardedValuesCookies {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#forward CloudfrontDistribution#forward}.
     *
     * @stability stable
     */
    readonly forward: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#whitelisted_names CloudfrontDistribution#whitelisted_names}.
     *
     * @stability stable
     */
    readonly whitelistedNames?: string[];
}
export declare function cloudfrontDistributionDefaultCacheBehaviorForwardedValuesCookiesToTerraform(struct?: CloudfrontDistributionDefaultCacheBehaviorForwardedValuesCookiesOutputReference | CloudfrontDistributionDefaultCacheBehaviorForwardedValuesCookies): any;
/**
 * @stability stable
 */
export declare class CloudfrontDistributionDefaultCacheBehaviorForwardedValuesCookiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudfrontDistributionDefaultCacheBehaviorForwardedValuesCookies | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudfrontDistributionDefaultCacheBehaviorForwardedValuesCookies | undefined);
    private _forward?;
    /**
     * @stability stable
     */
    get forward(): string;
    /**
     * @stability stable
     */
    set forward(value: string);
    /**
     * @stability stable
     */
    get forwardInput(): string | undefined;
    private _whitelistedNames?;
    /**
     * @stability stable
     */
    get whitelistedNames(): string[];
    /**
     * @stability stable
     */
    set whitelistedNames(value: string[]);
    /**
     * @stability stable
     */
    resetWhitelistedNames(): void;
    /**
     * @stability stable
     */
    get whitelistedNamesInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface CloudfrontDistributionDefaultCacheBehaviorForwardedValues {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#headers CloudfrontDistribution#headers}.
     *
     * @stability stable
     */
    readonly headers?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#query_string CloudfrontDistribution#query_string}.
     *
     * @stability stable
     */
    readonly queryString: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#query_string_cache_keys CloudfrontDistribution#query_string_cache_keys}.
     *
     * @stability stable
     */
    readonly queryStringCacheKeys?: string[];
    /**
     * cookies block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#cookies CloudfrontDistribution#cookies}
     *
     * @stability stable
     */
    readonly cookies: CloudfrontDistributionDefaultCacheBehaviorForwardedValuesCookies;
}
export declare function cloudfrontDistributionDefaultCacheBehaviorForwardedValuesToTerraform(struct?: CloudfrontDistributionDefaultCacheBehaviorForwardedValuesOutputReference | CloudfrontDistributionDefaultCacheBehaviorForwardedValues): any;
/**
 * @stability stable
 */
export declare class CloudfrontDistributionDefaultCacheBehaviorForwardedValuesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudfrontDistributionDefaultCacheBehaviorForwardedValues | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudfrontDistributionDefaultCacheBehaviorForwardedValues | undefined);
    private _headers?;
    /**
     * @stability stable
     */
    get headers(): string[];
    /**
     * @stability stable
     */
    set headers(value: string[]);
    /**
     * @stability stable
     */
    resetHeaders(): void;
    /**
     * @stability stable
     */
    get headersInput(): string[] | undefined;
    private _queryString?;
    /**
     * @stability stable
     */
    get queryString(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set queryString(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get queryStringInput(): boolean | cdktf.IResolvable | undefined;
    private _queryStringCacheKeys?;
    /**
     * @stability stable
     */
    get queryStringCacheKeys(): string[];
    /**
     * @stability stable
     */
    set queryStringCacheKeys(value: string[]);
    /**
     * @stability stable
     */
    resetQueryStringCacheKeys(): void;
    /**
     * @stability stable
     */
    get queryStringCacheKeysInput(): string[] | undefined;
    private _cookies;
    /**
     * @stability stable
     */
    get cookies(): CloudfrontDistributionDefaultCacheBehaviorForwardedValuesCookiesOutputReference;
    /**
     * @stability stable
     */
    putCookies(value: CloudfrontDistributionDefaultCacheBehaviorForwardedValuesCookies): void;
    /**
     * @stability stable
     */
    get cookiesInput(): CloudfrontDistributionDefaultCacheBehaviorForwardedValuesCookies | undefined;
}
/**
 * @stability stable
 */
export interface CloudfrontDistributionDefaultCacheBehaviorFunctionAssociation {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#event_type CloudfrontDistribution#event_type}.
     *
     * @stability stable
     */
    readonly eventType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#function_arn CloudfrontDistribution#function_arn}.
     *
     * @stability stable
     */
    readonly functionArn: string;
}
export declare function cloudfrontDistributionDefaultCacheBehaviorFunctionAssociationToTerraform(struct?: CloudfrontDistributionDefaultCacheBehaviorFunctionAssociation): any;
/**
 * @stability stable
 */
export interface CloudfrontDistributionDefaultCacheBehaviorLambdaFunctionAssociation {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#event_type CloudfrontDistribution#event_type}.
     *
     * @stability stable
     */
    readonly eventType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#include_body CloudfrontDistribution#include_body}.
     *
     * @stability stable
     */
    readonly includeBody?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#lambda_arn CloudfrontDistribution#lambda_arn}.
     *
     * @stability stable
     */
    readonly lambdaArn: string;
}
export declare function cloudfrontDistributionDefaultCacheBehaviorLambdaFunctionAssociationToTerraform(struct?: CloudfrontDistributionDefaultCacheBehaviorLambdaFunctionAssociation): any;
/**
 * @stability stable
 */
export interface CloudfrontDistributionDefaultCacheBehavior {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#allowed_methods CloudfrontDistribution#allowed_methods}.
     *
     * @stability stable
     */
    readonly allowedMethods: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#cache_policy_id CloudfrontDistribution#cache_policy_id}.
     *
     * @stability stable
     */
    readonly cachePolicyId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#cached_methods CloudfrontDistribution#cached_methods}.
     *
     * @stability stable
     */
    readonly cachedMethods: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#compress CloudfrontDistribution#compress}.
     *
     * @stability stable
     */
    readonly compress?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#default_ttl CloudfrontDistribution#default_ttl}.
     *
     * @stability stable
     */
    readonly defaultTtl?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#field_level_encryption_id CloudfrontDistribution#field_level_encryption_id}.
     *
     * @stability stable
     */
    readonly fieldLevelEncryptionId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#max_ttl CloudfrontDistribution#max_ttl}.
     *
     * @stability stable
     */
    readonly maxTtl?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#min_ttl CloudfrontDistribution#min_ttl}.
     *
     * @stability stable
     */
    readonly minTtl?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#origin_request_policy_id CloudfrontDistribution#origin_request_policy_id}.
     *
     * @stability stable
     */
    readonly originRequestPolicyId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#realtime_log_config_arn CloudfrontDistribution#realtime_log_config_arn}.
     *
     * @stability stable
     */
    readonly realtimeLogConfigArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#response_headers_policy_id CloudfrontDistribution#response_headers_policy_id}.
     *
     * @stability stable
     */
    readonly responseHeadersPolicyId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#smooth_streaming CloudfrontDistribution#smooth_streaming}.
     *
     * @stability stable
     */
    readonly smoothStreaming?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#target_origin_id CloudfrontDistribution#target_origin_id}.
     *
     * @stability stable
     */
    readonly targetOriginId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#trusted_key_groups CloudfrontDistribution#trusted_key_groups}.
     *
     * @stability stable
     */
    readonly trustedKeyGroups?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#trusted_signers CloudfrontDistribution#trusted_signers}.
     *
     * @stability stable
     */
    readonly trustedSigners?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#viewer_protocol_policy CloudfrontDistribution#viewer_protocol_policy}.
     *
     * @stability stable
     */
    readonly viewerProtocolPolicy: string;
    /**
     * forwarded_values block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#forwarded_values CloudfrontDistribution#forwarded_values}
     *
     * @stability stable
     */
    readonly forwardedValues?: CloudfrontDistributionDefaultCacheBehaviorForwardedValues;
    /**
     * function_association block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#function_association CloudfrontDistribution#function_association}
     *
     * @stability stable
     */
    readonly functionAssociation?: CloudfrontDistributionDefaultCacheBehaviorFunctionAssociation[];
    /**
     * lambda_function_association block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#lambda_function_association CloudfrontDistribution#lambda_function_association}
     *
     * @stability stable
     */
    readonly lambdaFunctionAssociation?: CloudfrontDistributionDefaultCacheBehaviorLambdaFunctionAssociation[];
}
export declare function cloudfrontDistributionDefaultCacheBehaviorToTerraform(struct?: CloudfrontDistributionDefaultCacheBehaviorOutputReference | CloudfrontDistributionDefaultCacheBehavior): any;
/**
 * @stability stable
 */
export declare class CloudfrontDistributionDefaultCacheBehaviorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudfrontDistributionDefaultCacheBehavior | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudfrontDistributionDefaultCacheBehavior | undefined);
    private _allowedMethods?;
    /**
     * @stability stable
     */
    get allowedMethods(): string[];
    /**
     * @stability stable
     */
    set allowedMethods(value: string[]);
    /**
     * @stability stable
     */
    get allowedMethodsInput(): string[] | undefined;
    private _cachePolicyId?;
    /**
     * @stability stable
     */
    get cachePolicyId(): string;
    /**
     * @stability stable
     */
    set cachePolicyId(value: string);
    /**
     * @stability stable
     */
    resetCachePolicyId(): void;
    /**
     * @stability stable
     */
    get cachePolicyIdInput(): string | undefined;
    private _cachedMethods?;
    /**
     * @stability stable
     */
    get cachedMethods(): string[];
    /**
     * @stability stable
     */
    set cachedMethods(value: string[]);
    /**
     * @stability stable
     */
    get cachedMethodsInput(): string[] | undefined;
    private _compress?;
    /**
     * @stability stable
     */
    get compress(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set compress(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetCompress(): void;
    /**
     * @stability stable
     */
    get compressInput(): boolean | cdktf.IResolvable | undefined;
    private _defaultTtl?;
    /**
     * @stability stable
     */
    get defaultTtl(): number;
    /**
     * @stability stable
     */
    set defaultTtl(value: number);
    /**
     * @stability stable
     */
    resetDefaultTtl(): void;
    /**
     * @stability stable
     */
    get defaultTtlInput(): number | undefined;
    private _fieldLevelEncryptionId?;
    /**
     * @stability stable
     */
    get fieldLevelEncryptionId(): string;
    /**
     * @stability stable
     */
    set fieldLevelEncryptionId(value: string);
    /**
     * @stability stable
     */
    resetFieldLevelEncryptionId(): void;
    /**
     * @stability stable
     */
    get fieldLevelEncryptionIdInput(): string | undefined;
    private _maxTtl?;
    /**
     * @stability stable
     */
    get maxTtl(): number;
    /**
     * @stability stable
     */
    set maxTtl(value: number);
    /**
     * @stability stable
     */
    resetMaxTtl(): void;
    /**
     * @stability stable
     */
    get maxTtlInput(): number | undefined;
    private _minTtl?;
    /**
     * @stability stable
     */
    get minTtl(): number;
    /**
     * @stability stable
     */
    set minTtl(value: number);
    /**
     * @stability stable
     */
    resetMinTtl(): void;
    /**
     * @stability stable
     */
    get minTtlInput(): number | undefined;
    private _originRequestPolicyId?;
    /**
     * @stability stable
     */
    get originRequestPolicyId(): string;
    /**
     * @stability stable
     */
    set originRequestPolicyId(value: string);
    /**
     * @stability stable
     */
    resetOriginRequestPolicyId(): void;
    /**
     * @stability stable
     */
    get originRequestPolicyIdInput(): string | undefined;
    private _realtimeLogConfigArn?;
    /**
     * @stability stable
     */
    get realtimeLogConfigArn(): string;
    /**
     * @stability stable
     */
    set realtimeLogConfigArn(value: string);
    /**
     * @stability stable
     */
    resetRealtimeLogConfigArn(): void;
    /**
     * @stability stable
     */
    get realtimeLogConfigArnInput(): string | undefined;
    private _responseHeadersPolicyId?;
    /**
     * @stability stable
     */
    get responseHeadersPolicyId(): string;
    /**
     * @stability stable
     */
    set responseHeadersPolicyId(value: string);
    /**
     * @stability stable
     */
    resetResponseHeadersPolicyId(): void;
    /**
     * @stability stable
     */
    get responseHeadersPolicyIdInput(): string | undefined;
    private _smoothStreaming?;
    /**
     * @stability stable
     */
    get smoothStreaming(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set smoothStreaming(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetSmoothStreaming(): void;
    /**
     * @stability stable
     */
    get smoothStreamingInput(): boolean | cdktf.IResolvable | undefined;
    private _targetOriginId?;
    /**
     * @stability stable
     */
    get targetOriginId(): string;
    /**
     * @stability stable
     */
    set targetOriginId(value: string);
    /**
     * @stability stable
     */
    get targetOriginIdInput(): string | undefined;
    private _trustedKeyGroups?;
    /**
     * @stability stable
     */
    get trustedKeyGroups(): string[];
    /**
     * @stability stable
     */
    set trustedKeyGroups(value: string[]);
    /**
     * @stability stable
     */
    resetTrustedKeyGroups(): void;
    /**
     * @stability stable
     */
    get trustedKeyGroupsInput(): string[] | undefined;
    private _trustedSigners?;
    /**
     * @stability stable
     */
    get trustedSigners(): string[];
    /**
     * @stability stable
     */
    set trustedSigners(value: string[]);
    /**
     * @stability stable
     */
    resetTrustedSigners(): void;
    /**
     * @stability stable
     */
    get trustedSignersInput(): string[] | undefined;
    private _viewerProtocolPolicy?;
    /**
     * @stability stable
     */
    get viewerProtocolPolicy(): string;
    /**
     * @stability stable
     */
    set viewerProtocolPolicy(value: string);
    /**
     * @stability stable
     */
    get viewerProtocolPolicyInput(): string | undefined;
    private _forwardedValues;
    /**
     * @stability stable
     */
    get forwardedValues(): CloudfrontDistributionDefaultCacheBehaviorForwardedValuesOutputReference;
    /**
     * @stability stable
     */
    putForwardedValues(value: CloudfrontDistributionDefaultCacheBehaviorForwardedValues): void;
    /**
     * @stability stable
     */
    resetForwardedValues(): void;
    /**
     * @stability stable
     */
    get forwardedValuesInput(): CloudfrontDistributionDefaultCacheBehaviorForwardedValues | undefined;
    private _functionAssociation?;
    /**
     * @stability stable
     */
    get functionAssociation(): CloudfrontDistributionDefaultCacheBehaviorFunctionAssociation[];
    /**
     * @stability stable
     */
    set functionAssociation(value: CloudfrontDistributionDefaultCacheBehaviorFunctionAssociation[]);
    /**
     * @stability stable
     */
    resetFunctionAssociation(): void;
    /**
     * @stability stable
     */
    get functionAssociationInput(): CloudfrontDistributionDefaultCacheBehaviorFunctionAssociation[] | undefined;
    private _lambdaFunctionAssociation?;
    /**
     * @stability stable
     */
    get lambdaFunctionAssociation(): CloudfrontDistributionDefaultCacheBehaviorLambdaFunctionAssociation[];
    /**
     * @stability stable
     */
    set lambdaFunctionAssociation(value: CloudfrontDistributionDefaultCacheBehaviorLambdaFunctionAssociation[]);
    /**
     * @stability stable
     */
    resetLambdaFunctionAssociation(): void;
    /**
     * @stability stable
     */
    get lambdaFunctionAssociationInput(): CloudfrontDistributionDefaultCacheBehaviorLambdaFunctionAssociation[] | undefined;
}
/**
 * @stability stable
 */
export interface CloudfrontDistributionLoggingConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#bucket CloudfrontDistribution#bucket}.
     *
     * @stability stable
     */
    readonly bucket: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#include_cookies CloudfrontDistribution#include_cookies}.
     *
     * @stability stable
     */
    readonly includeCookies?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#prefix CloudfrontDistribution#prefix}.
     *
     * @stability stable
     */
    readonly prefix?: string;
}
export declare function cloudfrontDistributionLoggingConfigToTerraform(struct?: CloudfrontDistributionLoggingConfigOutputReference | CloudfrontDistributionLoggingConfig): any;
/**
 * @stability stable
 */
export declare class CloudfrontDistributionLoggingConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudfrontDistributionLoggingConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudfrontDistributionLoggingConfig | undefined);
    private _bucket?;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    get bucketInput(): string | undefined;
    private _includeCookies?;
    /**
     * @stability stable
     */
    get includeCookies(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set includeCookies(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIncludeCookies(): void;
    /**
     * @stability stable
     */
    get includeCookiesInput(): boolean | cdktf.IResolvable | undefined;
    private _prefix?;
    /**
     * @stability stable
     */
    get prefix(): string;
    /**
     * @stability stable
     */
    set prefix(value: string);
    /**
     * @stability stable
     */
    resetPrefix(): void;
    /**
     * @stability stable
     */
    get prefixInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface CloudfrontDistributionOrderedCacheBehaviorForwardedValuesCookies {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#forward CloudfrontDistribution#forward}.
     *
     * @stability stable
     */
    readonly forward: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#whitelisted_names CloudfrontDistribution#whitelisted_names}.
     *
     * @stability stable
     */
    readonly whitelistedNames?: string[];
}
export declare function cloudfrontDistributionOrderedCacheBehaviorForwardedValuesCookiesToTerraform(struct?: CloudfrontDistributionOrderedCacheBehaviorForwardedValuesCookiesOutputReference | CloudfrontDistributionOrderedCacheBehaviorForwardedValuesCookies): any;
/**
 * @stability stable
 */
export declare class CloudfrontDistributionOrderedCacheBehaviorForwardedValuesCookiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudfrontDistributionOrderedCacheBehaviorForwardedValuesCookies | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudfrontDistributionOrderedCacheBehaviorForwardedValuesCookies | undefined);
    private _forward?;
    /**
     * @stability stable
     */
    get forward(): string;
    /**
     * @stability stable
     */
    set forward(value: string);
    /**
     * @stability stable
     */
    get forwardInput(): string | undefined;
    private _whitelistedNames?;
    /**
     * @stability stable
     */
    get whitelistedNames(): string[];
    /**
     * @stability stable
     */
    set whitelistedNames(value: string[]);
    /**
     * @stability stable
     */
    resetWhitelistedNames(): void;
    /**
     * @stability stable
     */
    get whitelistedNamesInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface CloudfrontDistributionOrderedCacheBehaviorForwardedValues {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#headers CloudfrontDistribution#headers}.
     *
     * @stability stable
     */
    readonly headers?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#query_string CloudfrontDistribution#query_string}.
     *
     * @stability stable
     */
    readonly queryString: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#query_string_cache_keys CloudfrontDistribution#query_string_cache_keys}.
     *
     * @stability stable
     */
    readonly queryStringCacheKeys?: string[];
    /**
     * cookies block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#cookies CloudfrontDistribution#cookies}
     *
     * @stability stable
     */
    readonly cookies: CloudfrontDistributionOrderedCacheBehaviorForwardedValuesCookies;
}
export declare function cloudfrontDistributionOrderedCacheBehaviorForwardedValuesToTerraform(struct?: CloudfrontDistributionOrderedCacheBehaviorForwardedValuesOutputReference | CloudfrontDistributionOrderedCacheBehaviorForwardedValues): any;
/**
 * @stability stable
 */
export declare class CloudfrontDistributionOrderedCacheBehaviorForwardedValuesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudfrontDistributionOrderedCacheBehaviorForwardedValues | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudfrontDistributionOrderedCacheBehaviorForwardedValues | undefined);
    private _headers?;
    /**
     * @stability stable
     */
    get headers(): string[];
    /**
     * @stability stable
     */
    set headers(value: string[]);
    /**
     * @stability stable
     */
    resetHeaders(): void;
    /**
     * @stability stable
     */
    get headersInput(): string[] | undefined;
    private _queryString?;
    /**
     * @stability stable
     */
    get queryString(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set queryString(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get queryStringInput(): boolean | cdktf.IResolvable | undefined;
    private _queryStringCacheKeys?;
    /**
     * @stability stable
     */
    get queryStringCacheKeys(): string[];
    /**
     * @stability stable
     */
    set queryStringCacheKeys(value: string[]);
    /**
     * @stability stable
     */
    resetQueryStringCacheKeys(): void;
    /**
     * @stability stable
     */
    get queryStringCacheKeysInput(): string[] | undefined;
    private _cookies;
    /**
     * @stability stable
     */
    get cookies(): CloudfrontDistributionOrderedCacheBehaviorForwardedValuesCookiesOutputReference;
    /**
     * @stability stable
     */
    putCookies(value: CloudfrontDistributionOrderedCacheBehaviorForwardedValuesCookies): void;
    /**
     * @stability stable
     */
    get cookiesInput(): CloudfrontDistributionOrderedCacheBehaviorForwardedValuesCookies | undefined;
}
/**
 * @stability stable
 */
export interface CloudfrontDistributionOrderedCacheBehaviorFunctionAssociation {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#event_type CloudfrontDistribution#event_type}.
     *
     * @stability stable
     */
    readonly eventType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#function_arn CloudfrontDistribution#function_arn}.
     *
     * @stability stable
     */
    readonly functionArn: string;
}
export declare function cloudfrontDistributionOrderedCacheBehaviorFunctionAssociationToTerraform(struct?: CloudfrontDistributionOrderedCacheBehaviorFunctionAssociation): any;
/**
 * @stability stable
 */
export interface CloudfrontDistributionOrderedCacheBehaviorLambdaFunctionAssociation {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#event_type CloudfrontDistribution#event_type}.
     *
     * @stability stable
     */
    readonly eventType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#include_body CloudfrontDistribution#include_body}.
     *
     * @stability stable
     */
    readonly includeBody?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#lambda_arn CloudfrontDistribution#lambda_arn}.
     *
     * @stability stable
     */
    readonly lambdaArn: string;
}
export declare function cloudfrontDistributionOrderedCacheBehaviorLambdaFunctionAssociationToTerraform(struct?: CloudfrontDistributionOrderedCacheBehaviorLambdaFunctionAssociation): any;
/**
 * @stability stable
 */
export interface CloudfrontDistributionOrderedCacheBehavior {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#allowed_methods CloudfrontDistribution#allowed_methods}.
     *
     * @stability stable
     */
    readonly allowedMethods: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#cache_policy_id CloudfrontDistribution#cache_policy_id}.
     *
     * @stability stable
     */
    readonly cachePolicyId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#cached_methods CloudfrontDistribution#cached_methods}.
     *
     * @stability stable
     */
    readonly cachedMethods: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#compress CloudfrontDistribution#compress}.
     *
     * @stability stable
     */
    readonly compress?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#default_ttl CloudfrontDistribution#default_ttl}.
     *
     * @stability stable
     */
    readonly defaultTtl?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#field_level_encryption_id CloudfrontDistribution#field_level_encryption_id}.
     *
     * @stability stable
     */
    readonly fieldLevelEncryptionId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#max_ttl CloudfrontDistribution#max_ttl}.
     *
     * @stability stable
     */
    readonly maxTtl?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#min_ttl CloudfrontDistribution#min_ttl}.
     *
     * @stability stable
     */
    readonly minTtl?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#origin_request_policy_id CloudfrontDistribution#origin_request_policy_id}.
     *
     * @stability stable
     */
    readonly originRequestPolicyId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#path_pattern CloudfrontDistribution#path_pattern}.
     *
     * @stability stable
     */
    readonly pathPattern: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#realtime_log_config_arn CloudfrontDistribution#realtime_log_config_arn}.
     *
     * @stability stable
     */
    readonly realtimeLogConfigArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#response_headers_policy_id CloudfrontDistribution#response_headers_policy_id}.
     *
     * @stability stable
     */
    readonly responseHeadersPolicyId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#smooth_streaming CloudfrontDistribution#smooth_streaming}.
     *
     * @stability stable
     */
    readonly smoothStreaming?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#target_origin_id CloudfrontDistribution#target_origin_id}.
     *
     * @stability stable
     */
    readonly targetOriginId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#trusted_key_groups CloudfrontDistribution#trusted_key_groups}.
     *
     * @stability stable
     */
    readonly trustedKeyGroups?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#trusted_signers CloudfrontDistribution#trusted_signers}.
     *
     * @stability stable
     */
    readonly trustedSigners?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#viewer_protocol_policy CloudfrontDistribution#viewer_protocol_policy}.
     *
     * @stability stable
     */
    readonly viewerProtocolPolicy: string;
    /**
     * forwarded_values block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#forwarded_values CloudfrontDistribution#forwarded_values}
     *
     * @stability stable
     */
    readonly forwardedValues?: CloudfrontDistributionOrderedCacheBehaviorForwardedValues;
    /**
     * function_association block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#function_association CloudfrontDistribution#function_association}
     *
     * @stability stable
     */
    readonly functionAssociation?: CloudfrontDistributionOrderedCacheBehaviorFunctionAssociation[];
    /**
     * lambda_function_association block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#lambda_function_association CloudfrontDistribution#lambda_function_association}
     *
     * @stability stable
     */
    readonly lambdaFunctionAssociation?: CloudfrontDistributionOrderedCacheBehaviorLambdaFunctionAssociation[];
}
export declare function cloudfrontDistributionOrderedCacheBehaviorToTerraform(struct?: CloudfrontDistributionOrderedCacheBehavior): any;
/**
 * @stability stable
 */
export interface CloudfrontDistributionOriginCustomHeader {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#name CloudfrontDistribution#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#value CloudfrontDistribution#value}.
     *
     * @stability stable
     */
    readonly value: string;
}
export declare function cloudfrontDistributionOriginCustomHeaderToTerraform(struct?: CloudfrontDistributionOriginCustomHeader): any;
/**
 * @stability stable
 */
export interface CloudfrontDistributionOriginCustomOriginConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#http_port CloudfrontDistribution#http_port}.
     *
     * @stability stable
     */
    readonly httpPort: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#https_port CloudfrontDistribution#https_port}.
     *
     * @stability stable
     */
    readonly httpsPort: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#origin_keepalive_timeout CloudfrontDistribution#origin_keepalive_timeout}.
     *
     * @stability stable
     */
    readonly originKeepaliveTimeout?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#origin_protocol_policy CloudfrontDistribution#origin_protocol_policy}.
     *
     * @stability stable
     */
    readonly originProtocolPolicy: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#origin_read_timeout CloudfrontDistribution#origin_read_timeout}.
     *
     * @stability stable
     */
    readonly originReadTimeout?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#origin_ssl_protocols CloudfrontDistribution#origin_ssl_protocols}.
     *
     * @stability stable
     */
    readonly originSslProtocols: string[];
}
export declare function cloudfrontDistributionOriginCustomOriginConfigToTerraform(struct?: CloudfrontDistributionOriginCustomOriginConfigOutputReference | CloudfrontDistributionOriginCustomOriginConfig): any;
/**
 * @stability stable
 */
export declare class CloudfrontDistributionOriginCustomOriginConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudfrontDistributionOriginCustomOriginConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudfrontDistributionOriginCustomOriginConfig | undefined);
    private _httpPort?;
    /**
     * @stability stable
     */
    get httpPort(): number;
    /**
     * @stability stable
     */
    set httpPort(value: number);
    /**
     * @stability stable
     */
    get httpPortInput(): number | undefined;
    private _httpsPort?;
    /**
     * @stability stable
     */
    get httpsPort(): number;
    /**
     * @stability stable
     */
    set httpsPort(value: number);
    /**
     * @stability stable
     */
    get httpsPortInput(): number | undefined;
    private _originKeepaliveTimeout?;
    /**
     * @stability stable
     */
    get originKeepaliveTimeout(): number;
    /**
     * @stability stable
     */
    set originKeepaliveTimeout(value: number);
    /**
     * @stability stable
     */
    resetOriginKeepaliveTimeout(): void;
    /**
     * @stability stable
     */
    get originKeepaliveTimeoutInput(): number | undefined;
    private _originProtocolPolicy?;
    /**
     * @stability stable
     */
    get originProtocolPolicy(): string;
    /**
     * @stability stable
     */
    set originProtocolPolicy(value: string);
    /**
     * @stability stable
     */
    get originProtocolPolicyInput(): string | undefined;
    private _originReadTimeout?;
    /**
     * @stability stable
     */
    get originReadTimeout(): number;
    /**
     * @stability stable
     */
    set originReadTimeout(value: number);
    /**
     * @stability stable
     */
    resetOriginReadTimeout(): void;
    /**
     * @stability stable
     */
    get originReadTimeoutInput(): number | undefined;
    private _originSslProtocols?;
    /**
     * @stability stable
     */
    get originSslProtocols(): string[];
    /**
     * @stability stable
     */
    set originSslProtocols(value: string[]);
    /**
     * @stability stable
     */
    get originSslProtocolsInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface CloudfrontDistributionOriginOriginShield {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#enabled CloudfrontDistribution#enabled}.
     *
     * @stability stable
     */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#origin_shield_region CloudfrontDistribution#origin_shield_region}.
     *
     * @stability stable
     */
    readonly originShieldRegion: string;
}
export declare function cloudfrontDistributionOriginOriginShieldToTerraform(struct?: CloudfrontDistributionOriginOriginShieldOutputReference | CloudfrontDistributionOriginOriginShield): any;
/**
 * @stability stable
 */
export declare class CloudfrontDistributionOriginOriginShieldOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudfrontDistributionOriginOriginShield | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudfrontDistributionOriginOriginShield | undefined);
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _originShieldRegion?;
    /**
     * @stability stable
     */
    get originShieldRegion(): string;
    /**
     * @stability stable
     */
    set originShieldRegion(value: string);
    /**
     * @stability stable
     */
    get originShieldRegionInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface CloudfrontDistributionOriginS3OriginConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#origin_access_identity CloudfrontDistribution#origin_access_identity}.
     *
     * @stability stable
     */
    readonly originAccessIdentity: string;
}
export declare function cloudfrontDistributionOriginS3OriginConfigToTerraform(struct?: CloudfrontDistributionOriginS3OriginConfigOutputReference | CloudfrontDistributionOriginS3OriginConfig): any;
/**
 * @stability stable
 */
export declare class CloudfrontDistributionOriginS3OriginConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudfrontDistributionOriginS3OriginConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudfrontDistributionOriginS3OriginConfig | undefined);
    private _originAccessIdentity?;
    /**
     * @stability stable
     */
    get originAccessIdentity(): string;
    /**
     * @stability stable
     */
    set originAccessIdentity(value: string);
    /**
     * @stability stable
     */
    get originAccessIdentityInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface CloudfrontDistributionOrigin {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#connection_attempts CloudfrontDistribution#connection_attempts}.
     *
     * @stability stable
     */
    readonly connectionAttempts?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#connection_timeout CloudfrontDistribution#connection_timeout}.
     *
     * @stability stable
     */
    readonly connectionTimeout?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#domain_name CloudfrontDistribution#domain_name}.
     *
     * @stability stable
     */
    readonly domainName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#origin_id CloudfrontDistribution#origin_id}.
     *
     * @stability stable
     */
    readonly originId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#origin_path CloudfrontDistribution#origin_path}.
     *
     * @stability stable
     */
    readonly originPath?: string;
    /**
     * custom_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#custom_header CloudfrontDistribution#custom_header}
     *
     * @stability stable
     */
    readonly customHeader?: CloudfrontDistributionOriginCustomHeader[];
    /**
     * custom_origin_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#custom_origin_config CloudfrontDistribution#custom_origin_config}
     *
     * @stability stable
     */
    readonly customOriginConfig?: CloudfrontDistributionOriginCustomOriginConfig;
    /**
     * origin_shield block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#origin_shield CloudfrontDistribution#origin_shield}
     *
     * @stability stable
     */
    readonly originShield?: CloudfrontDistributionOriginOriginShield;
    /**
     * s3_origin_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#s3_origin_config CloudfrontDistribution#s3_origin_config}
     *
     * @stability stable
     */
    readonly s3OriginConfig?: CloudfrontDistributionOriginS3OriginConfig;
}
export declare function cloudfrontDistributionOriginToTerraform(struct?: CloudfrontDistributionOrigin): any;
/**
 * @stability stable
 */
export interface CloudfrontDistributionOriginGroupFailoverCriteria {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#status_codes CloudfrontDistribution#status_codes}.
     *
     * @stability stable
     */
    readonly statusCodes: number[];
}
export declare function cloudfrontDistributionOriginGroupFailoverCriteriaToTerraform(struct?: CloudfrontDistributionOriginGroupFailoverCriteriaOutputReference | CloudfrontDistributionOriginGroupFailoverCriteria): any;
/**
 * @stability stable
 */
export declare class CloudfrontDistributionOriginGroupFailoverCriteriaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudfrontDistributionOriginGroupFailoverCriteria | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudfrontDistributionOriginGroupFailoverCriteria | undefined);
    private _statusCodes?;
    /**
     * @stability stable
     */
    get statusCodes(): number[];
    /**
     * @stability stable
     */
    set statusCodes(value: number[]);
    /**
     * @stability stable
     */
    get statusCodesInput(): number[] | undefined;
}
/**
 * @stability stable
 */
export interface CloudfrontDistributionOriginGroupMember {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#origin_id CloudfrontDistribution#origin_id}.
     *
     * @stability stable
     */
    readonly originId: string;
}
export declare function cloudfrontDistributionOriginGroupMemberToTerraform(struct?: CloudfrontDistributionOriginGroupMember): any;
/**
 * @stability stable
 */
export interface CloudfrontDistributionOriginGroup {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#origin_id CloudfrontDistribution#origin_id}.
     *
     * @stability stable
     */
    readonly originId: string;
    /**
     * failover_criteria block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#failover_criteria CloudfrontDistribution#failover_criteria}
     *
     * @stability stable
     */
    readonly failoverCriteria: CloudfrontDistributionOriginGroupFailoverCriteria;
    /**
     * member block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#member CloudfrontDistribution#member}
     *
     * @stability stable
     */
    readonly member: CloudfrontDistributionOriginGroupMember[];
}
export declare function cloudfrontDistributionOriginGroupToTerraform(struct?: CloudfrontDistributionOriginGroup): any;
/**
 * @stability stable
 */
export interface CloudfrontDistributionRestrictionsGeoRestriction {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#locations CloudfrontDistribution#locations}.
     *
     * @stability stable
     */
    readonly locations?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#restriction_type CloudfrontDistribution#restriction_type}.
     *
     * @stability stable
     */
    readonly restrictionType: string;
}
export declare function cloudfrontDistributionRestrictionsGeoRestrictionToTerraform(struct?: CloudfrontDistributionRestrictionsGeoRestrictionOutputReference | CloudfrontDistributionRestrictionsGeoRestriction): any;
/**
 * @stability stable
 */
export declare class CloudfrontDistributionRestrictionsGeoRestrictionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudfrontDistributionRestrictionsGeoRestriction | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudfrontDistributionRestrictionsGeoRestriction | undefined);
    private _locations?;
    /**
     * @stability stable
     */
    get locations(): string[];
    /**
     * @stability stable
     */
    set locations(value: string[]);
    /**
     * @stability stable
     */
    resetLocations(): void;
    /**
     * @stability stable
     */
    get locationsInput(): string[] | undefined;
    private _restrictionType?;
    /**
     * @stability stable
     */
    get restrictionType(): string;
    /**
     * @stability stable
     */
    set restrictionType(value: string);
    /**
     * @stability stable
     */
    get restrictionTypeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface CloudfrontDistributionRestrictions {
    /**
     * geo_restriction block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#geo_restriction CloudfrontDistribution#geo_restriction}
     *
     * @stability stable
     */
    readonly geoRestriction: CloudfrontDistributionRestrictionsGeoRestriction;
}
export declare function cloudfrontDistributionRestrictionsToTerraform(struct?: CloudfrontDistributionRestrictionsOutputReference | CloudfrontDistributionRestrictions): any;
/**
 * @stability stable
 */
export declare class CloudfrontDistributionRestrictionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudfrontDistributionRestrictions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudfrontDistributionRestrictions | undefined);
    private _geoRestriction;
    /**
     * @stability stable
     */
    get geoRestriction(): CloudfrontDistributionRestrictionsGeoRestrictionOutputReference;
    /**
     * @stability stable
     */
    putGeoRestriction(value: CloudfrontDistributionRestrictionsGeoRestriction): void;
    /**
     * @stability stable
     */
    get geoRestrictionInput(): CloudfrontDistributionRestrictionsGeoRestriction | undefined;
}
/**
 * @stability stable
 */
export interface CloudfrontDistributionViewerCertificate {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#acm_certificate_arn CloudfrontDistribution#acm_certificate_arn}.
     *
     * @stability stable
     */
    readonly acmCertificateArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#cloudfront_default_certificate CloudfrontDistribution#cloudfront_default_certificate}.
     *
     * @stability stable
     */
    readonly cloudfrontDefaultCertificate?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#iam_certificate_id CloudfrontDistribution#iam_certificate_id}.
     *
     * @stability stable
     */
    readonly iamCertificateId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#minimum_protocol_version CloudfrontDistribution#minimum_protocol_version}.
     *
     * @stability stable
     */
    readonly minimumProtocolVersion?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution#ssl_support_method CloudfrontDistribution#ssl_support_method}.
     *
     * @stability stable
     */
    readonly sslSupportMethod?: string;
}
export declare function cloudfrontDistributionViewerCertificateToTerraform(struct?: CloudfrontDistributionViewerCertificateOutputReference | CloudfrontDistributionViewerCertificate): any;
/**
 * @stability stable
 */
export declare class CloudfrontDistributionViewerCertificateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudfrontDistributionViewerCertificate | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudfrontDistributionViewerCertificate | undefined);
    private _acmCertificateArn?;
    /**
     * @stability stable
     */
    get acmCertificateArn(): string;
    /**
     * @stability stable
     */
    set acmCertificateArn(value: string);
    /**
     * @stability stable
     */
    resetAcmCertificateArn(): void;
    /**
     * @stability stable
     */
    get acmCertificateArnInput(): string | undefined;
    private _cloudfrontDefaultCertificate?;
    /**
     * @stability stable
     */
    get cloudfrontDefaultCertificate(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set cloudfrontDefaultCertificate(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetCloudfrontDefaultCertificate(): void;
    /**
     * @stability stable
     */
    get cloudfrontDefaultCertificateInput(): boolean | cdktf.IResolvable | undefined;
    private _iamCertificateId?;
    /**
     * @stability stable
     */
    get iamCertificateId(): string;
    /**
     * @stability stable
     */
    set iamCertificateId(value: string);
    /**
     * @stability stable
     */
    resetIamCertificateId(): void;
    /**
     * @stability stable
     */
    get iamCertificateIdInput(): string | undefined;
    private _minimumProtocolVersion?;
    /**
     * @stability stable
     */
    get minimumProtocolVersion(): string;
    /**
     * @stability stable
     */
    set minimumProtocolVersion(value: string);
    /**
     * @stability stable
     */
    resetMinimumProtocolVersion(): void;
    /**
     * @stability stable
     */
    get minimumProtocolVersionInput(): string | undefined;
    private _sslSupportMethod?;
    /**
     * @stability stable
     */
    get sslSupportMethod(): string;
    /**
     * @stability stable
     */
    set sslSupportMethod(value: string);
    /**
     * @stability stable
     */
    resetSslSupportMethod(): void;
    /**
     * @stability stable
     */
    get sslSupportMethodInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution aws_cloudfront_distribution}.
 *
 * @stability stable
 */
export declare class CloudfrontDistribution extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution aws_cloudfront_distribution} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CloudfrontDistributionConfig);
    private _aliases?;
    /**
     * @stability stable
     */
    get aliases(): string[];
    /**
     * @stability stable
     */
    set aliases(value: string[]);
    /**
     * @stability stable
     */
    resetAliases(): void;
    /**
     * @stability stable
     */
    get aliasesInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get callerReference(): string;
    private _comment?;
    /**
     * @stability stable
     */
    get comment(): string;
    /**
     * @stability stable
     */
    set comment(value: string);
    /**
     * @stability stable
     */
    resetComment(): void;
    /**
     * @stability stable
     */
    get commentInput(): string | undefined;
    private _defaultRootObject?;
    /**
     * @stability stable
     */
    get defaultRootObject(): string;
    /**
     * @stability stable
     */
    set defaultRootObject(value: string);
    /**
     * @stability stable
     */
    resetDefaultRootObject(): void;
    /**
     * @stability stable
     */
    get defaultRootObjectInput(): string | undefined;
    /**
     * @stability stable
     */
    get domainName(): string;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get etag(): string;
    /**
     * @stability stable
     */
    get hostedZoneId(): string;
    private _httpVersion?;
    /**
     * @stability stable
     */
    get httpVersion(): string;
    /**
     * @stability stable
     */
    set httpVersion(value: string);
    /**
     * @stability stable
     */
    resetHttpVersion(): void;
    /**
     * @stability stable
     */
    get httpVersionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get inProgressValidationBatches(): number;
    private _isIpv6Enabled?;
    /**
     * @stability stable
     */
    get isIpv6Enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set isIpv6Enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIsIpv6Enabled(): void;
    /**
     * @stability stable
     */
    get isIpv6EnabledInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get lastModifiedTime(): string;
    private _priceClass?;
    /**
     * @stability stable
     */
    get priceClass(): string;
    /**
     * @stability stable
     */
    set priceClass(value: string);
    /**
     * @stability stable
     */
    resetPriceClass(): void;
    /**
     * @stability stable
     */
    get priceClassInput(): string | undefined;
    private _retainOnDelete?;
    /**
     * @stability stable
     */
    get retainOnDelete(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set retainOnDelete(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRetainOnDelete(): void;
    /**
     * @stability stable
     */
    get retainOnDeleteInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get status(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    trustedKeyGroups(index: string): CloudfrontDistributionTrustedKeyGroups;
    /**
     * @stability stable
     */
    trustedSigners(index: string): CloudfrontDistributionTrustedSigners;
    private _waitForDeployment?;
    /**
     * @stability stable
     */
    get waitForDeployment(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set waitForDeployment(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetWaitForDeployment(): void;
    /**
     * @stability stable
     */
    get waitForDeploymentInput(): boolean | cdktf.IResolvable | undefined;
    private _webAclId?;
    /**
     * @stability stable
     */
    get webAclId(): string;
    /**
     * @stability stable
     */
    set webAclId(value: string);
    /**
     * @stability stable
     */
    resetWebAclId(): void;
    /**
     * @stability stable
     */
    get webAclIdInput(): string | undefined;
    private _customErrorResponse?;
    /**
     * @stability stable
     */
    get customErrorResponse(): CloudfrontDistributionCustomErrorResponse[];
    /**
     * @stability stable
     */
    set customErrorResponse(value: CloudfrontDistributionCustomErrorResponse[]);
    /**
     * @stability stable
     */
    resetCustomErrorResponse(): void;
    /**
     * @stability stable
     */
    get customErrorResponseInput(): CloudfrontDistributionCustomErrorResponse[] | undefined;
    private _defaultCacheBehavior;
    /**
     * @stability stable
     */
    get defaultCacheBehavior(): CloudfrontDistributionDefaultCacheBehaviorOutputReference;
    /**
     * @stability stable
     */
    putDefaultCacheBehavior(value: CloudfrontDistributionDefaultCacheBehavior): void;
    /**
     * @stability stable
     */
    get defaultCacheBehaviorInput(): CloudfrontDistributionDefaultCacheBehavior | undefined;
    private _loggingConfig;
    /**
     * @stability stable
     */
    get loggingConfig(): CloudfrontDistributionLoggingConfigOutputReference;
    /**
     * @stability stable
     */
    putLoggingConfig(value: CloudfrontDistributionLoggingConfig): void;
    /**
     * @stability stable
     */
    resetLoggingConfig(): void;
    /**
     * @stability stable
     */
    get loggingConfigInput(): CloudfrontDistributionLoggingConfig | undefined;
    private _orderedCacheBehavior?;
    /**
     * @stability stable
     */
    get orderedCacheBehavior(): CloudfrontDistributionOrderedCacheBehavior[];
    /**
     * @stability stable
     */
    set orderedCacheBehavior(value: CloudfrontDistributionOrderedCacheBehavior[]);
    /**
     * @stability stable
     */
    resetOrderedCacheBehavior(): void;
    /**
     * @stability stable
     */
    get orderedCacheBehaviorInput(): CloudfrontDistributionOrderedCacheBehavior[] | undefined;
    private _origin?;
    /**
     * @stability stable
     */
    get origin(): CloudfrontDistributionOrigin[];
    /**
     * @stability stable
     */
    set origin(value: CloudfrontDistributionOrigin[]);
    /**
     * @stability stable
     */
    get originInput(): CloudfrontDistributionOrigin[] | undefined;
    private _originGroup?;
    /**
     * @stability stable
     */
    get originGroup(): CloudfrontDistributionOriginGroup[];
    /**
     * @stability stable
     */
    set originGroup(value: CloudfrontDistributionOriginGroup[]);
    /**
     * @stability stable
     */
    resetOriginGroup(): void;
    /**
     * @stability stable
     */
    get originGroupInput(): CloudfrontDistributionOriginGroup[] | undefined;
    private _restrictions;
    /**
     * @stability stable
     */
    get restrictions(): CloudfrontDistributionRestrictionsOutputReference;
    /**
     * @stability stable
     */
    putRestrictions(value: CloudfrontDistributionRestrictions): void;
    /**
     * @stability stable
     */
    get restrictionsInput(): CloudfrontDistributionRestrictions | undefined;
    private _viewerCertificate;
    /**
     * @stability stable
     */
    get viewerCertificate(): CloudfrontDistributionViewerCertificateOutputReference;
    /**
     * @stability stable
     */
    putViewerCertificate(value: CloudfrontDistributionViewerCertificate): void;
    /**
     * @stability stable
     */
    get viewerCertificateInput(): CloudfrontDistributionViewerCertificate | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
