import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS CodePipeline.
 *
 * @stability stable
 */
export interface CodepipelineWebhookConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook#authentication CodepipelineWebhook#authentication}.
     *
     * @stability stable
     */
    readonly authentication: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook#name CodepipelineWebhook#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook#tags CodepipelineWebhook#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook#tags_all CodepipelineWebhook#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook#target_action CodepipelineWebhook#target_action}.
     *
     * @stability stable
     */
    readonly targetAction: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook#target_pipeline CodepipelineWebhook#target_pipeline}.
     *
     * @stability stable
     */
    readonly targetPipeline: string;
    /**
     * authentication_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook#authentication_configuration CodepipelineWebhook#authentication_configuration}
     *
     * @stability stable
     */
    readonly authenticationConfiguration?: CodepipelineWebhookAuthenticationConfiguration;
    /**
     * filter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook#filter CodepipelineWebhook#filter}
     *
     * @stability stable
     */
    readonly filter: CodepipelineWebhookFilter[];
}
/**
 * @stability stable
 */
export interface CodepipelineWebhookAuthenticationConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook#allowed_ip_range CodepipelineWebhook#allowed_ip_range}.
     *
     * @stability stable
     */
    readonly allowedIpRange?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook#secret_token CodepipelineWebhook#secret_token}.
     *
     * @stability stable
     */
    readonly secretToken?: string;
}
export declare function codepipelineWebhookAuthenticationConfigurationToTerraform(struct?: CodepipelineWebhookAuthenticationConfigurationOutputReference | CodepipelineWebhookAuthenticationConfiguration): any;
/**
 * @stability stable
 */
export declare class CodepipelineWebhookAuthenticationConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CodepipelineWebhookAuthenticationConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CodepipelineWebhookAuthenticationConfiguration | undefined);
    private _allowedIpRange?;
    /**
     * @stability stable
     */
    get allowedIpRange(): string;
    /**
     * @stability stable
     */
    set allowedIpRange(value: string);
    /**
     * @stability stable
     */
    resetAllowedIpRange(): void;
    /**
     * @stability stable
     */
    get allowedIpRangeInput(): string | undefined;
    private _secretToken?;
    /**
     * @stability stable
     */
    get secretToken(): string;
    /**
     * @stability stable
     */
    set secretToken(value: string);
    /**
     * @stability stable
     */
    resetSecretToken(): void;
    /**
     * @stability stable
     */
    get secretTokenInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface CodepipelineWebhookFilter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook#json_path CodepipelineWebhook#json_path}.
     *
     * @stability stable
     */
    readonly jsonPath: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook#match_equals CodepipelineWebhook#match_equals}.
     *
     * @stability stable
     */
    readonly matchEquals: string;
}
export declare function codepipelineWebhookFilterToTerraform(struct?: CodepipelineWebhookFilter): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook aws_codepipeline_webhook}.
 *
 * @stability stable
 */
export declare class CodepipelineWebhook extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook aws_codepipeline_webhook} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CodepipelineWebhookConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _authentication?;
    /**
     * @stability stable
     */
    get authentication(): string;
    /**
     * @stability stable
     */
    set authentication(value: string);
    /**
     * @stability stable
     */
    get authenticationInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _targetAction?;
    /**
     * @stability stable
     */
    get targetAction(): string;
    /**
     * @stability stable
     */
    set targetAction(value: string);
    /**
     * @stability stable
     */
    get targetActionInput(): string | undefined;
    private _targetPipeline?;
    /**
     * @stability stable
     */
    get targetPipeline(): string;
    /**
     * @stability stable
     */
    set targetPipeline(value: string);
    /**
     * @stability stable
     */
    get targetPipelineInput(): string | undefined;
    /**
     * @stability stable
     */
    get url(): string;
    private _authenticationConfiguration;
    /**
     * @stability stable
     */
    get authenticationConfiguration(): CodepipelineWebhookAuthenticationConfigurationOutputReference;
    /**
     * @stability stable
     */
    putAuthenticationConfiguration(value: CodepipelineWebhookAuthenticationConfiguration): void;
    /**
     * @stability stable
     */
    resetAuthenticationConfiguration(): void;
    /**
     * @stability stable
     */
    get authenticationConfigurationInput(): CodepipelineWebhookAuthenticationConfiguration | undefined;
    private _filter?;
    /**
     * @stability stable
     */
    get filter(): CodepipelineWebhookFilter[];
    /**
     * @stability stable
     */
    set filter(value: CodepipelineWebhookFilter[]);
    /**
     * @stability stable
     */
    get filterInput(): CodepipelineWebhookFilter[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
