import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Cognito.
 *
 * @stability stable
 */
export interface CognitoIdentityPoolConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool#allow_classic_flow CognitoIdentityPool#allow_classic_flow}.
     *
     * @stability stable
     */
    readonly allowClassicFlow?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool#allow_unauthenticated_identities CognitoIdentityPool#allow_unauthenticated_identities}.
     *
     * @stability stable
     */
    readonly allowUnauthenticatedIdentities?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool#developer_provider_name CognitoIdentityPool#developer_provider_name}.
     *
     * @stability stable
     */
    readonly developerProviderName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool#identity_pool_name CognitoIdentityPool#identity_pool_name}.
     *
     * @stability stable
     */
    readonly identityPoolName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool#openid_connect_provider_arns CognitoIdentityPool#openid_connect_provider_arns}.
     *
     * @stability stable
     */
    readonly openidConnectProviderArns?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool#saml_provider_arns CognitoIdentityPool#saml_provider_arns}.
     *
     * @stability stable
     */
    readonly samlProviderArns?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool#supported_login_providers CognitoIdentityPool#supported_login_providers}.
     *
     * @stability stable
     */
    readonly supportedLoginProviders?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool#tags CognitoIdentityPool#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool#tags_all CognitoIdentityPool#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * cognito_identity_providers block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool#cognito_identity_providers CognitoIdentityPool#cognito_identity_providers}
     *
     * @stability stable
     */
    readonly cognitoIdentityProviders?: CognitoIdentityPoolCognitoIdentityProviders[];
}
/**
 * @stability stable
 */
export interface CognitoIdentityPoolCognitoIdentityProviders {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool#client_id CognitoIdentityPool#client_id}.
     *
     * @stability stable
     */
    readonly clientId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool#provider_name CognitoIdentityPool#provider_name}.
     *
     * @stability stable
     */
    readonly providerName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool#server_side_token_check CognitoIdentityPool#server_side_token_check}.
     *
     * @stability stable
     */
    readonly serverSideTokenCheck?: boolean | cdktf.IResolvable;
}
export declare function cognitoIdentityPoolCognitoIdentityProvidersToTerraform(struct?: CognitoIdentityPoolCognitoIdentityProviders): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool aws_cognito_identity_pool}.
 *
 * @stability stable
 */
export declare class CognitoIdentityPool extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool aws_cognito_identity_pool} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CognitoIdentityPoolConfig);
    private _allowClassicFlow?;
    /**
     * @stability stable
     */
    get allowClassicFlow(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowClassicFlow(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowClassicFlow(): void;
    /**
     * @stability stable
     */
    get allowClassicFlowInput(): boolean | cdktf.IResolvable | undefined;
    private _allowUnauthenticatedIdentities?;
    /**
     * @stability stable
     */
    get allowUnauthenticatedIdentities(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowUnauthenticatedIdentities(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowUnauthenticatedIdentities(): void;
    /**
     * @stability stable
     */
    get allowUnauthenticatedIdentitiesInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    private _developerProviderName?;
    /**
     * @stability stable
     */
    get developerProviderName(): string;
    /**
     * @stability stable
     */
    set developerProviderName(value: string);
    /**
     * @stability stable
     */
    resetDeveloperProviderName(): void;
    /**
     * @stability stable
     */
    get developerProviderNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _identityPoolName?;
    /**
     * @stability stable
     */
    get identityPoolName(): string;
    /**
     * @stability stable
     */
    set identityPoolName(value: string);
    /**
     * @stability stable
     */
    get identityPoolNameInput(): string | undefined;
    private _openidConnectProviderArns?;
    /**
     * @stability stable
     */
    get openidConnectProviderArns(): string[];
    /**
     * @stability stable
     */
    set openidConnectProviderArns(value: string[]);
    /**
     * @stability stable
     */
    resetOpenidConnectProviderArns(): void;
    /**
     * @stability stable
     */
    get openidConnectProviderArnsInput(): string[] | undefined;
    private _samlProviderArns?;
    /**
     * @stability stable
     */
    get samlProviderArns(): string[];
    /**
     * @stability stable
     */
    set samlProviderArns(value: string[]);
    /**
     * @stability stable
     */
    resetSamlProviderArns(): void;
    /**
     * @stability stable
     */
    get samlProviderArnsInput(): string[] | undefined;
    private _supportedLoginProviders?;
    /**
     * @stability stable
     */
    get supportedLoginProviders(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set supportedLoginProviders(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetSupportedLoginProviders(): void;
    /**
     * @stability stable
     */
    get supportedLoginProvidersInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _cognitoIdentityProviders?;
    /**
     * @stability stable
     */
    get cognitoIdentityProviders(): CognitoIdentityPoolCognitoIdentityProviders[];
    /**
     * @stability stable
     */
    set cognitoIdentityProviders(value: CognitoIdentityPoolCognitoIdentityProviders[]);
    /**
     * @stability stable
     */
    resetCognitoIdentityProviders(): void;
    /**
     * @stability stable
     */
    get cognitoIdentityProvidersInput(): CognitoIdentityPoolCognitoIdentityProviders[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
