import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS DataSync.
 *
 * @stability stable
 */
export interface DatasyncLocationHdfsConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#agent_arns DatasyncLocationHdfs#agent_arns}.
     *
     * @stability stable
     */
    readonly agentArns: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#authentication_type DatasyncLocationHdfs#authentication_type}.
     *
     * @stability stable
     */
    readonly authenticationType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#block_size DatasyncLocationHdfs#block_size}.
     *
     * @stability stable
     */
    readonly blockSize?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#kerberos_keytab DatasyncLocationHdfs#kerberos_keytab}.
     *
     * @stability stable
     */
    readonly kerberosKeytab?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#kerberos_krb5_conf DatasyncLocationHdfs#kerberos_krb5_conf}.
     *
     * @stability stable
     */
    readonly kerberosKrb5Conf?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#kerberos_principal DatasyncLocationHdfs#kerberos_principal}.
     *
     * @stability stable
     */
    readonly kerberosPrincipal?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#kms_key_provider_uri DatasyncLocationHdfs#kms_key_provider_uri}.
     *
     * @stability stable
     */
    readonly kmsKeyProviderUri?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#replication_factor DatasyncLocationHdfs#replication_factor}.
     *
     * @stability stable
     */
    readonly replicationFactor?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#simple_user DatasyncLocationHdfs#simple_user}.
     *
     * @stability stable
     */
    readonly simpleUser?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#subdirectory DatasyncLocationHdfs#subdirectory}.
     *
     * @stability stable
     */
    readonly subdirectory?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#tags DatasyncLocationHdfs#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#tags_all DatasyncLocationHdfs#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * name_node block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#name_node DatasyncLocationHdfs#name_node}
     *
     * @stability stable
     */
    readonly nameNode: DatasyncLocationHdfsNameNode[];
    /**
     * qop_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#qop_configuration DatasyncLocationHdfs#qop_configuration}
     *
     * @stability stable
     */
    readonly qopConfiguration?: DatasyncLocationHdfsQopConfiguration;
}
/**
 * @stability stable
 */
export interface DatasyncLocationHdfsNameNode {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#hostname DatasyncLocationHdfs#hostname}.
     *
     * @stability stable
     */
    readonly hostname: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#port DatasyncLocationHdfs#port}.
     *
     * @stability stable
     */
    readonly port: number;
}
export declare function datasyncLocationHdfsNameNodeToTerraform(struct?: DatasyncLocationHdfsNameNode): any;
/**
 * @stability stable
 */
export interface DatasyncLocationHdfsQopConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#data_transfer_protection DatasyncLocationHdfs#data_transfer_protection}.
     *
     * @stability stable
     */
    readonly dataTransferProtection?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#rpc_protection DatasyncLocationHdfs#rpc_protection}.
     *
     * @stability stable
     */
    readonly rpcProtection?: string;
}
export declare function datasyncLocationHdfsQopConfigurationToTerraform(struct?: DatasyncLocationHdfsQopConfigurationOutputReference | DatasyncLocationHdfsQopConfiguration): any;
/**
 * @stability stable
 */
export declare class DatasyncLocationHdfsQopConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DatasyncLocationHdfsQopConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DatasyncLocationHdfsQopConfiguration | undefined);
    private _dataTransferProtection?;
    /**
     * @stability stable
     */
    get dataTransferProtection(): string;
    /**
     * @stability stable
     */
    set dataTransferProtection(value: string);
    /**
     * @stability stable
     */
    resetDataTransferProtection(): void;
    /**
     * @stability stable
     */
    get dataTransferProtectionInput(): string | undefined;
    private _rpcProtection?;
    /**
     * @stability stable
     */
    get rpcProtection(): string;
    /**
     * @stability stable
     */
    set rpcProtection(value: string);
    /**
     * @stability stable
     */
    resetRpcProtection(): void;
    /**
     * @stability stable
     */
    get rpcProtectionInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs aws_datasync_location_hdfs}.
 *
 * @stability stable
 */
export declare class DatasyncLocationHdfs extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs aws_datasync_location_hdfs} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DatasyncLocationHdfsConfig);
    private _agentArns?;
    /**
     * @stability stable
     */
    get agentArns(): string[];
    /**
     * @stability stable
     */
    set agentArns(value: string[]);
    /**
     * @stability stable
     */
    get agentArnsInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    private _authenticationType?;
    /**
     * @stability stable
     */
    get authenticationType(): string;
    /**
     * @stability stable
     */
    set authenticationType(value: string);
    /**
     * @stability stable
     */
    resetAuthenticationType(): void;
    /**
     * @stability stable
     */
    get authenticationTypeInput(): string | undefined;
    private _blockSize?;
    /**
     * @stability stable
     */
    get blockSize(): number;
    /**
     * @stability stable
     */
    set blockSize(value: number);
    /**
     * @stability stable
     */
    resetBlockSize(): void;
    /**
     * @stability stable
     */
    get blockSizeInput(): number | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _kerberosKeytab?;
    /**
     * @stability stable
     */
    get kerberosKeytab(): string;
    /**
     * @stability stable
     */
    set kerberosKeytab(value: string);
    /**
     * @stability stable
     */
    resetKerberosKeytab(): void;
    /**
     * @stability stable
     */
    get kerberosKeytabInput(): string | undefined;
    private _kerberosKrb5Conf?;
    /**
     * @stability stable
     */
    get kerberosKrb5Conf(): string;
    /**
     * @stability stable
     */
    set kerberosKrb5Conf(value: string);
    /**
     * @stability stable
     */
    resetKerberosKrb5Conf(): void;
    /**
     * @stability stable
     */
    get kerberosKrb5ConfInput(): string | undefined;
    private _kerberosPrincipal?;
    /**
     * @stability stable
     */
    get kerberosPrincipal(): string;
    /**
     * @stability stable
     */
    set kerberosPrincipal(value: string);
    /**
     * @stability stable
     */
    resetKerberosPrincipal(): void;
    /**
     * @stability stable
     */
    get kerberosPrincipalInput(): string | undefined;
    private _kmsKeyProviderUri?;
    /**
     * @stability stable
     */
    get kmsKeyProviderUri(): string;
    /**
     * @stability stable
     */
    set kmsKeyProviderUri(value: string);
    /**
     * @stability stable
     */
    resetKmsKeyProviderUri(): void;
    /**
     * @stability stable
     */
    get kmsKeyProviderUriInput(): string | undefined;
    private _replicationFactor?;
    /**
     * @stability stable
     */
    get replicationFactor(): number;
    /**
     * @stability stable
     */
    set replicationFactor(value: number);
    /**
     * @stability stable
     */
    resetReplicationFactor(): void;
    /**
     * @stability stable
     */
    get replicationFactorInput(): number | undefined;
    private _simpleUser?;
    /**
     * @stability stable
     */
    get simpleUser(): string;
    /**
     * @stability stable
     */
    set simpleUser(value: string);
    /**
     * @stability stable
     */
    resetSimpleUser(): void;
    /**
     * @stability stable
     */
    get simpleUserInput(): string | undefined;
    private _subdirectory?;
    /**
     * @stability stable
     */
    get subdirectory(): string;
    /**
     * @stability stable
     */
    set subdirectory(value: string);
    /**
     * @stability stable
     */
    resetSubdirectory(): void;
    /**
     * @stability stable
     */
    get subdirectoryInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get uri(): string;
    private _nameNode?;
    /**
     * @stability stable
     */
    get nameNode(): DatasyncLocationHdfsNameNode[];
    /**
     * @stability stable
     */
    set nameNode(value: DatasyncLocationHdfsNameNode[]);
    /**
     * @stability stable
     */
    get nameNodeInput(): DatasyncLocationHdfsNameNode[] | undefined;
    private _qopConfiguration;
    /**
     * @stability stable
     */
    get qopConfiguration(): DatasyncLocationHdfsQopConfigurationOutputReference;
    /**
     * @stability stable
     */
    putQopConfiguration(value: DatasyncLocationHdfsQopConfiguration): void;
    /**
     * @stability stable
     */
    resetQopConfiguration(): void;
    /**
     * @stability stable
     */
    get qopConfigurationInput(): DatasyncLocationHdfsQopConfiguration | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
