import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Direct Connect.
 *
 * @stability stable
 */
export interface DxBgpPeerConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer#address_family DxBgpPeer#address_family}.
     *
     * @stability stable
     */
    readonly addressFamily: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer#amazon_address DxBgpPeer#amazon_address}.
     *
     * @stability stable
     */
    readonly amazonAddress?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer#bgp_asn DxBgpPeer#bgp_asn}.
     *
     * @stability stable
     */
    readonly bgpAsn: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer#bgp_auth_key DxBgpPeer#bgp_auth_key}.
     *
     * @stability stable
     */
    readonly bgpAuthKey?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer#customer_address DxBgpPeer#customer_address}.
     *
     * @stability stable
     */
    readonly customerAddress?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer#virtual_interface_id DxBgpPeer#virtual_interface_id}.
     *
     * @stability stable
     */
    readonly virtualInterfaceId: string;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer#timeouts DxBgpPeer#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DxBgpPeerTimeouts;
}
/**
 * @stability stable
 */
export interface DxBgpPeerTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer#create DxBgpPeer#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer#delete DxBgpPeer#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
}
export declare function dxBgpPeerTimeoutsToTerraform(struct?: DxBgpPeerTimeoutsOutputReference | DxBgpPeerTimeouts): any;
/**
 * @stability stable
 */
export declare class DxBgpPeerTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DxBgpPeerTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DxBgpPeerTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer aws_dx_bgp_peer}.
 *
 * @stability stable
 */
export declare class DxBgpPeer extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer aws_dx_bgp_peer} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DxBgpPeerConfig);
    private _addressFamily?;
    /**
     * @stability stable
     */
    get addressFamily(): string;
    /**
     * @stability stable
     */
    set addressFamily(value: string);
    /**
     * @stability stable
     */
    get addressFamilyInput(): string | undefined;
    private _amazonAddress?;
    /**
     * @stability stable
     */
    get amazonAddress(): string;
    /**
     * @stability stable
     */
    set amazonAddress(value: string);
    /**
     * @stability stable
     */
    resetAmazonAddress(): void;
    /**
     * @stability stable
     */
    get amazonAddressInput(): string | undefined;
    /**
     * @stability stable
     */
    get awsDevice(): string;
    private _bgpAsn?;
    /**
     * @stability stable
     */
    get bgpAsn(): number;
    /**
     * @stability stable
     */
    set bgpAsn(value: number);
    /**
     * @stability stable
     */
    get bgpAsnInput(): number | undefined;
    private _bgpAuthKey?;
    /**
     * @stability stable
     */
    get bgpAuthKey(): string;
    /**
     * @stability stable
     */
    set bgpAuthKey(value: string);
    /**
     * @stability stable
     */
    resetBgpAuthKey(): void;
    /**
     * @stability stable
     */
    get bgpAuthKeyInput(): string | undefined;
    /**
     * @stability stable
     */
    get bgpPeerId(): string;
    /**
     * @stability stable
     */
    get bgpStatus(): string;
    private _customerAddress?;
    /**
     * @stability stable
     */
    get customerAddress(): string;
    /**
     * @stability stable
     */
    set customerAddress(value: string);
    /**
     * @stability stable
     */
    resetCustomerAddress(): void;
    /**
     * @stability stable
     */
    get customerAddressInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _virtualInterfaceId?;
    /**
     * @stability stable
     */
    get virtualInterfaceId(): string;
    /**
     * @stability stable
     */
    set virtualInterfaceId(value: string);
    /**
     * @stability stable
     */
    get virtualInterfaceIdInput(): string | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): DxBgpPeerTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: DxBgpPeerTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DxBgpPeerTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
