import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Direct Connect.
 *
 * @stability stable
 */
export interface DxTransitVirtualInterfaceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface#address_family DxTransitVirtualInterface#address_family}.
     *
     * @stability stable
     */
    readonly addressFamily: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface#amazon_address DxTransitVirtualInterface#amazon_address}.
     *
     * @stability stable
     */
    readonly amazonAddress?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface#bgp_asn DxTransitVirtualInterface#bgp_asn}.
     *
     * @stability stable
     */
    readonly bgpAsn: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface#bgp_auth_key DxTransitVirtualInterface#bgp_auth_key}.
     *
     * @stability stable
     */
    readonly bgpAuthKey?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface#connection_id DxTransitVirtualInterface#connection_id}.
     *
     * @stability stable
     */
    readonly connectionId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface#customer_address DxTransitVirtualInterface#customer_address}.
     *
     * @stability stable
     */
    readonly customerAddress?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface#dx_gateway_id DxTransitVirtualInterface#dx_gateway_id}.
     *
     * @stability stable
     */
    readonly dxGatewayId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface#mtu DxTransitVirtualInterface#mtu}.
     *
     * @stability stable
     */
    readonly mtu?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface#name DxTransitVirtualInterface#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface#sitelink_enabled DxTransitVirtualInterface#sitelink_enabled}.
     *
     * @stability stable
     */
    readonly sitelinkEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface#tags DxTransitVirtualInterface#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface#tags_all DxTransitVirtualInterface#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface#vlan DxTransitVirtualInterface#vlan}.
     *
     * @stability stable
     */
    readonly vlan: number;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface#timeouts DxTransitVirtualInterface#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DxTransitVirtualInterfaceTimeouts;
}
/**
 * @stability stable
 */
export interface DxTransitVirtualInterfaceTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface#create DxTransitVirtualInterface#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface#delete DxTransitVirtualInterface#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface#update DxTransitVirtualInterface#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function dxTransitVirtualInterfaceTimeoutsToTerraform(struct?: DxTransitVirtualInterfaceTimeoutsOutputReference | DxTransitVirtualInterfaceTimeouts): any;
/**
 * @stability stable
 */
export declare class DxTransitVirtualInterfaceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DxTransitVirtualInterfaceTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DxTransitVirtualInterfaceTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface aws_dx_transit_virtual_interface}.
 *
 * @stability stable
 */
export declare class DxTransitVirtualInterface extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface aws_dx_transit_virtual_interface} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DxTransitVirtualInterfaceConfig);
    private _addressFamily?;
    /**
     * @stability stable
     */
    get addressFamily(): string;
    /**
     * @stability stable
     */
    set addressFamily(value: string);
    /**
     * @stability stable
     */
    get addressFamilyInput(): string | undefined;
    private _amazonAddress?;
    /**
     * @stability stable
     */
    get amazonAddress(): string;
    /**
     * @stability stable
     */
    set amazonAddress(value: string);
    /**
     * @stability stable
     */
    resetAmazonAddress(): void;
    /**
     * @stability stable
     */
    get amazonAddressInput(): string | undefined;
    /**
     * @stability stable
     */
    get amazonSideAsn(): string;
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get awsDevice(): string;
    private _bgpAsn?;
    /**
     * @stability stable
     */
    get bgpAsn(): number;
    /**
     * @stability stable
     */
    set bgpAsn(value: number);
    /**
     * @stability stable
     */
    get bgpAsnInput(): number | undefined;
    private _bgpAuthKey?;
    /**
     * @stability stable
     */
    get bgpAuthKey(): string;
    /**
     * @stability stable
     */
    set bgpAuthKey(value: string);
    /**
     * @stability stable
     */
    resetBgpAuthKey(): void;
    /**
     * @stability stable
     */
    get bgpAuthKeyInput(): string | undefined;
    private _connectionId?;
    /**
     * @stability stable
     */
    get connectionId(): string;
    /**
     * @stability stable
     */
    set connectionId(value: string);
    /**
     * @stability stable
     */
    get connectionIdInput(): string | undefined;
    private _customerAddress?;
    /**
     * @stability stable
     */
    get customerAddress(): string;
    /**
     * @stability stable
     */
    set customerAddress(value: string);
    /**
     * @stability stable
     */
    resetCustomerAddress(): void;
    /**
     * @stability stable
     */
    get customerAddressInput(): string | undefined;
    private _dxGatewayId?;
    /**
     * @stability stable
     */
    get dxGatewayId(): string;
    /**
     * @stability stable
     */
    set dxGatewayId(value: string);
    /**
     * @stability stable
     */
    get dxGatewayIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get jumboFrameCapable(): any;
    private _mtu?;
    /**
     * @stability stable
     */
    get mtu(): number;
    /**
     * @stability stable
     */
    set mtu(value: number);
    /**
     * @stability stable
     */
    resetMtu(): void;
    /**
     * @stability stable
     */
    get mtuInput(): number | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _sitelinkEnabled?;
    /**
     * @stability stable
     */
    get sitelinkEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set sitelinkEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetSitelinkEnabled(): void;
    /**
     * @stability stable
     */
    get sitelinkEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _vlan?;
    /**
     * @stability stable
     */
    get vlan(): number;
    /**
     * @stability stable
     */
    set vlan(value: number);
    /**
     * @stability stable
     */
    get vlanInput(): number | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): DxTransitVirtualInterfaceTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: DxTransitVirtualInterfaceTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DxTransitVirtualInterfaceTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
