import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS DocumentDB.
 *
 * @stability stable
 */
export interface DocdbGlobalClusterConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/docdb_global_cluster#database_name DocdbGlobalCluster#database_name}.
     *
     * @stability stable
     */
    readonly databaseName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/docdb_global_cluster#deletion_protection DocdbGlobalCluster#deletion_protection}.
     *
     * @stability stable
     */
    readonly deletionProtection?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/docdb_global_cluster#engine DocdbGlobalCluster#engine}.
     *
     * @stability stable
     */
    readonly engine?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/docdb_global_cluster#engine_version DocdbGlobalCluster#engine_version}.
     *
     * @stability stable
     */
    readonly engineVersion?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/docdb_global_cluster#global_cluster_identifier DocdbGlobalCluster#global_cluster_identifier}.
     *
     * @stability stable
     */
    readonly globalClusterIdentifier: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/docdb_global_cluster#source_db_cluster_identifier DocdbGlobalCluster#source_db_cluster_identifier}.
     *
     * @stability stable
     */
    readonly sourceDbClusterIdentifier?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/docdb_global_cluster#storage_encrypted DocdbGlobalCluster#storage_encrypted}.
     *
     * @stability stable
     */
    readonly storageEncrypted?: boolean | cdktf.IResolvable;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/docdb_global_cluster#timeouts DocdbGlobalCluster#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DocdbGlobalClusterTimeouts;
}
/**
 * @stability stable
 */
export declare class DocdbGlobalClusterGlobalClusterMembers extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get dbClusterArn(): string;
    /**
     * @stability stable
     */
    get isWriter(): any;
}
/**
 * @stability stable
 */
export interface DocdbGlobalClusterTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/docdb_global_cluster#create DocdbGlobalCluster#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/docdb_global_cluster#delete DocdbGlobalCluster#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/docdb_global_cluster#update DocdbGlobalCluster#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function docdbGlobalClusterTimeoutsToTerraform(struct?: DocdbGlobalClusterTimeoutsOutputReference | DocdbGlobalClusterTimeouts): any;
/**
 * @stability stable
 */
export declare class DocdbGlobalClusterTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DocdbGlobalClusterTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DocdbGlobalClusterTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/docdb_global_cluster aws_docdb_global_cluster}.
 *
 * @stability stable
 */
export declare class DocdbGlobalCluster extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/docdb_global_cluster aws_docdb_global_cluster} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DocdbGlobalClusterConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _databaseName?;
    /**
     * @stability stable
     */
    get databaseName(): string;
    /**
     * @stability stable
     */
    set databaseName(value: string);
    /**
     * @stability stable
     */
    resetDatabaseName(): void;
    /**
     * @stability stable
     */
    get databaseNameInput(): string | undefined;
    private _deletionProtection?;
    /**
     * @stability stable
     */
    get deletionProtection(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set deletionProtection(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetDeletionProtection(): void;
    /**
     * @stability stable
     */
    get deletionProtectionInput(): boolean | cdktf.IResolvable | undefined;
    private _engine?;
    /**
     * @stability stable
     */
    get engine(): string;
    /**
     * @stability stable
     */
    set engine(value: string);
    /**
     * @stability stable
     */
    resetEngine(): void;
    /**
     * @stability stable
     */
    get engineInput(): string | undefined;
    private _engineVersion?;
    /**
     * @stability stable
     */
    get engineVersion(): string;
    /**
     * @stability stable
     */
    set engineVersion(value: string);
    /**
     * @stability stable
     */
    resetEngineVersion(): void;
    /**
     * @stability stable
     */
    get engineVersionInput(): string | undefined;
    private _globalClusterIdentifier?;
    /**
     * @stability stable
     */
    get globalClusterIdentifier(): string;
    /**
     * @stability stable
     */
    set globalClusterIdentifier(value: string);
    /**
     * @stability stable
     */
    get globalClusterIdentifierInput(): string | undefined;
    /**
     * @stability stable
     */
    globalClusterMembers(index: string): DocdbGlobalClusterGlobalClusterMembers;
    /**
     * @stability stable
     */
    get globalClusterResourceId(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _sourceDbClusterIdentifier?;
    /**
     * @stability stable
     */
    get sourceDbClusterIdentifier(): string;
    /**
     * @stability stable
     */
    set sourceDbClusterIdentifier(value: string);
    /**
     * @stability stable
     */
    resetSourceDbClusterIdentifier(): void;
    /**
     * @stability stable
     */
    get sourceDbClusterIdentifierInput(): string | undefined;
    /**
     * @stability stable
     */
    get status(): string;
    private _storageEncrypted?;
    /**
     * @stability stable
     */
    get storageEncrypted(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set storageEncrypted(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetStorageEncrypted(): void;
    /**
     * @stability stable
     */
    get storageEncryptedInput(): boolean | cdktf.IResolvable | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): DocdbGlobalClusterTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: DocdbGlobalClusterTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DocdbGlobalClusterTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
