import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS DynamoDB.
 *
 * @stability stable
 */
export interface DynamodbTableConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#billing_mode DynamodbTable#billing_mode}.
     *
     * @stability stable
     */
    readonly billingMode?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#hash_key DynamodbTable#hash_key}.
     *
     * @stability stable
     */
    readonly hashKey?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#name DynamodbTable#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#range_key DynamodbTable#range_key}.
     *
     * @stability stable
     */
    readonly rangeKey?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#read_capacity DynamodbTable#read_capacity}.
     *
     * @stability stable
     */
    readonly readCapacity?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#restore_date_time DynamodbTable#restore_date_time}.
     *
     * @stability stable
     */
    readonly restoreDateTime?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#restore_source_name DynamodbTable#restore_source_name}.
     *
     * @stability stable
     */
    readonly restoreSourceName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#restore_to_latest_time DynamodbTable#restore_to_latest_time}.
     *
     * @stability stable
     */
    readonly restoreToLatestTime?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#stream_enabled DynamodbTable#stream_enabled}.
     *
     * @stability stable
     */
    readonly streamEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#stream_view_type DynamodbTable#stream_view_type}.
     *
     * @stability stable
     */
    readonly streamViewType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#table_class DynamodbTable#table_class}.
     *
     * @stability stable
     */
    readonly tableClass?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#tags DynamodbTable#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#tags_all DynamodbTable#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#write_capacity DynamodbTable#write_capacity}.
     *
     * @stability stable
     */
    readonly writeCapacity?: number;
    /**
     * attribute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#attribute DynamodbTable#attribute}
     *
     * @stability stable
     */
    readonly attribute?: DynamodbTableAttribute[];
    /**
     * global_secondary_index block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#global_secondary_index DynamodbTable#global_secondary_index}
     *
     * @stability stable
     */
    readonly globalSecondaryIndex?: DynamodbTableGlobalSecondaryIndex[];
    /**
     * local_secondary_index block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#local_secondary_index DynamodbTable#local_secondary_index}
     *
     * @stability stable
     */
    readonly localSecondaryIndex?: DynamodbTableLocalSecondaryIndex[];
    /**
     * point_in_time_recovery block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#point_in_time_recovery DynamodbTable#point_in_time_recovery}
     *
     * @stability stable
     */
    readonly pointInTimeRecovery?: DynamodbTablePointInTimeRecovery;
    /**
     * replica block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#replica DynamodbTable#replica}
     *
     * @stability stable
     */
    readonly replica?: DynamodbTableReplica[];
    /**
     * server_side_encryption block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#server_side_encryption DynamodbTable#server_side_encryption}
     *
     * @stability stable
     */
    readonly serverSideEncryption?: DynamodbTableServerSideEncryption;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#timeouts DynamodbTable#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DynamodbTableTimeouts;
    /**
     * ttl block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#ttl DynamodbTable#ttl}
     *
     * @stability stable
     */
    readonly ttl?: DynamodbTableTtl;
}
/**
 * @stability stable
 */
export interface DynamodbTableAttribute {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#name DynamodbTable#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#type DynamodbTable#type}.
     *
     * @stability stable
     */
    readonly type: string;
}
export declare function dynamodbTableAttributeToTerraform(struct?: DynamodbTableAttribute): any;
/**
 * @stability stable
 */
export interface DynamodbTableGlobalSecondaryIndex {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#hash_key DynamodbTable#hash_key}.
     *
     * @stability stable
     */
    readonly hashKey: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#name DynamodbTable#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#non_key_attributes DynamodbTable#non_key_attributes}.
     *
     * @stability stable
     */
    readonly nonKeyAttributes?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#projection_type DynamodbTable#projection_type}.
     *
     * @stability stable
     */
    readonly projectionType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#range_key DynamodbTable#range_key}.
     *
     * @stability stable
     */
    readonly rangeKey?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#read_capacity DynamodbTable#read_capacity}.
     *
     * @stability stable
     */
    readonly readCapacity?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#write_capacity DynamodbTable#write_capacity}.
     *
     * @stability stable
     */
    readonly writeCapacity?: number;
}
export declare function dynamodbTableGlobalSecondaryIndexToTerraform(struct?: DynamodbTableGlobalSecondaryIndex): any;
/**
 * @stability stable
 */
export interface DynamodbTableLocalSecondaryIndex {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#name DynamodbTable#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#non_key_attributes DynamodbTable#non_key_attributes}.
     *
     * @stability stable
     */
    readonly nonKeyAttributes?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#projection_type DynamodbTable#projection_type}.
     *
     * @stability stable
     */
    readonly projectionType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#range_key DynamodbTable#range_key}.
     *
     * @stability stable
     */
    readonly rangeKey: string;
}
export declare function dynamodbTableLocalSecondaryIndexToTerraform(struct?: DynamodbTableLocalSecondaryIndex): any;
/**
 * @stability stable
 */
export interface DynamodbTablePointInTimeRecovery {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#enabled DynamodbTable#enabled}.
     *
     * @stability stable
     */
    readonly enabled: boolean | cdktf.IResolvable;
}
export declare function dynamodbTablePointInTimeRecoveryToTerraform(struct?: DynamodbTablePointInTimeRecoveryOutputReference | DynamodbTablePointInTimeRecovery): any;
/**
 * @stability stable
 */
export declare class DynamodbTablePointInTimeRecoveryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DynamodbTablePointInTimeRecovery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DynamodbTablePointInTimeRecovery | undefined);
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface DynamodbTableReplica {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#kms_key_arn DynamodbTable#kms_key_arn}.
     *
     * @stability stable
     */
    readonly kmsKeyArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#region_name DynamodbTable#region_name}.
     *
     * @stability stable
     */
    readonly regionName: string;
}
export declare function dynamodbTableReplicaToTerraform(struct?: DynamodbTableReplica): any;
/**
 * @stability stable
 */
export interface DynamodbTableServerSideEncryption {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#enabled DynamodbTable#enabled}.
     *
     * @stability stable
     */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#kms_key_arn DynamodbTable#kms_key_arn}.
     *
     * @stability stable
     */
    readonly kmsKeyArn?: string;
}
export declare function dynamodbTableServerSideEncryptionToTerraform(struct?: DynamodbTableServerSideEncryptionOutputReference | DynamodbTableServerSideEncryption): any;
/**
 * @stability stable
 */
export declare class DynamodbTableServerSideEncryptionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DynamodbTableServerSideEncryption | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DynamodbTableServerSideEncryption | undefined);
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _kmsKeyArn?;
    /**
     * @stability stable
     */
    get kmsKeyArn(): string;
    /**
     * @stability stable
     */
    set kmsKeyArn(value: string);
    /**
     * @stability stable
     */
    resetKmsKeyArn(): void;
    /**
     * @stability stable
     */
    get kmsKeyArnInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DynamodbTableTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#create DynamodbTable#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#delete DynamodbTable#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#update DynamodbTable#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function dynamodbTableTimeoutsToTerraform(struct?: DynamodbTableTimeoutsOutputReference | DynamodbTableTimeouts): any;
/**
 * @stability stable
 */
export declare class DynamodbTableTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DynamodbTableTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DynamodbTableTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DynamodbTableTtl {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#attribute_name DynamodbTable#attribute_name}.
     *
     * @stability stable
     */
    readonly attributeName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table#enabled DynamodbTable#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
}
export declare function dynamodbTableTtlToTerraform(struct?: DynamodbTableTtlOutputReference | DynamodbTableTtl): any;
/**
 * @stability stable
 */
export declare class DynamodbTableTtlOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DynamodbTableTtl | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DynamodbTableTtl | undefined);
    private _attributeName?;
    /**
     * @stability stable
     */
    get attributeName(): string;
    /**
     * @stability stable
     */
    set attributeName(value: string);
    /**
     * @stability stable
     */
    get attributeNameInput(): string | undefined;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table aws_dynamodb_table}.
 *
 * @stability stable
 */
export declare class DynamodbTable extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table aws_dynamodb_table} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DynamodbTableConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _billingMode?;
    /**
     * @stability stable
     */
    get billingMode(): string;
    /**
     * @stability stable
     */
    set billingMode(value: string);
    /**
     * @stability stable
     */
    resetBillingMode(): void;
    /**
     * @stability stable
     */
    get billingModeInput(): string | undefined;
    private _hashKey?;
    /**
     * @stability stable
     */
    get hashKey(): string;
    /**
     * @stability stable
     */
    set hashKey(value: string);
    /**
     * @stability stable
     */
    resetHashKey(): void;
    /**
     * @stability stable
     */
    get hashKeyInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _rangeKey?;
    /**
     * @stability stable
     */
    get rangeKey(): string;
    /**
     * @stability stable
     */
    set rangeKey(value: string);
    /**
     * @stability stable
     */
    resetRangeKey(): void;
    /**
     * @stability stable
     */
    get rangeKeyInput(): string | undefined;
    private _readCapacity?;
    /**
     * @stability stable
     */
    get readCapacity(): number;
    /**
     * @stability stable
     */
    set readCapacity(value: number);
    /**
     * @stability stable
     */
    resetReadCapacity(): void;
    /**
     * @stability stable
     */
    get readCapacityInput(): number | undefined;
    private _restoreDateTime?;
    /**
     * @stability stable
     */
    get restoreDateTime(): string;
    /**
     * @stability stable
     */
    set restoreDateTime(value: string);
    /**
     * @stability stable
     */
    resetRestoreDateTime(): void;
    /**
     * @stability stable
     */
    get restoreDateTimeInput(): string | undefined;
    private _restoreSourceName?;
    /**
     * @stability stable
     */
    get restoreSourceName(): string;
    /**
     * @stability stable
     */
    set restoreSourceName(value: string);
    /**
     * @stability stable
     */
    resetRestoreSourceName(): void;
    /**
     * @stability stable
     */
    get restoreSourceNameInput(): string | undefined;
    private _restoreToLatestTime?;
    /**
     * @stability stable
     */
    get restoreToLatestTime(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set restoreToLatestTime(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRestoreToLatestTime(): void;
    /**
     * @stability stable
     */
    get restoreToLatestTimeInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get streamArn(): string;
    private _streamEnabled?;
    /**
     * @stability stable
     */
    get streamEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set streamEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetStreamEnabled(): void;
    /**
     * @stability stable
     */
    get streamEnabledInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get streamLabel(): string;
    private _streamViewType?;
    /**
     * @stability stable
     */
    get streamViewType(): string;
    /**
     * @stability stable
     */
    set streamViewType(value: string);
    /**
     * @stability stable
     */
    resetStreamViewType(): void;
    /**
     * @stability stable
     */
    get streamViewTypeInput(): string | undefined;
    private _tableClass?;
    /**
     * @stability stable
     */
    get tableClass(): string;
    /**
     * @stability stable
     */
    set tableClass(value: string);
    /**
     * @stability stable
     */
    resetTableClass(): void;
    /**
     * @stability stable
     */
    get tableClassInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _writeCapacity?;
    /**
     * @stability stable
     */
    get writeCapacity(): number;
    /**
     * @stability stable
     */
    set writeCapacity(value: number);
    /**
     * @stability stable
     */
    resetWriteCapacity(): void;
    /**
     * @stability stable
     */
    get writeCapacityInput(): number | undefined;
    private _attribute?;
    /**
     * @stability stable
     */
    get attribute(): DynamodbTableAttribute[];
    /**
     * @stability stable
     */
    set attribute(value: DynamodbTableAttribute[]);
    /**
     * @stability stable
     */
    resetAttribute(): void;
    /**
     * @stability stable
     */
    get attributeInput(): DynamodbTableAttribute[] | undefined;
    private _globalSecondaryIndex?;
    /**
     * @stability stable
     */
    get globalSecondaryIndex(): DynamodbTableGlobalSecondaryIndex[];
    /**
     * @stability stable
     */
    set globalSecondaryIndex(value: DynamodbTableGlobalSecondaryIndex[]);
    /**
     * @stability stable
     */
    resetGlobalSecondaryIndex(): void;
    /**
     * @stability stable
     */
    get globalSecondaryIndexInput(): DynamodbTableGlobalSecondaryIndex[] | undefined;
    private _localSecondaryIndex?;
    /**
     * @stability stable
     */
    get localSecondaryIndex(): DynamodbTableLocalSecondaryIndex[];
    /**
     * @stability stable
     */
    set localSecondaryIndex(value: DynamodbTableLocalSecondaryIndex[]);
    /**
     * @stability stable
     */
    resetLocalSecondaryIndex(): void;
    /**
     * @stability stable
     */
    get localSecondaryIndexInput(): DynamodbTableLocalSecondaryIndex[] | undefined;
    private _pointInTimeRecovery;
    /**
     * @stability stable
     */
    get pointInTimeRecovery(): DynamodbTablePointInTimeRecoveryOutputReference;
    /**
     * @stability stable
     */
    putPointInTimeRecovery(value: DynamodbTablePointInTimeRecovery): void;
    /**
     * @stability stable
     */
    resetPointInTimeRecovery(): void;
    /**
     * @stability stable
     */
    get pointInTimeRecoveryInput(): DynamodbTablePointInTimeRecovery | undefined;
    private _replica?;
    /**
     * @stability stable
     */
    get replica(): DynamodbTableReplica[];
    /**
     * @stability stable
     */
    set replica(value: DynamodbTableReplica[]);
    /**
     * @stability stable
     */
    resetReplica(): void;
    /**
     * @stability stable
     */
    get replicaInput(): DynamodbTableReplica[] | undefined;
    private _serverSideEncryption;
    /**
     * @stability stable
     */
    get serverSideEncryption(): DynamodbTableServerSideEncryptionOutputReference;
    /**
     * @stability stable
     */
    putServerSideEncryption(value: DynamodbTableServerSideEncryption): void;
    /**
     * @stability stable
     */
    resetServerSideEncryption(): void;
    /**
     * @stability stable
     */
    get serverSideEncryptionInput(): DynamodbTableServerSideEncryption | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): DynamodbTableTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: DynamodbTableTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DynamodbTableTimeouts | undefined;
    private _ttl;
    /**
     * @stability stable
     */
    get ttl(): DynamodbTableTtlOutputReference;
    /**
     * @stability stable
     */
    putTtl(value: DynamodbTableTtl): void;
    /**
     * @stability stable
     */
    resetTtl(): void;
    /**
     * @stability stable
     */
    get ttlInput(): DynamodbTableTtl | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
