import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS EC2.
 *
 * @stability stable
 */
export interface DataAwsInstanceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/instance#get_password_data DataAwsInstance#get_password_data}.
     *
     * @stability stable
     */
    readonly fetchPasswordData?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/instance#get_user_data DataAwsInstance#get_user_data}.
     *
     * @stability stable
     */
    readonly fetchUserData?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/instance#instance_id DataAwsInstance#instance_id}.
     *
     * @stability stable
     */
    readonly instanceId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/instance#instance_tags DataAwsInstance#instance_tags}.
     *
     * @stability stable
     */
    readonly instanceTags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/instance#tags DataAwsInstance#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * filter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/instance#filter DataAwsInstance#filter}
     *
     * @stability stable
     */
    readonly filter?: DataAwsInstanceFilter[];
}
/**
 * @stability stable
 */
export declare class DataAwsInstanceCreditSpecification extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get cpuCredits(): string;
}
/**
 * @stability stable
 */
export declare class DataAwsInstanceEbsBlockDevice extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get deleteOnTermination(): any;
    /**
     * @stability stable
     */
    get deviceName(): string;
    /**
     * @stability stable
     */
    get encrypted(): any;
    /**
     * @stability stable
     */
    get iops(): number;
    /**
     * @stability stable
     */
    get kmsKeyId(): string;
    /**
     * @stability stable
     */
    get snapshotId(): string;
    /**
     * @stability stable
     */
    get tags(): any;
    /**
     * @stability stable
     */
    get throughput(): number;
    /**
     * @stability stable
     */
    get volumeId(): string;
    /**
     * @stability stable
     */
    get volumeSize(): number;
    /**
     * @stability stable
     */
    get volumeType(): string;
}
/**
 * @stability stable
 */
export declare class DataAwsInstanceEnclaveOptions extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get enabled(): any;
}
/**
 * @stability stable
 */
export declare class DataAwsInstanceEphemeralBlockDevice extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get deviceName(): string;
    /**
     * @stability stable
     */
    get noDevice(): any;
    /**
     * @stability stable
     */
    get virtualName(): string;
}
/**
 * @stability stable
 */
export declare class DataAwsInstanceMetadataOptions extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get httpEndpoint(): string;
    /**
     * @stability stable
     */
    get httpPutResponseHopLimit(): number;
    /**
     * @stability stable
     */
    get httpTokens(): string;
    /**
     * @stability stable
     */
    get instanceMetadataTags(): string;
}
/**
 * @stability stable
 */
export declare class DataAwsInstanceRootBlockDevice extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get deleteOnTermination(): any;
    /**
     * @stability stable
     */
    get deviceName(): string;
    /**
     * @stability stable
     */
    get encrypted(): any;
    /**
     * @stability stable
     */
    get iops(): number;
    /**
     * @stability stable
     */
    get kmsKeyId(): string;
    /**
     * @stability stable
     */
    get tags(): any;
    /**
     * @stability stable
     */
    get throughput(): number;
    /**
     * @stability stable
     */
    get volumeId(): string;
    /**
     * @stability stable
     */
    get volumeSize(): number;
    /**
     * @stability stable
     */
    get volumeType(): string;
}
/**
 * @stability stable
 */
export interface DataAwsInstanceFilter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/instance#name DataAwsInstance#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/instance#values DataAwsInstance#values}.
     *
     * @stability stable
     */
    readonly values: string[];
}
export declare function dataAwsInstanceFilterToTerraform(struct?: DataAwsInstanceFilter): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/d/instance aws_instance}.
 *
 * @stability stable
 */
export declare class DataAwsInstance extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/d/instance aws_instance} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: DataAwsInstanceConfig);
    /**
     * @stability stable
     */
    get ami(): string;
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get associatePublicIpAddress(): any;
    /**
     * @stability stable
     */
    get availabilityZone(): string;
    /**
     * @stability stable
     */
    creditSpecification(index: string): DataAwsInstanceCreditSpecification;
    /**
     * @stability stable
     */
    get disableApiTermination(): any;
    /**
     * @stability stable
     */
    ebsBlockDevice(index: string): DataAwsInstanceEbsBlockDevice;
    /**
     * @stability stable
     */
    get ebsOptimized(): any;
    /**
     * @stability stable
     */
    enclaveOptions(index: string): DataAwsInstanceEnclaveOptions;
    /**
     * @stability stable
     */
    ephemeralBlockDevice(index: string): DataAwsInstanceEphemeralBlockDevice;
    private _getPasswordData?;
    /**
     * @stability stable
     */
    get fetchPasswordData(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set fetchPasswordData(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetFetchPasswordData(): void;
    /**
     * @stability stable
     */
    get fetchPasswordDataInput(): boolean | cdktf.IResolvable | undefined;
    private _getUserData?;
    /**
     * @stability stable
     */
    get fetchUserData(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set fetchUserData(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetFetchUserData(): void;
    /**
     * @stability stable
     */
    get fetchUserDataInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get hostId(): string;
    /**
     * @stability stable
     */
    get iamInstanceProfile(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _instanceId?;
    /**
     * @stability stable
     */
    get instanceId(): string;
    /**
     * @stability stable
     */
    set instanceId(value: string);
    /**
     * @stability stable
     */
    resetInstanceId(): void;
    /**
     * @stability stable
     */
    get instanceIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get instanceState(): string;
    private _instanceTags?;
    /**
     * @stability stable
     */
    get instanceTags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set instanceTags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetInstanceTags(): void;
    /**
     * @stability stable
     */
    get instanceTagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get instanceType(): string;
    /**
     * @stability stable
     */
    get ipv6Addresses(): string[];
    /**
     * @stability stable
     */
    get keyName(): string;
    /**
     * @stability stable
     */
    metadataOptions(index: string): DataAwsInstanceMetadataOptions;
    /**
     * @stability stable
     */
    get monitoring(): any;
    /**
     * @stability stable
     */
    get networkInterfaceId(): string;
    /**
     * @stability stable
     */
    get outpostArn(): string;
    /**
     * @stability stable
     */
    get passwordData(): string;
    /**
     * @stability stable
     */
    get placementGroup(): string;
    /**
     * @stability stable
     */
    get placementPartitionNumber(): number;
    /**
     * @stability stable
     */
    get privateDns(): string;
    /**
     * @stability stable
     */
    get privateIp(): string;
    /**
     * @stability stable
     */
    get publicDns(): string;
    /**
     * @stability stable
     */
    get publicIp(): string;
    /**
     * @stability stable
     */
    rootBlockDevice(index: string): DataAwsInstanceRootBlockDevice;
    /**
     * @stability stable
     */
    get secondaryPrivateIps(): string[];
    /**
     * @stability stable
     */
    get securityGroups(): string[];
    /**
     * @stability stable
     */
    get sourceDestCheck(): any;
    /**
     * @stability stable
     */
    get subnetId(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get tenancy(): string;
    /**
     * @stability stable
     */
    get userData(): string;
    /**
     * @stability stable
     */
    get userDataBase64(): string;
    /**
     * @stability stable
     */
    get vpcSecurityGroupIds(): string[];
    private _filter?;
    /**
     * @stability stable
     */
    get filter(): DataAwsInstanceFilter[];
    /**
     * @stability stable
     */
    set filter(value: DataAwsInstanceFilter[]);
    /**
     * @stability stable
     */
    resetFilter(): void;
    /**
     * @stability stable
     */
    get filterInput(): DataAwsInstanceFilter[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
