import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS EC2 Container Registry.
 *
 * @stability stable
 */
export interface EcrpublicRepositoryConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository#force_destroy EcrpublicRepository#force_destroy}.
     *
     * @stability stable
     */
    readonly forceDestroy?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository#repository_name EcrpublicRepository#repository_name}.
     *
     * @stability stable
     */
    readonly repositoryName: string;
    /**
     * catalog_data block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository#catalog_data EcrpublicRepository#catalog_data}
     *
     * @stability stable
     */
    readonly catalogData?: EcrpublicRepositoryCatalogData;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository#timeouts EcrpublicRepository#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: EcrpublicRepositoryTimeouts;
}
/**
 * @stability stable
 */
export interface EcrpublicRepositoryCatalogData {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository#about_text EcrpublicRepository#about_text}.
     *
     * @stability stable
     */
    readonly aboutText?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository#architectures EcrpublicRepository#architectures}.
     *
     * @stability stable
     */
    readonly architectures?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository#description EcrpublicRepository#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository#logo_image_blob EcrpublicRepository#logo_image_blob}.
     *
     * @stability stable
     */
    readonly logoImageBlob?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository#operating_systems EcrpublicRepository#operating_systems}.
     *
     * @stability stable
     */
    readonly operatingSystems?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository#usage_text EcrpublicRepository#usage_text}.
     *
     * @stability stable
     */
    readonly usageText?: string;
}
export declare function ecrpublicRepositoryCatalogDataToTerraform(struct?: EcrpublicRepositoryCatalogDataOutputReference | EcrpublicRepositoryCatalogData): any;
/**
 * @stability stable
 */
export declare class EcrpublicRepositoryCatalogDataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EcrpublicRepositoryCatalogData | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EcrpublicRepositoryCatalogData | undefined);
    private _aboutText?;
    /**
     * @stability stable
     */
    get aboutText(): string;
    /**
     * @stability stable
     */
    set aboutText(value: string);
    /**
     * @stability stable
     */
    resetAboutText(): void;
    /**
     * @stability stable
     */
    get aboutTextInput(): string | undefined;
    private _architectures?;
    /**
     * @stability stable
     */
    get architectures(): string[];
    /**
     * @stability stable
     */
    set architectures(value: string[]);
    /**
     * @stability stable
     */
    resetArchitectures(): void;
    /**
     * @stability stable
     */
    get architecturesInput(): string[] | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _logoImageBlob?;
    /**
     * @stability stable
     */
    get logoImageBlob(): string;
    /**
     * @stability stable
     */
    set logoImageBlob(value: string);
    /**
     * @stability stable
     */
    resetLogoImageBlob(): void;
    /**
     * @stability stable
     */
    get logoImageBlobInput(): string | undefined;
    private _operatingSystems?;
    /**
     * @stability stable
     */
    get operatingSystems(): string[];
    /**
     * @stability stable
     */
    set operatingSystems(value: string[]);
    /**
     * @stability stable
     */
    resetOperatingSystems(): void;
    /**
     * @stability stable
     */
    get operatingSystemsInput(): string[] | undefined;
    private _usageText?;
    /**
     * @stability stable
     */
    get usageText(): string;
    /**
     * @stability stable
     */
    set usageText(value: string);
    /**
     * @stability stable
     */
    resetUsageText(): void;
    /**
     * @stability stable
     */
    get usageTextInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface EcrpublicRepositoryTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository#delete EcrpublicRepository#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
}
export declare function ecrpublicRepositoryTimeoutsToTerraform(struct?: EcrpublicRepositoryTimeoutsOutputReference | EcrpublicRepositoryTimeouts): any;
/**
 * @stability stable
 */
export declare class EcrpublicRepositoryTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EcrpublicRepositoryTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EcrpublicRepositoryTimeouts | undefined);
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository aws_ecrpublic_repository}.
 *
 * @stability stable
 */
export declare class EcrpublicRepository extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository aws_ecrpublic_repository} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EcrpublicRepositoryConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _forceDestroy?;
    /**
     * @stability stable
     */
    get forceDestroy(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set forceDestroy(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetForceDestroy(): void;
    /**
     * @stability stable
     */
    get forceDestroyInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get registryId(): string;
    private _repositoryName?;
    /**
     * @stability stable
     */
    get repositoryName(): string;
    /**
     * @stability stable
     */
    set repositoryName(value: string);
    /**
     * @stability stable
     */
    get repositoryNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get repositoryUri(): string;
    private _catalogData;
    /**
     * @stability stable
     */
    get catalogData(): EcrpublicRepositoryCatalogDataOutputReference;
    /**
     * @stability stable
     */
    putCatalogData(value: EcrpublicRepositoryCatalogData): void;
    /**
     * @stability stable
     */
    resetCatalogData(): void;
    /**
     * @stability stable
     */
    get catalogDataInput(): EcrpublicRepositoryCatalogData | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): EcrpublicRepositoryTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: EcrpublicRepositoryTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): EcrpublicRepositoryTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
