import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS EC2 Container Service.
 *
 * @stability stable
 */
export interface EcsCapacityProviderConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#name EcsCapacityProvider#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#tags EcsCapacityProvider#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#tags_all EcsCapacityProvider#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * auto_scaling_group_provider block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#auto_scaling_group_provider EcsCapacityProvider#auto_scaling_group_provider}
     *
     * @stability stable
     */
    readonly autoScalingGroupProvider: EcsCapacityProviderAutoScalingGroupProvider;
}
/**
 * @stability stable
 */
export interface EcsCapacityProviderAutoScalingGroupProviderManagedScaling {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#instance_warmup_period EcsCapacityProvider#instance_warmup_period}.
     *
     * @stability stable
     */
    readonly instanceWarmupPeriod?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#maximum_scaling_step_size EcsCapacityProvider#maximum_scaling_step_size}.
     *
     * @stability stable
     */
    readonly maximumScalingStepSize?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#minimum_scaling_step_size EcsCapacityProvider#minimum_scaling_step_size}.
     *
     * @stability stable
     */
    readonly minimumScalingStepSize?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#status EcsCapacityProvider#status}.
     *
     * @stability stable
     */
    readonly status?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#target_capacity EcsCapacityProvider#target_capacity}.
     *
     * @stability stable
     */
    readonly targetCapacity?: number;
}
export declare function ecsCapacityProviderAutoScalingGroupProviderManagedScalingToTerraform(struct?: EcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference | EcsCapacityProviderAutoScalingGroupProviderManagedScaling): any;
/**
 * @stability stable
 */
export declare class EcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EcsCapacityProviderAutoScalingGroupProviderManagedScaling | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EcsCapacityProviderAutoScalingGroupProviderManagedScaling | undefined);
    private _instanceWarmupPeriod?;
    /**
     * @stability stable
     */
    get instanceWarmupPeriod(): number;
    /**
     * @stability stable
     */
    set instanceWarmupPeriod(value: number);
    /**
     * @stability stable
     */
    resetInstanceWarmupPeriod(): void;
    /**
     * @stability stable
     */
    get instanceWarmupPeriodInput(): number | undefined;
    private _maximumScalingStepSize?;
    /**
     * @stability stable
     */
    get maximumScalingStepSize(): number;
    /**
     * @stability stable
     */
    set maximumScalingStepSize(value: number);
    /**
     * @stability stable
     */
    resetMaximumScalingStepSize(): void;
    /**
     * @stability stable
     */
    get maximumScalingStepSizeInput(): number | undefined;
    private _minimumScalingStepSize?;
    /**
     * @stability stable
     */
    get minimumScalingStepSize(): number;
    /**
     * @stability stable
     */
    set minimumScalingStepSize(value: number);
    /**
     * @stability stable
     */
    resetMinimumScalingStepSize(): void;
    /**
     * @stability stable
     */
    get minimumScalingStepSizeInput(): number | undefined;
    private _status?;
    /**
     * @stability stable
     */
    get status(): string;
    /**
     * @stability stable
     */
    set status(value: string);
    /**
     * @stability stable
     */
    resetStatus(): void;
    /**
     * @stability stable
     */
    get statusInput(): string | undefined;
    private _targetCapacity?;
    /**
     * @stability stable
     */
    get targetCapacity(): number;
    /**
     * @stability stable
     */
    set targetCapacity(value: number);
    /**
     * @stability stable
     */
    resetTargetCapacity(): void;
    /**
     * @stability stable
     */
    get targetCapacityInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface EcsCapacityProviderAutoScalingGroupProvider {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#auto_scaling_group_arn EcsCapacityProvider#auto_scaling_group_arn}.
     *
     * @stability stable
     */
    readonly autoScalingGroupArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#managed_termination_protection EcsCapacityProvider#managed_termination_protection}.
     *
     * @stability stable
     */
    readonly managedTerminationProtection?: string;
    /**
     * managed_scaling block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#managed_scaling EcsCapacityProvider#managed_scaling}
     *
     * @stability stable
     */
    readonly managedScaling?: EcsCapacityProviderAutoScalingGroupProviderManagedScaling;
}
export declare function ecsCapacityProviderAutoScalingGroupProviderToTerraform(struct?: EcsCapacityProviderAutoScalingGroupProviderOutputReference | EcsCapacityProviderAutoScalingGroupProvider): any;
/**
 * @stability stable
 */
export declare class EcsCapacityProviderAutoScalingGroupProviderOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EcsCapacityProviderAutoScalingGroupProvider | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EcsCapacityProviderAutoScalingGroupProvider | undefined);
    private _autoScalingGroupArn?;
    /**
     * @stability stable
     */
    get autoScalingGroupArn(): string;
    /**
     * @stability stable
     */
    set autoScalingGroupArn(value: string);
    /**
     * @stability stable
     */
    get autoScalingGroupArnInput(): string | undefined;
    private _managedTerminationProtection?;
    /**
     * @stability stable
     */
    get managedTerminationProtection(): string;
    /**
     * @stability stable
     */
    set managedTerminationProtection(value: string);
    /**
     * @stability stable
     */
    resetManagedTerminationProtection(): void;
    /**
     * @stability stable
     */
    get managedTerminationProtectionInput(): string | undefined;
    private _managedScaling;
    /**
     * @stability stable
     */
    get managedScaling(): EcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference;
    /**
     * @stability stable
     */
    putManagedScaling(value: EcsCapacityProviderAutoScalingGroupProviderManagedScaling): void;
    /**
     * @stability stable
     */
    resetManagedScaling(): void;
    /**
     * @stability stable
     */
    get managedScalingInput(): EcsCapacityProviderAutoScalingGroupProviderManagedScaling | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider aws_ecs_capacity_provider}.
 *
 * @stability stable
 */
export declare class EcsCapacityProvider extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider aws_ecs_capacity_provider} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EcsCapacityProviderConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _autoScalingGroupProvider;
    /**
     * @stability stable
     */
    get autoScalingGroupProvider(): EcsCapacityProviderAutoScalingGroupProviderOutputReference;
    /**
     * @stability stable
     */
    putAutoScalingGroupProvider(value: EcsCapacityProviderAutoScalingGroupProvider): void;
    /**
     * @stability stable
     */
    get autoScalingGroupProviderInput(): EcsCapacityProviderAutoScalingGroupProvider | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
