import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS EFS.
 *
 * @stability stable
 */
export interface EfsAccessPointConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#file_system_id EfsAccessPoint#file_system_id}.
     *
     * @stability stable
     */
    readonly fileSystemId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#tags EfsAccessPoint#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#tags_all EfsAccessPoint#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * posix_user block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#posix_user EfsAccessPoint#posix_user}
     *
     * @stability stable
     */
    readonly posixUser?: EfsAccessPointPosixUser;
    /**
     * root_directory block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#root_directory EfsAccessPoint#root_directory}
     *
     * @stability stable
     */
    readonly rootDirectory?: EfsAccessPointRootDirectory;
}
/**
 * @stability stable
 */
export interface EfsAccessPointPosixUser {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#gid EfsAccessPoint#gid}.
     *
     * @stability stable
     */
    readonly gid: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#secondary_gids EfsAccessPoint#secondary_gids}.
     *
     * @stability stable
     */
    readonly secondaryGids?: number[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#uid EfsAccessPoint#uid}.
     *
     * @stability stable
     */
    readonly uid: number;
}
export declare function efsAccessPointPosixUserToTerraform(struct?: EfsAccessPointPosixUserOutputReference | EfsAccessPointPosixUser): any;
/**
 * @stability stable
 */
export declare class EfsAccessPointPosixUserOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EfsAccessPointPosixUser | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EfsAccessPointPosixUser | undefined);
    private _gid?;
    /**
     * @stability stable
     */
    get gid(): number;
    /**
     * @stability stable
     */
    set gid(value: number);
    /**
     * @stability stable
     */
    get gidInput(): number | undefined;
    private _secondaryGids?;
    /**
     * @stability stable
     */
    get secondaryGids(): number[];
    /**
     * @stability stable
     */
    set secondaryGids(value: number[]);
    /**
     * @stability stable
     */
    resetSecondaryGids(): void;
    /**
     * @stability stable
     */
    get secondaryGidsInput(): number[] | undefined;
    private _uid?;
    /**
     * @stability stable
     */
    get uid(): number;
    /**
     * @stability stable
     */
    set uid(value: number);
    /**
     * @stability stable
     */
    get uidInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface EfsAccessPointRootDirectoryCreationInfo {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#owner_gid EfsAccessPoint#owner_gid}.
     *
     * @stability stable
     */
    readonly ownerGid: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#owner_uid EfsAccessPoint#owner_uid}.
     *
     * @stability stable
     */
    readonly ownerUid: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#permissions EfsAccessPoint#permissions}.
     *
     * @stability stable
     */
    readonly permissions: string;
}
export declare function efsAccessPointRootDirectoryCreationInfoToTerraform(struct?: EfsAccessPointRootDirectoryCreationInfoOutputReference | EfsAccessPointRootDirectoryCreationInfo): any;
/**
 * @stability stable
 */
export declare class EfsAccessPointRootDirectoryCreationInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EfsAccessPointRootDirectoryCreationInfo | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EfsAccessPointRootDirectoryCreationInfo | undefined);
    private _ownerGid?;
    /**
     * @stability stable
     */
    get ownerGid(): number;
    /**
     * @stability stable
     */
    set ownerGid(value: number);
    /**
     * @stability stable
     */
    get ownerGidInput(): number | undefined;
    private _ownerUid?;
    /**
     * @stability stable
     */
    get ownerUid(): number;
    /**
     * @stability stable
     */
    set ownerUid(value: number);
    /**
     * @stability stable
     */
    get ownerUidInput(): number | undefined;
    private _permissions?;
    /**
     * @stability stable
     */
    get permissions(): string;
    /**
     * @stability stable
     */
    set permissions(value: string);
    /**
     * @stability stable
     */
    get permissionsInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface EfsAccessPointRootDirectory {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#path EfsAccessPoint#path}.
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * creation_info block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#creation_info EfsAccessPoint#creation_info}
     *
     * @stability stable
     */
    readonly creationInfo?: EfsAccessPointRootDirectoryCreationInfo;
}
export declare function efsAccessPointRootDirectoryToTerraform(struct?: EfsAccessPointRootDirectoryOutputReference | EfsAccessPointRootDirectory): any;
/**
 * @stability stable
 */
export declare class EfsAccessPointRootDirectoryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EfsAccessPointRootDirectory | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EfsAccessPointRootDirectory | undefined);
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _creationInfo;
    /**
     * @stability stable
     */
    get creationInfo(): EfsAccessPointRootDirectoryCreationInfoOutputReference;
    /**
     * @stability stable
     */
    putCreationInfo(value: EfsAccessPointRootDirectoryCreationInfo): void;
    /**
     * @stability stable
     */
    resetCreationInfo(): void;
    /**
     * @stability stable
     */
    get creationInfoInput(): EfsAccessPointRootDirectoryCreationInfo | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point aws_efs_access_point}.
 *
 * @stability stable
 */
export declare class EfsAccessPoint extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point aws_efs_access_point} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EfsAccessPointConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get fileSystemArn(): string;
    private _fileSystemId?;
    /**
     * @stability stable
     */
    get fileSystemId(): string;
    /**
     * @stability stable
     */
    set fileSystemId(value: string);
    /**
     * @stability stable
     */
    get fileSystemIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get ownerId(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _posixUser;
    /**
     * @stability stable
     */
    get posixUser(): EfsAccessPointPosixUserOutputReference;
    /**
     * @stability stable
     */
    putPosixUser(value: EfsAccessPointPosixUser): void;
    /**
     * @stability stable
     */
    resetPosixUser(): void;
    /**
     * @stability stable
     */
    get posixUserInput(): EfsAccessPointPosixUser | undefined;
    private _rootDirectory;
    /**
     * @stability stable
     */
    get rootDirectory(): EfsAccessPointRootDirectoryOutputReference;
    /**
     * @stability stable
     */
    putRootDirectory(value: EfsAccessPointRootDirectory): void;
    /**
     * @stability stable
     */
    resetRootDirectory(): void;
    /**
     * @stability stable
     */
    get rootDirectoryInput(): EfsAccessPointRootDirectory | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
