import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Elastic Kubernetes Service.
 *
 * @stability stable
 */
export interface EksClusterConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#enabled_cluster_log_types EksCluster#enabled_cluster_log_types}.
     *
     * @stability stable
     */
    readonly enabledClusterLogTypes?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#name EksCluster#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#role_arn EksCluster#role_arn}.
     *
     * @stability stable
     */
    readonly roleArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#tags EksCluster#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#tags_all EksCluster#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#version EksCluster#version}.
     *
     * @stability stable
     */
    readonly version?: string;
    /**
     * encryption_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#encryption_config EksCluster#encryption_config}
     *
     * @stability stable
     */
    readonly encryptionConfig?: EksClusterEncryptionConfig;
    /**
     * kubernetes_network_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#kubernetes_network_config EksCluster#kubernetes_network_config}
     *
     * @stability stable
     */
    readonly kubernetesNetworkConfig?: EksClusterKubernetesNetworkConfig;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#timeouts EksCluster#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: EksClusterTimeouts;
    /**
     * vpc_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#vpc_config EksCluster#vpc_config}
     *
     * @stability stable
     */
    readonly vpcConfig: EksClusterVpcConfig;
}
/**
 * @stability stable
 */
export declare class EksClusterCertificateAuthority extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get data(): string;
}
/**
 * @stability stable
 */
export declare class EksClusterIdentityOidc extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get issuer(): string;
}
/**
 * @stability stable
 */
export declare class EksClusterIdentity extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get oidc(): any;
}
/**
 * @stability stable
 */
export interface EksClusterEncryptionConfigProvider {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#key_arn EksCluster#key_arn}.
     *
     * @stability stable
     */
    readonly keyArn: string;
}
export declare function eksClusterEncryptionConfigProviderToTerraform(struct?: EksClusterEncryptionConfigProviderOutputReference | EksClusterEncryptionConfigProvider): any;
/**
 * @stability stable
 */
export declare class EksClusterEncryptionConfigProviderOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EksClusterEncryptionConfigProvider | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EksClusterEncryptionConfigProvider | undefined);
    private _keyArn?;
    /**
     * @stability stable
     */
    get keyArn(): string;
    /**
     * @stability stable
     */
    set keyArn(value: string);
    /**
     * @stability stable
     */
    get keyArnInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface EksClusterEncryptionConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#resources EksCluster#resources}.
     *
     * @stability stable
     */
    readonly resources: string[];
    /**
     * provider block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#provider EksCluster#provider}
     *
     * @stability stable
     */
    readonly provider: EksClusterEncryptionConfigProvider;
}
export declare function eksClusterEncryptionConfigToTerraform(struct?: EksClusterEncryptionConfigOutputReference | EksClusterEncryptionConfig): any;
/**
 * @stability stable
 */
export declare class EksClusterEncryptionConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EksClusterEncryptionConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EksClusterEncryptionConfig | undefined);
    private _resources?;
    /**
     * @stability stable
     */
    get resources(): string[];
    /**
     * @stability stable
     */
    set resources(value: string[]);
    /**
     * @stability stable
     */
    get resourcesInput(): string[] | undefined;
    private _provider;
    /**
     * @stability stable
     */
    get provider(): EksClusterEncryptionConfigProviderOutputReference;
    /**
     * @stability stable
     */
    putProvider(value: EksClusterEncryptionConfigProvider): void;
    /**
     * @stability stable
     */
    get providerInput(): EksClusterEncryptionConfigProvider | undefined;
}
/**
 * @stability stable
 */
export interface EksClusterKubernetesNetworkConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#ip_family EksCluster#ip_family}.
     *
     * @stability stable
     */
    readonly ipFamily?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#service_ipv4_cidr EksCluster#service_ipv4_cidr}.
     *
     * @stability stable
     */
    readonly serviceIpv4Cidr?: string;
}
export declare function eksClusterKubernetesNetworkConfigToTerraform(struct?: EksClusterKubernetesNetworkConfigOutputReference | EksClusterKubernetesNetworkConfig): any;
/**
 * @stability stable
 */
export declare class EksClusterKubernetesNetworkConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EksClusterKubernetesNetworkConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EksClusterKubernetesNetworkConfig | undefined);
    private _ipFamily?;
    /**
     * @stability stable
     */
    get ipFamily(): string;
    /**
     * @stability stable
     */
    set ipFamily(value: string);
    /**
     * @stability stable
     */
    resetIpFamily(): void;
    /**
     * @stability stable
     */
    get ipFamilyInput(): string | undefined;
    private _serviceIpv4Cidr?;
    /**
     * @stability stable
     */
    get serviceIpv4Cidr(): string;
    /**
     * @stability stable
     */
    set serviceIpv4Cidr(value: string);
    /**
     * @stability stable
     */
    resetServiceIpv4Cidr(): void;
    /**
     * @stability stable
     */
    get serviceIpv4CidrInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface EksClusterTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#create EksCluster#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#delete EksCluster#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#update EksCluster#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function eksClusterTimeoutsToTerraform(struct?: EksClusterTimeoutsOutputReference | EksClusterTimeouts): any;
/**
 * @stability stable
 */
export declare class EksClusterTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EksClusterTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EksClusterTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface EksClusterVpcConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#endpoint_private_access EksCluster#endpoint_private_access}.
     *
     * @stability stable
     */
    readonly endpointPrivateAccess?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#endpoint_public_access EksCluster#endpoint_public_access}.
     *
     * @stability stable
     */
    readonly endpointPublicAccess?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#public_access_cidrs EksCluster#public_access_cidrs}.
     *
     * @stability stable
     */
    readonly publicAccessCidrs?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#security_group_ids EksCluster#security_group_ids}.
     *
     * @stability stable
     */
    readonly securityGroupIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#subnet_ids EksCluster#subnet_ids}.
     *
     * @stability stable
     */
    readonly subnetIds: string[];
}
export declare function eksClusterVpcConfigToTerraform(struct?: EksClusterVpcConfigOutputReference | EksClusterVpcConfig): any;
/**
 * @stability stable
 */
export declare class EksClusterVpcConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EksClusterVpcConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EksClusterVpcConfig | undefined);
    private _endpointPrivateAccess?;
    /**
     * @stability stable
     */
    get endpointPrivateAccess(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set endpointPrivateAccess(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEndpointPrivateAccess(): void;
    /**
     * @stability stable
     */
    get endpointPrivateAccessInput(): boolean | cdktf.IResolvable | undefined;
    private _endpointPublicAccess?;
    /**
     * @stability stable
     */
    get endpointPublicAccess(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set endpointPublicAccess(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEndpointPublicAccess(): void;
    /**
     * @stability stable
     */
    get endpointPublicAccessInput(): boolean | cdktf.IResolvable | undefined;
    private _publicAccessCidrs?;
    /**
     * @stability stable
     */
    get publicAccessCidrs(): string[];
    /**
     * @stability stable
     */
    set publicAccessCidrs(value: string[]);
    /**
     * @stability stable
     */
    resetPublicAccessCidrs(): void;
    /**
     * @stability stable
     */
    get publicAccessCidrsInput(): string[] | undefined;
    private _securityGroupIds?;
    /**
     * @stability stable
     */
    get securityGroupIds(): string[];
    /**
     * @stability stable
     */
    set securityGroupIds(value: string[]);
    /**
     * @stability stable
     */
    resetSecurityGroupIds(): void;
    /**
     * @stability stable
     */
    get securityGroupIdsInput(): string[] | undefined;
    private _subnetIds?;
    /**
     * @stability stable
     */
    get subnetIds(): string[];
    /**
     * @stability stable
     */
    set subnetIds(value: string[]);
    /**
     * @stability stable
     */
    get subnetIdsInput(): string[] | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster aws_eks_cluster}.
 *
 * @stability stable
 */
export declare class EksCluster extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster aws_eks_cluster} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EksClusterConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    certificateAuthority(index: string): EksClusterCertificateAuthority;
    /**
     * @stability stable
     */
    get createdAt(): string;
    private _enabledClusterLogTypes?;
    /**
     * @stability stable
     */
    get enabledClusterLogTypes(): string[];
    /**
     * @stability stable
     */
    set enabledClusterLogTypes(value: string[]);
    /**
     * @stability stable
     */
    resetEnabledClusterLogTypes(): void;
    /**
     * @stability stable
     */
    get enabledClusterLogTypesInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get endpoint(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    identity(index: string): EksClusterIdentity;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get platformVersion(): string;
    private _roleArn?;
    /**
     * @stability stable
     */
    get roleArn(): string;
    /**
     * @stability stable
     */
    set roleArn(value: string);
    /**
     * @stability stable
     */
    get roleArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get status(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _version?;
    /**
     * @stability stable
     */
    get version(): string;
    /**
     * @stability stable
     */
    set version(value: string);
    /**
     * @stability stable
     */
    resetVersion(): void;
    /**
     * @stability stable
     */
    get versionInput(): string | undefined;
    private _encryptionConfig;
    /**
     * @stability stable
     */
    get encryptionConfig(): EksClusterEncryptionConfigOutputReference;
    /**
     * @stability stable
     */
    putEncryptionConfig(value: EksClusterEncryptionConfig): void;
    /**
     * @stability stable
     */
    resetEncryptionConfig(): void;
    /**
     * @stability stable
     */
    get encryptionConfigInput(): EksClusterEncryptionConfig | undefined;
    private _kubernetesNetworkConfig;
    /**
     * @stability stable
     */
    get kubernetesNetworkConfig(): EksClusterKubernetesNetworkConfigOutputReference;
    /**
     * @stability stable
     */
    putKubernetesNetworkConfig(value: EksClusterKubernetesNetworkConfig): void;
    /**
     * @stability stable
     */
    resetKubernetesNetworkConfig(): void;
    /**
     * @stability stable
     */
    get kubernetesNetworkConfigInput(): EksClusterKubernetesNetworkConfig | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): EksClusterTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: EksClusterTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): EksClusterTimeouts | undefined;
    private _vpcConfig;
    /**
     * @stability stable
     */
    get vpcConfig(): EksClusterVpcConfigOutputReference;
    /**
     * @stability stable
     */
    putVpcConfig(value: EksClusterVpcConfig): void;
    /**
     * @stability stable
     */
    get vpcConfigInput(): EksClusterVpcConfig | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
