import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Elastic Load Balancer.
 *
 * @stability stable
 */
export interface LbListenerRuleConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#listener_arn LbListenerRule#listener_arn}.
     *
     * @stability stable
     */
    readonly listenerArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#priority LbListenerRule#priority}.
     *
     * @stability stable
     */
    readonly priority?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#tags LbListenerRule#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#tags_all LbListenerRule#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * action block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#action LbListenerRule#action}
     *
     * @stability stable
     */
    readonly action: LbListenerRuleAction[];
    /**
     * condition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#condition LbListenerRule#condition}
     *
     * @stability stable
     */
    readonly condition: LbListenerRuleCondition[];
}
/**
 * @stability stable
 */
export interface LbListenerRuleActionAuthenticateCognito {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#authentication_request_extra_params LbListenerRule#authentication_request_extra_params}.
     *
     * @stability stable
     */
    readonly authenticationRequestExtraParams?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#on_unauthenticated_request LbListenerRule#on_unauthenticated_request}.
     *
     * @stability stable
     */
    readonly onUnauthenticatedRequest?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#scope LbListenerRule#scope}.
     *
     * @stability stable
     */
    readonly scope?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#session_cookie_name LbListenerRule#session_cookie_name}.
     *
     * @stability stable
     */
    readonly sessionCookieName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#session_timeout LbListenerRule#session_timeout}.
     *
     * @stability stable
     */
    readonly sessionTimeout?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#user_pool_arn LbListenerRule#user_pool_arn}.
     *
     * @stability stable
     */
    readonly userPoolArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#user_pool_client_id LbListenerRule#user_pool_client_id}.
     *
     * @stability stable
     */
    readonly userPoolClientId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#user_pool_domain LbListenerRule#user_pool_domain}.
     *
     * @stability stable
     */
    readonly userPoolDomain: string;
}
export declare function lbListenerRuleActionAuthenticateCognitoToTerraform(struct?: LbListenerRuleActionAuthenticateCognitoOutputReference | LbListenerRuleActionAuthenticateCognito): any;
/**
 * @stability stable
 */
export declare class LbListenerRuleActionAuthenticateCognitoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerRuleActionAuthenticateCognito | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerRuleActionAuthenticateCognito | undefined);
    private _authenticationRequestExtraParams?;
    /**
     * @stability stable
     */
    get authenticationRequestExtraParams(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set authenticationRequestExtraParams(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAuthenticationRequestExtraParams(): void;
    /**
     * @stability stable
     */
    get authenticationRequestExtraParamsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _onUnauthenticatedRequest?;
    /**
     * @stability stable
     */
    get onUnauthenticatedRequest(): string;
    /**
     * @stability stable
     */
    set onUnauthenticatedRequest(value: string);
    /**
     * @stability stable
     */
    resetOnUnauthenticatedRequest(): void;
    /**
     * @stability stable
     */
    get onUnauthenticatedRequestInput(): string | undefined;
    private _scope?;
    /**
     * @stability stable
     */
    get scope(): string;
    /**
     * @stability stable
     */
    set scope(value: string);
    /**
     * @stability stable
     */
    resetScope(): void;
    /**
     * @stability stable
     */
    get scopeInput(): string | undefined;
    private _sessionCookieName?;
    /**
     * @stability stable
     */
    get sessionCookieName(): string;
    /**
     * @stability stable
     */
    set sessionCookieName(value: string);
    /**
     * @stability stable
     */
    resetSessionCookieName(): void;
    /**
     * @stability stable
     */
    get sessionCookieNameInput(): string | undefined;
    private _sessionTimeout?;
    /**
     * @stability stable
     */
    get sessionTimeout(): number;
    /**
     * @stability stable
     */
    set sessionTimeout(value: number);
    /**
     * @stability stable
     */
    resetSessionTimeout(): void;
    /**
     * @stability stable
     */
    get sessionTimeoutInput(): number | undefined;
    private _userPoolArn?;
    /**
     * @stability stable
     */
    get userPoolArn(): string;
    /**
     * @stability stable
     */
    set userPoolArn(value: string);
    /**
     * @stability stable
     */
    get userPoolArnInput(): string | undefined;
    private _userPoolClientId?;
    /**
     * @stability stable
     */
    get userPoolClientId(): string;
    /**
     * @stability stable
     */
    set userPoolClientId(value: string);
    /**
     * @stability stable
     */
    get userPoolClientIdInput(): string | undefined;
    private _userPoolDomain?;
    /**
     * @stability stable
     */
    get userPoolDomain(): string;
    /**
     * @stability stable
     */
    set userPoolDomain(value: string);
    /**
     * @stability stable
     */
    get userPoolDomainInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface LbListenerRuleActionAuthenticateOidc {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#authentication_request_extra_params LbListenerRule#authentication_request_extra_params}.
     *
     * @stability stable
     */
    readonly authenticationRequestExtraParams?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#authorization_endpoint LbListenerRule#authorization_endpoint}.
     *
     * @stability stable
     */
    readonly authorizationEndpoint: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#client_id LbListenerRule#client_id}.
     *
     * @stability stable
     */
    readonly clientId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#client_secret LbListenerRule#client_secret}.
     *
     * @stability stable
     */
    readonly clientSecret: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#issuer LbListenerRule#issuer}.
     *
     * @stability stable
     */
    readonly issuer: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#on_unauthenticated_request LbListenerRule#on_unauthenticated_request}.
     *
     * @stability stable
     */
    readonly onUnauthenticatedRequest?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#scope LbListenerRule#scope}.
     *
     * @stability stable
     */
    readonly scope?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#session_cookie_name LbListenerRule#session_cookie_name}.
     *
     * @stability stable
     */
    readonly sessionCookieName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#session_timeout LbListenerRule#session_timeout}.
     *
     * @stability stable
     */
    readonly sessionTimeout?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#token_endpoint LbListenerRule#token_endpoint}.
     *
     * @stability stable
     */
    readonly tokenEndpoint: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#user_info_endpoint LbListenerRule#user_info_endpoint}.
     *
     * @stability stable
     */
    readonly userInfoEndpoint: string;
}
export declare function lbListenerRuleActionAuthenticateOidcToTerraform(struct?: LbListenerRuleActionAuthenticateOidcOutputReference | LbListenerRuleActionAuthenticateOidc): any;
/**
 * @stability stable
 */
export declare class LbListenerRuleActionAuthenticateOidcOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerRuleActionAuthenticateOidc | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerRuleActionAuthenticateOidc | undefined);
    private _authenticationRequestExtraParams?;
    /**
     * @stability stable
     */
    get authenticationRequestExtraParams(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set authenticationRequestExtraParams(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAuthenticationRequestExtraParams(): void;
    /**
     * @stability stable
     */
    get authenticationRequestExtraParamsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _authorizationEndpoint?;
    /**
     * @stability stable
     */
    get authorizationEndpoint(): string;
    /**
     * @stability stable
     */
    set authorizationEndpoint(value: string);
    /**
     * @stability stable
     */
    get authorizationEndpointInput(): string | undefined;
    private _clientId?;
    /**
     * @stability stable
     */
    get clientId(): string;
    /**
     * @stability stable
     */
    set clientId(value: string);
    /**
     * @stability stable
     */
    get clientIdInput(): string | undefined;
    private _clientSecret?;
    /**
     * @stability stable
     */
    get clientSecret(): string;
    /**
     * @stability stable
     */
    set clientSecret(value: string);
    /**
     * @stability stable
     */
    get clientSecretInput(): string | undefined;
    private _issuer?;
    /**
     * @stability stable
     */
    get issuer(): string;
    /**
     * @stability stable
     */
    set issuer(value: string);
    /**
     * @stability stable
     */
    get issuerInput(): string | undefined;
    private _onUnauthenticatedRequest?;
    /**
     * @stability stable
     */
    get onUnauthenticatedRequest(): string;
    /**
     * @stability stable
     */
    set onUnauthenticatedRequest(value: string);
    /**
     * @stability stable
     */
    resetOnUnauthenticatedRequest(): void;
    /**
     * @stability stable
     */
    get onUnauthenticatedRequestInput(): string | undefined;
    private _scope?;
    /**
     * @stability stable
     */
    get scope(): string;
    /**
     * @stability stable
     */
    set scope(value: string);
    /**
     * @stability stable
     */
    resetScope(): void;
    /**
     * @stability stable
     */
    get scopeInput(): string | undefined;
    private _sessionCookieName?;
    /**
     * @stability stable
     */
    get sessionCookieName(): string;
    /**
     * @stability stable
     */
    set sessionCookieName(value: string);
    /**
     * @stability stable
     */
    resetSessionCookieName(): void;
    /**
     * @stability stable
     */
    get sessionCookieNameInput(): string | undefined;
    private _sessionTimeout?;
    /**
     * @stability stable
     */
    get sessionTimeout(): number;
    /**
     * @stability stable
     */
    set sessionTimeout(value: number);
    /**
     * @stability stable
     */
    resetSessionTimeout(): void;
    /**
     * @stability stable
     */
    get sessionTimeoutInput(): number | undefined;
    private _tokenEndpoint?;
    /**
     * @stability stable
     */
    get tokenEndpoint(): string;
    /**
     * @stability stable
     */
    set tokenEndpoint(value: string);
    /**
     * @stability stable
     */
    get tokenEndpointInput(): string | undefined;
    private _userInfoEndpoint?;
    /**
     * @stability stable
     */
    get userInfoEndpoint(): string;
    /**
     * @stability stable
     */
    set userInfoEndpoint(value: string);
    /**
     * @stability stable
     */
    get userInfoEndpointInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface LbListenerRuleActionFixedResponse {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#content_type LbListenerRule#content_type}.
     *
     * @stability stable
     */
    readonly contentType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#message_body LbListenerRule#message_body}.
     *
     * @stability stable
     */
    readonly messageBody?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#status_code LbListenerRule#status_code}.
     *
     * @stability stable
     */
    readonly statusCode?: string;
}
export declare function lbListenerRuleActionFixedResponseToTerraform(struct?: LbListenerRuleActionFixedResponseOutputReference | LbListenerRuleActionFixedResponse): any;
/**
 * @stability stable
 */
export declare class LbListenerRuleActionFixedResponseOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerRuleActionFixedResponse | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerRuleActionFixedResponse | undefined);
    private _contentType?;
    /**
     * @stability stable
     */
    get contentType(): string;
    /**
     * @stability stable
     */
    set contentType(value: string);
    /**
     * @stability stable
     */
    get contentTypeInput(): string | undefined;
    private _messageBody?;
    /**
     * @stability stable
     */
    get messageBody(): string;
    /**
     * @stability stable
     */
    set messageBody(value: string);
    /**
     * @stability stable
     */
    resetMessageBody(): void;
    /**
     * @stability stable
     */
    get messageBodyInput(): string | undefined;
    private _statusCode?;
    /**
     * @stability stable
     */
    get statusCode(): string;
    /**
     * @stability stable
     */
    set statusCode(value: string);
    /**
     * @stability stable
     */
    resetStatusCode(): void;
    /**
     * @stability stable
     */
    get statusCodeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface LbListenerRuleActionForwardStickiness {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#duration LbListenerRule#duration}.
     *
     * @stability stable
     */
    readonly duration: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#enabled LbListenerRule#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
}
export declare function lbListenerRuleActionForwardStickinessToTerraform(struct?: LbListenerRuleActionForwardStickinessOutputReference | LbListenerRuleActionForwardStickiness): any;
/**
 * @stability stable
 */
export declare class LbListenerRuleActionForwardStickinessOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerRuleActionForwardStickiness | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerRuleActionForwardStickiness | undefined);
    private _duration?;
    /**
     * @stability stable
     */
    get duration(): number;
    /**
     * @stability stable
     */
    set duration(value: number);
    /**
     * @stability stable
     */
    get durationInput(): number | undefined;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface LbListenerRuleActionForwardTargetGroup {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#arn LbListenerRule#arn}.
     *
     * @stability stable
     */
    readonly arn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#weight LbListenerRule#weight}.
     *
     * @stability stable
     */
    readonly weight?: number;
}
export declare function lbListenerRuleActionForwardTargetGroupToTerraform(struct?: LbListenerRuleActionForwardTargetGroup): any;
/**
 * @stability stable
 */
export interface LbListenerRuleActionForward {
    /**
     * stickiness block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#stickiness LbListenerRule#stickiness}
     *
     * @stability stable
     */
    readonly stickiness?: LbListenerRuleActionForwardStickiness;
    /**
     * target_group block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#target_group LbListenerRule#target_group}
     *
     * @stability stable
     */
    readonly targetGroup: LbListenerRuleActionForwardTargetGroup[];
}
export declare function lbListenerRuleActionForwardToTerraform(struct?: LbListenerRuleActionForwardOutputReference | LbListenerRuleActionForward): any;
/**
 * @stability stable
 */
export declare class LbListenerRuleActionForwardOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerRuleActionForward | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerRuleActionForward | undefined);
    private _stickiness;
    /**
     * @stability stable
     */
    get stickiness(): LbListenerRuleActionForwardStickinessOutputReference;
    /**
     * @stability stable
     */
    putStickiness(value: LbListenerRuleActionForwardStickiness): void;
    /**
     * @stability stable
     */
    resetStickiness(): void;
    /**
     * @stability stable
     */
    get stickinessInput(): LbListenerRuleActionForwardStickiness | undefined;
    private _targetGroup?;
    /**
     * @stability stable
     */
    get targetGroup(): LbListenerRuleActionForwardTargetGroup[];
    /**
     * @stability stable
     */
    set targetGroup(value: LbListenerRuleActionForwardTargetGroup[]);
    /**
     * @stability stable
     */
    get targetGroupInput(): LbListenerRuleActionForwardTargetGroup[] | undefined;
}
/**
 * @stability stable
 */
export interface LbListenerRuleActionRedirect {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#host LbListenerRule#host}.
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#path LbListenerRule#path}.
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#port LbListenerRule#port}.
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#protocol LbListenerRule#protocol}.
     *
     * @stability stable
     */
    readonly protocol?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#query LbListenerRule#query}.
     *
     * @stability stable
     */
    readonly query?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#status_code LbListenerRule#status_code}.
     *
     * @stability stable
     */
    readonly statusCode: string;
}
export declare function lbListenerRuleActionRedirectToTerraform(struct?: LbListenerRuleActionRedirectOutputReference | LbListenerRuleActionRedirect): any;
/**
 * @stability stable
 */
export declare class LbListenerRuleActionRedirectOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerRuleActionRedirect | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerRuleActionRedirect | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _protocol?;
    /**
     * @stability stable
     */
    get protocol(): string;
    /**
     * @stability stable
     */
    set protocol(value: string);
    /**
     * @stability stable
     */
    resetProtocol(): void;
    /**
     * @stability stable
     */
    get protocolInput(): string | undefined;
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    resetQuery(): void;
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
    private _statusCode?;
    /**
     * @stability stable
     */
    get statusCode(): string;
    /**
     * @stability stable
     */
    set statusCode(value: string);
    /**
     * @stability stable
     */
    get statusCodeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface LbListenerRuleAction {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#order LbListenerRule#order}.
     *
     * @stability stable
     */
    readonly order?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#target_group_arn LbListenerRule#target_group_arn}.
     *
     * @stability stable
     */
    readonly targetGroupArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#type LbListenerRule#type}.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * authenticate_cognito block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#authenticate_cognito LbListenerRule#authenticate_cognito}
     *
     * @stability stable
     */
    readonly authenticateCognito?: LbListenerRuleActionAuthenticateCognito;
    /**
     * authenticate_oidc block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#authenticate_oidc LbListenerRule#authenticate_oidc}
     *
     * @stability stable
     */
    readonly authenticateOidc?: LbListenerRuleActionAuthenticateOidc;
    /**
     * fixed_response block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#fixed_response LbListenerRule#fixed_response}
     *
     * @stability stable
     */
    readonly fixedResponse?: LbListenerRuleActionFixedResponse;
    /**
     * forward block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#forward LbListenerRule#forward}
     *
     * @stability stable
     */
    readonly forward?: LbListenerRuleActionForward;
    /**
     * redirect block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#redirect LbListenerRule#redirect}
     *
     * @stability stable
     */
    readonly redirect?: LbListenerRuleActionRedirect;
}
export declare function lbListenerRuleActionToTerraform(struct?: LbListenerRuleAction): any;
/**
 * @stability stable
 */
export interface LbListenerRuleConditionHostHeader {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#values LbListenerRule#values}.
     *
     * @stability stable
     */
    readonly values: string[];
}
export declare function lbListenerRuleConditionHostHeaderToTerraform(struct?: LbListenerRuleConditionHostHeaderOutputReference | LbListenerRuleConditionHostHeader): any;
/**
 * @stability stable
 */
export declare class LbListenerRuleConditionHostHeaderOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerRuleConditionHostHeader | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerRuleConditionHostHeader | undefined);
    private _values?;
    /**
     * @stability stable
     */
    get values(): string[];
    /**
     * @stability stable
     */
    set values(value: string[]);
    /**
     * @stability stable
     */
    get valuesInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface LbListenerRuleConditionHttpHeader {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#http_header_name LbListenerRule#http_header_name}.
     *
     * @stability stable
     */
    readonly httpHeaderName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#values LbListenerRule#values}.
     *
     * @stability stable
     */
    readonly values: string[];
}
export declare function lbListenerRuleConditionHttpHeaderToTerraform(struct?: LbListenerRuleConditionHttpHeaderOutputReference | LbListenerRuleConditionHttpHeader): any;
/**
 * @stability stable
 */
export declare class LbListenerRuleConditionHttpHeaderOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerRuleConditionHttpHeader | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerRuleConditionHttpHeader | undefined);
    private _httpHeaderName?;
    /**
     * @stability stable
     */
    get httpHeaderName(): string;
    /**
     * @stability stable
     */
    set httpHeaderName(value: string);
    /**
     * @stability stable
     */
    get httpHeaderNameInput(): string | undefined;
    private _values?;
    /**
     * @stability stable
     */
    get values(): string[];
    /**
     * @stability stable
     */
    set values(value: string[]);
    /**
     * @stability stable
     */
    get valuesInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface LbListenerRuleConditionHttpRequestMethod {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#values LbListenerRule#values}.
     *
     * @stability stable
     */
    readonly values: string[];
}
export declare function lbListenerRuleConditionHttpRequestMethodToTerraform(struct?: LbListenerRuleConditionHttpRequestMethodOutputReference | LbListenerRuleConditionHttpRequestMethod): any;
/**
 * @stability stable
 */
export declare class LbListenerRuleConditionHttpRequestMethodOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerRuleConditionHttpRequestMethod | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerRuleConditionHttpRequestMethod | undefined);
    private _values?;
    /**
     * @stability stable
     */
    get values(): string[];
    /**
     * @stability stable
     */
    set values(value: string[]);
    /**
     * @stability stable
     */
    get valuesInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface LbListenerRuleConditionPathPattern {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#values LbListenerRule#values}.
     *
     * @stability stable
     */
    readonly values: string[];
}
export declare function lbListenerRuleConditionPathPatternToTerraform(struct?: LbListenerRuleConditionPathPatternOutputReference | LbListenerRuleConditionPathPattern): any;
/**
 * @stability stable
 */
export declare class LbListenerRuleConditionPathPatternOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerRuleConditionPathPattern | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerRuleConditionPathPattern | undefined);
    private _values?;
    /**
     * @stability stable
     */
    get values(): string[];
    /**
     * @stability stable
     */
    set values(value: string[]);
    /**
     * @stability stable
     */
    get valuesInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface LbListenerRuleConditionQueryString {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#key LbListenerRule#key}.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#value LbListenerRule#value}.
     *
     * @stability stable
     */
    readonly value: string;
}
export declare function lbListenerRuleConditionQueryStringToTerraform(struct?: LbListenerRuleConditionQueryString): any;
/**
 * @stability stable
 */
export interface LbListenerRuleConditionSourceIp {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#values LbListenerRule#values}.
     *
     * @stability stable
     */
    readonly values: string[];
}
export declare function lbListenerRuleConditionSourceIpToTerraform(struct?: LbListenerRuleConditionSourceIpOutputReference | LbListenerRuleConditionSourceIp): any;
/**
 * @stability stable
 */
export declare class LbListenerRuleConditionSourceIpOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerRuleConditionSourceIp | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerRuleConditionSourceIp | undefined);
    private _values?;
    /**
     * @stability stable
     */
    get values(): string[];
    /**
     * @stability stable
     */
    set values(value: string[]);
    /**
     * @stability stable
     */
    get valuesInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface LbListenerRuleCondition {
    /**
     * host_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#host_header LbListenerRule#host_header}
     *
     * @stability stable
     */
    readonly hostHeader?: LbListenerRuleConditionHostHeader;
    /**
     * http_header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#http_header LbListenerRule#http_header}
     *
     * @stability stable
     */
    readonly httpHeader?: LbListenerRuleConditionHttpHeader;
    /**
     * http_request_method block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#http_request_method LbListenerRule#http_request_method}
     *
     * @stability stable
     */
    readonly httpRequestMethod?: LbListenerRuleConditionHttpRequestMethod;
    /**
     * path_pattern block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#path_pattern LbListenerRule#path_pattern}
     *
     * @stability stable
     */
    readonly pathPattern?: LbListenerRuleConditionPathPattern;
    /**
     * query_string block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#query_string LbListenerRule#query_string}
     *
     * @stability stable
     */
    readonly queryString?: LbListenerRuleConditionQueryString[];
    /**
     * source_ip block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule#source_ip LbListenerRule#source_ip}
     *
     * @stability stable
     */
    readonly sourceIp?: LbListenerRuleConditionSourceIp;
}
export declare function lbListenerRuleConditionToTerraform(struct?: LbListenerRuleCondition): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule aws_lb_listener_rule}.
 *
 * @stability stable
 */
export declare class LbListenerRule extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule aws_lb_listener_rule} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: LbListenerRuleConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _listenerArn?;
    /**
     * @stability stable
     */
    get listenerArn(): string;
    /**
     * @stability stable
     */
    set listenerArn(value: string);
    /**
     * @stability stable
     */
    get listenerArnInput(): string | undefined;
    private _priority?;
    /**
     * @stability stable
     */
    get priority(): number;
    /**
     * @stability stable
     */
    set priority(value: number);
    /**
     * @stability stable
     */
    resetPriority(): void;
    /**
     * @stability stable
     */
    get priorityInput(): number | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _action?;
    /**
     * @stability stable
     */
    get action(): LbListenerRuleAction[];
    /**
     * @stability stable
     */
    set action(value: LbListenerRuleAction[]);
    /**
     * @stability stable
     */
    get actionInput(): LbListenerRuleAction[] | undefined;
    private _condition?;
    /**
     * @stability stable
     */
    get condition(): LbListenerRuleCondition[];
    /**
     * @stability stable
     */
    set condition(value: LbListenerRuleCondition[]);
    /**
     * @stability stable
     */
    get conditionInput(): LbListenerRuleCondition[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
