import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Elastic Load Balancer.
 *
 * @stability stable
 */
export interface LbListenerConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#alpn_policy LbListener#alpn_policy}.
     *
     * @stability stable
     */
    readonly alpnPolicy?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#certificate_arn LbListener#certificate_arn}.
     *
     * @stability stable
     */
    readonly certificateArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#load_balancer_arn LbListener#load_balancer_arn}.
     *
     * @stability stable
     */
    readonly loadBalancerArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#port LbListener#port}.
     *
     * @stability stable
     */
    readonly port?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#protocol LbListener#protocol}.
     *
     * @stability stable
     */
    readonly protocol?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#ssl_policy LbListener#ssl_policy}.
     *
     * @stability stable
     */
    readonly sslPolicy?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#tags LbListener#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#tags_all LbListener#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * default_action block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#default_action LbListener#default_action}
     *
     * @stability stable
     */
    readonly defaultAction: LbListenerDefaultAction[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#timeouts LbListener#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: LbListenerTimeouts;
}
/**
 * @stability stable
 */
export interface LbListenerDefaultActionAuthenticateCognito {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#authentication_request_extra_params LbListener#authentication_request_extra_params}.
     *
     * @stability stable
     */
    readonly authenticationRequestExtraParams?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#on_unauthenticated_request LbListener#on_unauthenticated_request}.
     *
     * @stability stable
     */
    readonly onUnauthenticatedRequest?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#scope LbListener#scope}.
     *
     * @stability stable
     */
    readonly scope?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#session_cookie_name LbListener#session_cookie_name}.
     *
     * @stability stable
     */
    readonly sessionCookieName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#session_timeout LbListener#session_timeout}.
     *
     * @stability stable
     */
    readonly sessionTimeout?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#user_pool_arn LbListener#user_pool_arn}.
     *
     * @stability stable
     */
    readonly userPoolArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#user_pool_client_id LbListener#user_pool_client_id}.
     *
     * @stability stable
     */
    readonly userPoolClientId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#user_pool_domain LbListener#user_pool_domain}.
     *
     * @stability stable
     */
    readonly userPoolDomain: string;
}
export declare function lbListenerDefaultActionAuthenticateCognitoToTerraform(struct?: LbListenerDefaultActionAuthenticateCognitoOutputReference | LbListenerDefaultActionAuthenticateCognito): any;
/**
 * @stability stable
 */
export declare class LbListenerDefaultActionAuthenticateCognitoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerDefaultActionAuthenticateCognito | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerDefaultActionAuthenticateCognito | undefined);
    private _authenticationRequestExtraParams?;
    /**
     * @stability stable
     */
    get authenticationRequestExtraParams(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set authenticationRequestExtraParams(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAuthenticationRequestExtraParams(): void;
    /**
     * @stability stable
     */
    get authenticationRequestExtraParamsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _onUnauthenticatedRequest?;
    /**
     * @stability stable
     */
    get onUnauthenticatedRequest(): string;
    /**
     * @stability stable
     */
    set onUnauthenticatedRequest(value: string);
    /**
     * @stability stable
     */
    resetOnUnauthenticatedRequest(): void;
    /**
     * @stability stable
     */
    get onUnauthenticatedRequestInput(): string | undefined;
    private _scope?;
    /**
     * @stability stable
     */
    get scope(): string;
    /**
     * @stability stable
     */
    set scope(value: string);
    /**
     * @stability stable
     */
    resetScope(): void;
    /**
     * @stability stable
     */
    get scopeInput(): string | undefined;
    private _sessionCookieName?;
    /**
     * @stability stable
     */
    get sessionCookieName(): string;
    /**
     * @stability stable
     */
    set sessionCookieName(value: string);
    /**
     * @stability stable
     */
    resetSessionCookieName(): void;
    /**
     * @stability stable
     */
    get sessionCookieNameInput(): string | undefined;
    private _sessionTimeout?;
    /**
     * @stability stable
     */
    get sessionTimeout(): number;
    /**
     * @stability stable
     */
    set sessionTimeout(value: number);
    /**
     * @stability stable
     */
    resetSessionTimeout(): void;
    /**
     * @stability stable
     */
    get sessionTimeoutInput(): number | undefined;
    private _userPoolArn?;
    /**
     * @stability stable
     */
    get userPoolArn(): string;
    /**
     * @stability stable
     */
    set userPoolArn(value: string);
    /**
     * @stability stable
     */
    get userPoolArnInput(): string | undefined;
    private _userPoolClientId?;
    /**
     * @stability stable
     */
    get userPoolClientId(): string;
    /**
     * @stability stable
     */
    set userPoolClientId(value: string);
    /**
     * @stability stable
     */
    get userPoolClientIdInput(): string | undefined;
    private _userPoolDomain?;
    /**
     * @stability stable
     */
    get userPoolDomain(): string;
    /**
     * @stability stable
     */
    set userPoolDomain(value: string);
    /**
     * @stability stable
     */
    get userPoolDomainInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface LbListenerDefaultActionAuthenticateOidc {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#authentication_request_extra_params LbListener#authentication_request_extra_params}.
     *
     * @stability stable
     */
    readonly authenticationRequestExtraParams?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#authorization_endpoint LbListener#authorization_endpoint}.
     *
     * @stability stable
     */
    readonly authorizationEndpoint: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#client_id LbListener#client_id}.
     *
     * @stability stable
     */
    readonly clientId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#client_secret LbListener#client_secret}.
     *
     * @stability stable
     */
    readonly clientSecret: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#issuer LbListener#issuer}.
     *
     * @stability stable
     */
    readonly issuer: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#on_unauthenticated_request LbListener#on_unauthenticated_request}.
     *
     * @stability stable
     */
    readonly onUnauthenticatedRequest?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#scope LbListener#scope}.
     *
     * @stability stable
     */
    readonly scope?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#session_cookie_name LbListener#session_cookie_name}.
     *
     * @stability stable
     */
    readonly sessionCookieName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#session_timeout LbListener#session_timeout}.
     *
     * @stability stable
     */
    readonly sessionTimeout?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#token_endpoint LbListener#token_endpoint}.
     *
     * @stability stable
     */
    readonly tokenEndpoint: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#user_info_endpoint LbListener#user_info_endpoint}.
     *
     * @stability stable
     */
    readonly userInfoEndpoint: string;
}
export declare function lbListenerDefaultActionAuthenticateOidcToTerraform(struct?: LbListenerDefaultActionAuthenticateOidcOutputReference | LbListenerDefaultActionAuthenticateOidc): any;
/**
 * @stability stable
 */
export declare class LbListenerDefaultActionAuthenticateOidcOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerDefaultActionAuthenticateOidc | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerDefaultActionAuthenticateOidc | undefined);
    private _authenticationRequestExtraParams?;
    /**
     * @stability stable
     */
    get authenticationRequestExtraParams(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set authenticationRequestExtraParams(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAuthenticationRequestExtraParams(): void;
    /**
     * @stability stable
     */
    get authenticationRequestExtraParamsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _authorizationEndpoint?;
    /**
     * @stability stable
     */
    get authorizationEndpoint(): string;
    /**
     * @stability stable
     */
    set authorizationEndpoint(value: string);
    /**
     * @stability stable
     */
    get authorizationEndpointInput(): string | undefined;
    private _clientId?;
    /**
     * @stability stable
     */
    get clientId(): string;
    /**
     * @stability stable
     */
    set clientId(value: string);
    /**
     * @stability stable
     */
    get clientIdInput(): string | undefined;
    private _clientSecret?;
    /**
     * @stability stable
     */
    get clientSecret(): string;
    /**
     * @stability stable
     */
    set clientSecret(value: string);
    /**
     * @stability stable
     */
    get clientSecretInput(): string | undefined;
    private _issuer?;
    /**
     * @stability stable
     */
    get issuer(): string;
    /**
     * @stability stable
     */
    set issuer(value: string);
    /**
     * @stability stable
     */
    get issuerInput(): string | undefined;
    private _onUnauthenticatedRequest?;
    /**
     * @stability stable
     */
    get onUnauthenticatedRequest(): string;
    /**
     * @stability stable
     */
    set onUnauthenticatedRequest(value: string);
    /**
     * @stability stable
     */
    resetOnUnauthenticatedRequest(): void;
    /**
     * @stability stable
     */
    get onUnauthenticatedRequestInput(): string | undefined;
    private _scope?;
    /**
     * @stability stable
     */
    get scope(): string;
    /**
     * @stability stable
     */
    set scope(value: string);
    /**
     * @stability stable
     */
    resetScope(): void;
    /**
     * @stability stable
     */
    get scopeInput(): string | undefined;
    private _sessionCookieName?;
    /**
     * @stability stable
     */
    get sessionCookieName(): string;
    /**
     * @stability stable
     */
    set sessionCookieName(value: string);
    /**
     * @stability stable
     */
    resetSessionCookieName(): void;
    /**
     * @stability stable
     */
    get sessionCookieNameInput(): string | undefined;
    private _sessionTimeout?;
    /**
     * @stability stable
     */
    get sessionTimeout(): number;
    /**
     * @stability stable
     */
    set sessionTimeout(value: number);
    /**
     * @stability stable
     */
    resetSessionTimeout(): void;
    /**
     * @stability stable
     */
    get sessionTimeoutInput(): number | undefined;
    private _tokenEndpoint?;
    /**
     * @stability stable
     */
    get tokenEndpoint(): string;
    /**
     * @stability stable
     */
    set tokenEndpoint(value: string);
    /**
     * @stability stable
     */
    get tokenEndpointInput(): string | undefined;
    private _userInfoEndpoint?;
    /**
     * @stability stable
     */
    get userInfoEndpoint(): string;
    /**
     * @stability stable
     */
    set userInfoEndpoint(value: string);
    /**
     * @stability stable
     */
    get userInfoEndpointInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface LbListenerDefaultActionFixedResponse {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#content_type LbListener#content_type}.
     *
     * @stability stable
     */
    readonly contentType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#message_body LbListener#message_body}.
     *
     * @stability stable
     */
    readonly messageBody?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#status_code LbListener#status_code}.
     *
     * @stability stable
     */
    readonly statusCode?: string;
}
export declare function lbListenerDefaultActionFixedResponseToTerraform(struct?: LbListenerDefaultActionFixedResponseOutputReference | LbListenerDefaultActionFixedResponse): any;
/**
 * @stability stable
 */
export declare class LbListenerDefaultActionFixedResponseOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerDefaultActionFixedResponse | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerDefaultActionFixedResponse | undefined);
    private _contentType?;
    /**
     * @stability stable
     */
    get contentType(): string;
    /**
     * @stability stable
     */
    set contentType(value: string);
    /**
     * @stability stable
     */
    get contentTypeInput(): string | undefined;
    private _messageBody?;
    /**
     * @stability stable
     */
    get messageBody(): string;
    /**
     * @stability stable
     */
    set messageBody(value: string);
    /**
     * @stability stable
     */
    resetMessageBody(): void;
    /**
     * @stability stable
     */
    get messageBodyInput(): string | undefined;
    private _statusCode?;
    /**
     * @stability stable
     */
    get statusCode(): string;
    /**
     * @stability stable
     */
    set statusCode(value: string);
    /**
     * @stability stable
     */
    resetStatusCode(): void;
    /**
     * @stability stable
     */
    get statusCodeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface LbListenerDefaultActionForwardStickiness {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#duration LbListener#duration}.
     *
     * @stability stable
     */
    readonly duration: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#enabled LbListener#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
}
export declare function lbListenerDefaultActionForwardStickinessToTerraform(struct?: LbListenerDefaultActionForwardStickinessOutputReference | LbListenerDefaultActionForwardStickiness): any;
/**
 * @stability stable
 */
export declare class LbListenerDefaultActionForwardStickinessOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerDefaultActionForwardStickiness | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerDefaultActionForwardStickiness | undefined);
    private _duration?;
    /**
     * @stability stable
     */
    get duration(): number;
    /**
     * @stability stable
     */
    set duration(value: number);
    /**
     * @stability stable
     */
    get durationInput(): number | undefined;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface LbListenerDefaultActionForwardTargetGroup {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#arn LbListener#arn}.
     *
     * @stability stable
     */
    readonly arn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#weight LbListener#weight}.
     *
     * @stability stable
     */
    readonly weight?: number;
}
export declare function lbListenerDefaultActionForwardTargetGroupToTerraform(struct?: LbListenerDefaultActionForwardTargetGroup): any;
/**
 * @stability stable
 */
export interface LbListenerDefaultActionForward {
    /**
     * stickiness block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#stickiness LbListener#stickiness}
     *
     * @stability stable
     */
    readonly stickiness?: LbListenerDefaultActionForwardStickiness;
    /**
     * target_group block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#target_group LbListener#target_group}
     *
     * @stability stable
     */
    readonly targetGroup: LbListenerDefaultActionForwardTargetGroup[];
}
export declare function lbListenerDefaultActionForwardToTerraform(struct?: LbListenerDefaultActionForwardOutputReference | LbListenerDefaultActionForward): any;
/**
 * @stability stable
 */
export declare class LbListenerDefaultActionForwardOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerDefaultActionForward | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerDefaultActionForward | undefined);
    private _stickiness;
    /**
     * @stability stable
     */
    get stickiness(): LbListenerDefaultActionForwardStickinessOutputReference;
    /**
     * @stability stable
     */
    putStickiness(value: LbListenerDefaultActionForwardStickiness): void;
    /**
     * @stability stable
     */
    resetStickiness(): void;
    /**
     * @stability stable
     */
    get stickinessInput(): LbListenerDefaultActionForwardStickiness | undefined;
    private _targetGroup?;
    /**
     * @stability stable
     */
    get targetGroup(): LbListenerDefaultActionForwardTargetGroup[];
    /**
     * @stability stable
     */
    set targetGroup(value: LbListenerDefaultActionForwardTargetGroup[]);
    /**
     * @stability stable
     */
    get targetGroupInput(): LbListenerDefaultActionForwardTargetGroup[] | undefined;
}
/**
 * @stability stable
 */
export interface LbListenerDefaultActionRedirect {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#host LbListener#host}.
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#path LbListener#path}.
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#port LbListener#port}.
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#protocol LbListener#protocol}.
     *
     * @stability stable
     */
    readonly protocol?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#query LbListener#query}.
     *
     * @stability stable
     */
    readonly query?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#status_code LbListener#status_code}.
     *
     * @stability stable
     */
    readonly statusCode: string;
}
export declare function lbListenerDefaultActionRedirectToTerraform(struct?: LbListenerDefaultActionRedirectOutputReference | LbListenerDefaultActionRedirect): any;
/**
 * @stability stable
 */
export declare class LbListenerDefaultActionRedirectOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerDefaultActionRedirect | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerDefaultActionRedirect | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _protocol?;
    /**
     * @stability stable
     */
    get protocol(): string;
    /**
     * @stability stable
     */
    set protocol(value: string);
    /**
     * @stability stable
     */
    resetProtocol(): void;
    /**
     * @stability stable
     */
    get protocolInput(): string | undefined;
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    resetQuery(): void;
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
    private _statusCode?;
    /**
     * @stability stable
     */
    get statusCode(): string;
    /**
     * @stability stable
     */
    set statusCode(value: string);
    /**
     * @stability stable
     */
    get statusCodeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface LbListenerDefaultAction {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#order LbListener#order}.
     *
     * @stability stable
     */
    readonly order?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#target_group_arn LbListener#target_group_arn}.
     *
     * @stability stable
     */
    readonly targetGroupArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#type LbListener#type}.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * authenticate_cognito block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#authenticate_cognito LbListener#authenticate_cognito}
     *
     * @stability stable
     */
    readonly authenticateCognito?: LbListenerDefaultActionAuthenticateCognito;
    /**
     * authenticate_oidc block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#authenticate_oidc LbListener#authenticate_oidc}
     *
     * @stability stable
     */
    readonly authenticateOidc?: LbListenerDefaultActionAuthenticateOidc;
    /**
     * fixed_response block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#fixed_response LbListener#fixed_response}
     *
     * @stability stable
     */
    readonly fixedResponse?: LbListenerDefaultActionFixedResponse;
    /**
     * forward block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#forward LbListener#forward}
     *
     * @stability stable
     */
    readonly forward?: LbListenerDefaultActionForward;
    /**
     * redirect block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#redirect LbListener#redirect}
     *
     * @stability stable
     */
    readonly redirect?: LbListenerDefaultActionRedirect;
}
export declare function lbListenerDefaultActionToTerraform(struct?: LbListenerDefaultAction): any;
/**
 * @stability stable
 */
export interface LbListenerTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#read LbListener#read}.
     *
     * @stability stable
     */
    readonly read?: string;
}
export declare function lbListenerTimeoutsToTerraform(struct?: LbListenerTimeoutsOutputReference | LbListenerTimeouts): any;
/**
 * @stability stable
 */
export declare class LbListenerTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbListenerTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbListenerTimeouts | undefined);
    private _read?;
    /**
     * @stability stable
     */
    get read(): string;
    /**
     * @stability stable
     */
    set read(value: string);
    /**
     * @stability stable
     */
    resetRead(): void;
    /**
     * @stability stable
     */
    get readInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lb_listener aws_lb_listener}.
 *
 * @stability stable
 */
export declare class LbListener extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lb_listener aws_lb_listener} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: LbListenerConfig);
    private _alpnPolicy?;
    /**
     * @stability stable
     */
    get alpnPolicy(): string;
    /**
     * @stability stable
     */
    set alpnPolicy(value: string);
    /**
     * @stability stable
     */
    resetAlpnPolicy(): void;
    /**
     * @stability stable
     */
    get alpnPolicyInput(): string | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    private _certificateArn?;
    /**
     * @stability stable
     */
    get certificateArn(): string;
    /**
     * @stability stable
     */
    set certificateArn(value: string);
    /**
     * @stability stable
     */
    resetCertificateArn(): void;
    /**
     * @stability stable
     */
    get certificateArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _loadBalancerArn?;
    /**
     * @stability stable
     */
    get loadBalancerArn(): string;
    /**
     * @stability stable
     */
    set loadBalancerArn(value: string);
    /**
     * @stability stable
     */
    get loadBalancerArnInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
    private _protocol?;
    /**
     * @stability stable
     */
    get protocol(): string;
    /**
     * @stability stable
     */
    set protocol(value: string);
    /**
     * @stability stable
     */
    resetProtocol(): void;
    /**
     * @stability stable
     */
    get protocolInput(): string | undefined;
    private _sslPolicy?;
    /**
     * @stability stable
     */
    get sslPolicy(): string;
    /**
     * @stability stable
     */
    set sslPolicy(value: string);
    /**
     * @stability stable
     */
    resetSslPolicy(): void;
    /**
     * @stability stable
     */
    get sslPolicyInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _defaultAction?;
    /**
     * @stability stable
     */
    get defaultAction(): LbListenerDefaultAction[];
    /**
     * @stability stable
     */
    set defaultAction(value: LbListenerDefaultAction[]);
    /**
     * @stability stable
     */
    get defaultActionInput(): LbListenerDefaultAction[] | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): LbListenerTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: LbListenerTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): LbListenerTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
