import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS CloudWatch Event Bridge.
 *
 * @stability stable
 */
export interface CloudwatchEventConnectionConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#authorization_type CloudwatchEventConnection#authorization_type}.
     *
     * @stability stable
     */
    readonly authorizationType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#description CloudwatchEventConnection#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#name CloudwatchEventConnection#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * auth_parameters block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#auth_parameters CloudwatchEventConnection#auth_parameters}
     *
     * @stability stable
     */
    readonly authParameters: CloudwatchEventConnectionAuthParameters;
}
/**
 * @stability stable
 */
export interface CloudwatchEventConnectionAuthParametersApiKey {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#key CloudwatchEventConnection#key}.
     *
     * @stability stable
     */
    readonly key: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#value CloudwatchEventConnection#value}.
     *
     * @stability stable
     */
    readonly value: string;
}
export declare function cloudwatchEventConnectionAuthParametersApiKeyToTerraform(struct?: CloudwatchEventConnectionAuthParametersApiKeyOutputReference | CloudwatchEventConnectionAuthParametersApiKey): any;
/**
 * @stability stable
 */
export declare class CloudwatchEventConnectionAuthParametersApiKeyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudwatchEventConnectionAuthParametersApiKey | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudwatchEventConnectionAuthParametersApiKey | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _value?;
    /**
     * @stability stable
     */
    get value(): string;
    /**
     * @stability stable
     */
    set value(value: string);
    /**
     * @stability stable
     */
    get valueInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface CloudwatchEventConnectionAuthParametersBasic {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#password CloudwatchEventConnection#password}.
     *
     * @stability stable
     */
    readonly password: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#username CloudwatchEventConnection#username}.
     *
     * @stability stable
     */
    readonly username: string;
}
export declare function cloudwatchEventConnectionAuthParametersBasicToTerraform(struct?: CloudwatchEventConnectionAuthParametersBasicOutputReference | CloudwatchEventConnectionAuthParametersBasic): any;
/**
 * @stability stable
 */
export declare class CloudwatchEventConnectionAuthParametersBasicOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudwatchEventConnectionAuthParametersBasic | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudwatchEventConnectionAuthParametersBasic | undefined);
    private _password?;
    /**
     * @stability stable
     */
    get password(): string;
    /**
     * @stability stable
     */
    set password(value: string);
    /**
     * @stability stable
     */
    get passwordInput(): string | undefined;
    private _username?;
    /**
     * @stability stable
     */
    get username(): string;
    /**
     * @stability stable
     */
    set username(value: string);
    /**
     * @stability stable
     */
    get usernameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface CloudwatchEventConnectionAuthParametersInvocationHttpParametersBody {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#is_value_secret CloudwatchEventConnection#is_value_secret}.
     *
     * @stability stable
     */
    readonly isValueSecret?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#key CloudwatchEventConnection#key}.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#value CloudwatchEventConnection#value}.
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function cloudwatchEventConnectionAuthParametersInvocationHttpParametersBodyToTerraform(struct?: CloudwatchEventConnectionAuthParametersInvocationHttpParametersBody): any;
/**
 * @stability stable
 */
export interface CloudwatchEventConnectionAuthParametersInvocationHttpParametersHeader {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#is_value_secret CloudwatchEventConnection#is_value_secret}.
     *
     * @stability stable
     */
    readonly isValueSecret?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#key CloudwatchEventConnection#key}.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#value CloudwatchEventConnection#value}.
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function cloudwatchEventConnectionAuthParametersInvocationHttpParametersHeaderToTerraform(struct?: CloudwatchEventConnectionAuthParametersInvocationHttpParametersHeader): any;
/**
 * @stability stable
 */
export interface CloudwatchEventConnectionAuthParametersInvocationHttpParametersQueryString {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#is_value_secret CloudwatchEventConnection#is_value_secret}.
     *
     * @stability stable
     */
    readonly isValueSecret?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#key CloudwatchEventConnection#key}.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#value CloudwatchEventConnection#value}.
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function cloudwatchEventConnectionAuthParametersInvocationHttpParametersQueryStringToTerraform(struct?: CloudwatchEventConnectionAuthParametersInvocationHttpParametersQueryString): any;
/**
 * @stability stable
 */
export interface CloudwatchEventConnectionAuthParametersInvocationHttpParameters {
    /**
     * body block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#body CloudwatchEventConnection#body}
     *
     * @stability stable
     */
    readonly body?: CloudwatchEventConnectionAuthParametersInvocationHttpParametersBody[];
    /**
     * header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#header CloudwatchEventConnection#header}
     *
     * @stability stable
     */
    readonly header?: CloudwatchEventConnectionAuthParametersInvocationHttpParametersHeader[];
    /**
     * query_string block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#query_string CloudwatchEventConnection#query_string}
     *
     * @stability stable
     */
    readonly queryString?: CloudwatchEventConnectionAuthParametersInvocationHttpParametersQueryString[];
}
export declare function cloudwatchEventConnectionAuthParametersInvocationHttpParametersToTerraform(struct?: CloudwatchEventConnectionAuthParametersInvocationHttpParametersOutputReference | CloudwatchEventConnectionAuthParametersInvocationHttpParameters): any;
/**
 * @stability stable
 */
export declare class CloudwatchEventConnectionAuthParametersInvocationHttpParametersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudwatchEventConnectionAuthParametersInvocationHttpParameters | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudwatchEventConnectionAuthParametersInvocationHttpParameters | undefined);
    private _body?;
    /**
     * @stability stable
     */
    get body(): CloudwatchEventConnectionAuthParametersInvocationHttpParametersBody[];
    /**
     * @stability stable
     */
    set body(value: CloudwatchEventConnectionAuthParametersInvocationHttpParametersBody[]);
    /**
     * @stability stable
     */
    resetBody(): void;
    /**
     * @stability stable
     */
    get bodyInput(): CloudwatchEventConnectionAuthParametersInvocationHttpParametersBody[] | undefined;
    private _header?;
    /**
     * @stability stable
     */
    get header(): CloudwatchEventConnectionAuthParametersInvocationHttpParametersHeader[];
    /**
     * @stability stable
     */
    set header(value: CloudwatchEventConnectionAuthParametersInvocationHttpParametersHeader[]);
    /**
     * @stability stable
     */
    resetHeader(): void;
    /**
     * @stability stable
     */
    get headerInput(): CloudwatchEventConnectionAuthParametersInvocationHttpParametersHeader[] | undefined;
    private _queryString?;
    /**
     * @stability stable
     */
    get queryString(): CloudwatchEventConnectionAuthParametersInvocationHttpParametersQueryString[];
    /**
     * @stability stable
     */
    set queryString(value: CloudwatchEventConnectionAuthParametersInvocationHttpParametersQueryString[]);
    /**
     * @stability stable
     */
    resetQueryString(): void;
    /**
     * @stability stable
     */
    get queryStringInput(): CloudwatchEventConnectionAuthParametersInvocationHttpParametersQueryString[] | undefined;
}
/**
 * @stability stable
 */
export interface CloudwatchEventConnectionAuthParametersOauthClientParameters {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#client_id CloudwatchEventConnection#client_id}.
     *
     * @stability stable
     */
    readonly clientId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#client_secret CloudwatchEventConnection#client_secret}.
     *
     * @stability stable
     */
    readonly clientSecret: string;
}
export declare function cloudwatchEventConnectionAuthParametersOauthClientParametersToTerraform(struct?: CloudwatchEventConnectionAuthParametersOauthClientParametersOutputReference | CloudwatchEventConnectionAuthParametersOauthClientParameters): any;
/**
 * @stability stable
 */
export declare class CloudwatchEventConnectionAuthParametersOauthClientParametersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudwatchEventConnectionAuthParametersOauthClientParameters | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudwatchEventConnectionAuthParametersOauthClientParameters | undefined);
    private _clientId?;
    /**
     * @stability stable
     */
    get clientId(): string;
    /**
     * @stability stable
     */
    set clientId(value: string);
    /**
     * @stability stable
     */
    get clientIdInput(): string | undefined;
    private _clientSecret?;
    /**
     * @stability stable
     */
    get clientSecret(): string;
    /**
     * @stability stable
     */
    set clientSecret(value: string);
    /**
     * @stability stable
     */
    get clientSecretInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersBody {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#is_value_secret CloudwatchEventConnection#is_value_secret}.
     *
     * @stability stable
     */
    readonly isValueSecret?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#key CloudwatchEventConnection#key}.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#value CloudwatchEventConnection#value}.
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function cloudwatchEventConnectionAuthParametersOauthOauthHttpParametersBodyToTerraform(struct?: CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersBody): any;
/**
 * @stability stable
 */
export interface CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersHeader {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#is_value_secret CloudwatchEventConnection#is_value_secret}.
     *
     * @stability stable
     */
    readonly isValueSecret?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#key CloudwatchEventConnection#key}.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#value CloudwatchEventConnection#value}.
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function cloudwatchEventConnectionAuthParametersOauthOauthHttpParametersHeaderToTerraform(struct?: CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersHeader): any;
/**
 * @stability stable
 */
export interface CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersQueryString {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#is_value_secret CloudwatchEventConnection#is_value_secret}.
     *
     * @stability stable
     */
    readonly isValueSecret?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#key CloudwatchEventConnection#key}.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#value CloudwatchEventConnection#value}.
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function cloudwatchEventConnectionAuthParametersOauthOauthHttpParametersQueryStringToTerraform(struct?: CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersQueryString): any;
/**
 * @stability stable
 */
export interface CloudwatchEventConnectionAuthParametersOauthOauthHttpParameters {
    /**
     * body block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#body CloudwatchEventConnection#body}
     *
     * @stability stable
     */
    readonly body?: CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersBody[];
    /**
     * header block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#header CloudwatchEventConnection#header}
     *
     * @stability stable
     */
    readonly header?: CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersHeader[];
    /**
     * query_string block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#query_string CloudwatchEventConnection#query_string}
     *
     * @stability stable
     */
    readonly queryString?: CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersQueryString[];
}
export declare function cloudwatchEventConnectionAuthParametersOauthOauthHttpParametersToTerraform(struct?: CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersOutputReference | CloudwatchEventConnectionAuthParametersOauthOauthHttpParameters): any;
/**
 * @stability stable
 */
export declare class CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudwatchEventConnectionAuthParametersOauthOauthHttpParameters | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudwatchEventConnectionAuthParametersOauthOauthHttpParameters | undefined);
    private _body?;
    /**
     * @stability stable
     */
    get body(): CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersBody[];
    /**
     * @stability stable
     */
    set body(value: CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersBody[]);
    /**
     * @stability stable
     */
    resetBody(): void;
    /**
     * @stability stable
     */
    get bodyInput(): CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersBody[] | undefined;
    private _header?;
    /**
     * @stability stable
     */
    get header(): CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersHeader[];
    /**
     * @stability stable
     */
    set header(value: CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersHeader[]);
    /**
     * @stability stable
     */
    resetHeader(): void;
    /**
     * @stability stable
     */
    get headerInput(): CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersHeader[] | undefined;
    private _queryString?;
    /**
     * @stability stable
     */
    get queryString(): CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersQueryString[];
    /**
     * @stability stable
     */
    set queryString(value: CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersQueryString[]);
    /**
     * @stability stable
     */
    resetQueryString(): void;
    /**
     * @stability stable
     */
    get queryStringInput(): CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersQueryString[] | undefined;
}
/**
 * @stability stable
 */
export interface CloudwatchEventConnectionAuthParametersOauth {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#authorization_endpoint CloudwatchEventConnection#authorization_endpoint}.
     *
     * @stability stable
     */
    readonly authorizationEndpoint: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#http_method CloudwatchEventConnection#http_method}.
     *
     * @stability stable
     */
    readonly httpMethod: string;
    /**
     * client_parameters block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#client_parameters CloudwatchEventConnection#client_parameters}
     *
     * @stability stable
     */
    readonly clientParameters?: CloudwatchEventConnectionAuthParametersOauthClientParameters;
    /**
     * oauth_http_parameters block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#oauth_http_parameters CloudwatchEventConnection#oauth_http_parameters}
     *
     * @stability stable
     */
    readonly oauthHttpParameters: CloudwatchEventConnectionAuthParametersOauthOauthHttpParameters;
}
export declare function cloudwatchEventConnectionAuthParametersOauthToTerraform(struct?: CloudwatchEventConnectionAuthParametersOauthOutputReference | CloudwatchEventConnectionAuthParametersOauth): any;
/**
 * @stability stable
 */
export declare class CloudwatchEventConnectionAuthParametersOauthOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudwatchEventConnectionAuthParametersOauth | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudwatchEventConnectionAuthParametersOauth | undefined);
    private _authorizationEndpoint?;
    /**
     * @stability stable
     */
    get authorizationEndpoint(): string;
    /**
     * @stability stable
     */
    set authorizationEndpoint(value: string);
    /**
     * @stability stable
     */
    get authorizationEndpointInput(): string | undefined;
    private _httpMethod?;
    /**
     * @stability stable
     */
    get httpMethod(): string;
    /**
     * @stability stable
     */
    set httpMethod(value: string);
    /**
     * @stability stable
     */
    get httpMethodInput(): string | undefined;
    private _clientParameters;
    /**
     * @stability stable
     */
    get clientParameters(): CloudwatchEventConnectionAuthParametersOauthClientParametersOutputReference;
    /**
     * @stability stable
     */
    putClientParameters(value: CloudwatchEventConnectionAuthParametersOauthClientParameters): void;
    /**
     * @stability stable
     */
    resetClientParameters(): void;
    /**
     * @stability stable
     */
    get clientParametersInput(): CloudwatchEventConnectionAuthParametersOauthClientParameters | undefined;
    private _oauthHttpParameters;
    /**
     * @stability stable
     */
    get oauthHttpParameters(): CloudwatchEventConnectionAuthParametersOauthOauthHttpParametersOutputReference;
    /**
     * @stability stable
     */
    putOauthHttpParameters(value: CloudwatchEventConnectionAuthParametersOauthOauthHttpParameters): void;
    /**
     * @stability stable
     */
    get oauthHttpParametersInput(): CloudwatchEventConnectionAuthParametersOauthOauthHttpParameters | undefined;
}
/**
 * @stability stable
 */
export interface CloudwatchEventConnectionAuthParameters {
    /**
     * api_key block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#api_key CloudwatchEventConnection#api_key}
     *
     * @stability stable
     */
    readonly apiKey?: CloudwatchEventConnectionAuthParametersApiKey;
    /**
     * basic block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#basic CloudwatchEventConnection#basic}
     *
     * @stability stable
     */
    readonly basic?: CloudwatchEventConnectionAuthParametersBasic;
    /**
     * invocation_http_parameters block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#invocation_http_parameters CloudwatchEventConnection#invocation_http_parameters}
     *
     * @stability stable
     */
    readonly invocationHttpParameters?: CloudwatchEventConnectionAuthParametersInvocationHttpParameters;
    /**
     * oauth block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection#oauth CloudwatchEventConnection#oauth}
     *
     * @stability stable
     */
    readonly oauth?: CloudwatchEventConnectionAuthParametersOauth;
}
export declare function cloudwatchEventConnectionAuthParametersToTerraform(struct?: CloudwatchEventConnectionAuthParametersOutputReference | CloudwatchEventConnectionAuthParameters): any;
/**
 * @stability stable
 */
export declare class CloudwatchEventConnectionAuthParametersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudwatchEventConnectionAuthParameters | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudwatchEventConnectionAuthParameters | undefined);
    private _apiKey;
    /**
     * @stability stable
     */
    get apiKey(): CloudwatchEventConnectionAuthParametersApiKeyOutputReference;
    /**
     * @stability stable
     */
    putApiKey(value: CloudwatchEventConnectionAuthParametersApiKey): void;
    /**
     * @stability stable
     */
    resetApiKey(): void;
    /**
     * @stability stable
     */
    get apiKeyInput(): CloudwatchEventConnectionAuthParametersApiKey | undefined;
    private _basic;
    /**
     * @stability stable
     */
    get basic(): CloudwatchEventConnectionAuthParametersBasicOutputReference;
    /**
     * @stability stable
     */
    putBasic(value: CloudwatchEventConnectionAuthParametersBasic): void;
    /**
     * @stability stable
     */
    resetBasic(): void;
    /**
     * @stability stable
     */
    get basicInput(): CloudwatchEventConnectionAuthParametersBasic | undefined;
    private _invocationHttpParameters;
    /**
     * @stability stable
     */
    get invocationHttpParameters(): CloudwatchEventConnectionAuthParametersInvocationHttpParametersOutputReference;
    /**
     * @stability stable
     */
    putInvocationHttpParameters(value: CloudwatchEventConnectionAuthParametersInvocationHttpParameters): void;
    /**
     * @stability stable
     */
    resetInvocationHttpParameters(): void;
    /**
     * @stability stable
     */
    get invocationHttpParametersInput(): CloudwatchEventConnectionAuthParametersInvocationHttpParameters | undefined;
    private _oauth;
    /**
     * @stability stable
     */
    get oauth(): CloudwatchEventConnectionAuthParametersOauthOutputReference;
    /**
     * @stability stable
     */
    putOauth(value: CloudwatchEventConnectionAuthParametersOauth): void;
    /**
     * @stability stable
     */
    resetOauth(): void;
    /**
     * @stability stable
     */
    get oauthInput(): CloudwatchEventConnectionAuthParametersOauth | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection aws_cloudwatch_event_connection}.
 *
 * @stability stable
 */
export declare class CloudwatchEventConnection extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_connection aws_cloudwatch_event_connection} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CloudwatchEventConnectionConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _authorizationType?;
    /**
     * @stability stable
     */
    get authorizationType(): string;
    /**
     * @stability stable
     */
    set authorizationType(value: string);
    /**
     * @stability stable
     */
    get authorizationTypeInput(): string | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get secretArn(): string;
    private _authParameters;
    /**
     * @stability stable
     */
    get authParameters(): CloudwatchEventConnectionAuthParametersOutputReference;
    /**
     * @stability stable
     */
    putAuthParameters(value: CloudwatchEventConnectionAuthParameters): void;
    /**
     * @stability stable
     */
    get authParametersInput(): CloudwatchEventConnectionAuthParameters | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
