import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS CloudWatch Event Bridge.
 *
 * @stability stable
 */
export interface CloudwatchEventTargetConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#arn CloudwatchEventTarget#arn}.
     *
     * @stability stable
     */
    readonly arn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#event_bus_name CloudwatchEventTarget#event_bus_name}.
     *
     * @stability stable
     */
    readonly eventBusName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#input CloudwatchEventTarget#input}.
     *
     * @stability stable
     */
    readonly input?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#input_path CloudwatchEventTarget#input_path}.
     *
     * @stability stable
     */
    readonly inputPath?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#role_arn CloudwatchEventTarget#role_arn}.
     *
     * @stability stable
     */
    readonly roleArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#rule CloudwatchEventTarget#rule}.
     *
     * @stability stable
     */
    readonly rule: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#target_id CloudwatchEventTarget#target_id}.
     *
     * @stability stable
     */
    readonly targetId?: string;
    /**
     * batch_target block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#batch_target CloudwatchEventTarget#batch_target}
     *
     * @stability stable
     */
    readonly batchTarget?: CloudwatchEventTargetBatchTarget;
    /**
     * dead_letter_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#dead_letter_config CloudwatchEventTarget#dead_letter_config}
     *
     * @stability stable
     */
    readonly deadLetterConfig?: CloudwatchEventTargetDeadLetterConfig;
    /**
     * ecs_target block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#ecs_target CloudwatchEventTarget#ecs_target}
     *
     * @stability stable
     */
    readonly ecsTarget?: CloudwatchEventTargetEcsTarget;
    /**
     * http_target block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#http_target CloudwatchEventTarget#http_target}
     *
     * @stability stable
     */
    readonly httpTarget?: CloudwatchEventTargetHttpTarget;
    /**
     * input_transformer block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#input_transformer CloudwatchEventTarget#input_transformer}
     *
     * @stability stable
     */
    readonly inputTransformer?: CloudwatchEventTargetInputTransformer;
    /**
     * kinesis_target block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#kinesis_target CloudwatchEventTarget#kinesis_target}
     *
     * @stability stable
     */
    readonly kinesisTarget?: CloudwatchEventTargetKinesisTarget;
    /**
     * redshift_target block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#redshift_target CloudwatchEventTarget#redshift_target}
     *
     * @stability stable
     */
    readonly redshiftTarget?: CloudwatchEventTargetRedshiftTarget;
    /**
     * retry_policy block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#retry_policy CloudwatchEventTarget#retry_policy}
     *
     * @stability stable
     */
    readonly retryPolicy?: CloudwatchEventTargetRetryPolicy;
    /**
     * run_command_targets block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#run_command_targets CloudwatchEventTarget#run_command_targets}
     *
     * @stability stable
     */
    readonly runCommandTargets?: CloudwatchEventTargetRunCommandTargets[];
    /**
     * sqs_target block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#sqs_target CloudwatchEventTarget#sqs_target}
     *
     * @stability stable
     */
    readonly sqsTarget?: CloudwatchEventTargetSqsTarget;
}
/**
 * @stability stable
 */
export interface CloudwatchEventTargetBatchTarget {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#array_size CloudwatchEventTarget#array_size}.
     *
     * @stability stable
     */
    readonly arraySize?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#job_attempts CloudwatchEventTarget#job_attempts}.
     *
     * @stability stable
     */
    readonly jobAttempts?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#job_definition CloudwatchEventTarget#job_definition}.
     *
     * @stability stable
     */
    readonly jobDefinition: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#job_name CloudwatchEventTarget#job_name}.
     *
     * @stability stable
     */
    readonly jobName: string;
}
export declare function cloudwatchEventTargetBatchTargetToTerraform(struct?: CloudwatchEventTargetBatchTargetOutputReference | CloudwatchEventTargetBatchTarget): any;
/**
 * @stability stable
 */
export declare class CloudwatchEventTargetBatchTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudwatchEventTargetBatchTarget | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudwatchEventTargetBatchTarget | undefined);
    private _arraySize?;
    /**
     * @stability stable
     */
    get arraySize(): number;
    /**
     * @stability stable
     */
    set arraySize(value: number);
    /**
     * @stability stable
     */
    resetArraySize(): void;
    /**
     * @stability stable
     */
    get arraySizeInput(): number | undefined;
    private _jobAttempts?;
    /**
     * @stability stable
     */
    get jobAttempts(): number;
    /**
     * @stability stable
     */
    set jobAttempts(value: number);
    /**
     * @stability stable
     */
    resetJobAttempts(): void;
    /**
     * @stability stable
     */
    get jobAttemptsInput(): number | undefined;
    private _jobDefinition?;
    /**
     * @stability stable
     */
    get jobDefinition(): string;
    /**
     * @stability stable
     */
    set jobDefinition(value: string);
    /**
     * @stability stable
     */
    get jobDefinitionInput(): string | undefined;
    private _jobName?;
    /**
     * @stability stable
     */
    get jobName(): string;
    /**
     * @stability stable
     */
    set jobName(value: string);
    /**
     * @stability stable
     */
    get jobNameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface CloudwatchEventTargetDeadLetterConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#arn CloudwatchEventTarget#arn}.
     *
     * @stability stable
     */
    readonly arn?: string;
}
export declare function cloudwatchEventTargetDeadLetterConfigToTerraform(struct?: CloudwatchEventTargetDeadLetterConfigOutputReference | CloudwatchEventTargetDeadLetterConfig): any;
/**
 * @stability stable
 */
export declare class CloudwatchEventTargetDeadLetterConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudwatchEventTargetDeadLetterConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudwatchEventTargetDeadLetterConfig | undefined);
    private _arn?;
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    set arn(value: string);
    /**
     * @stability stable
     */
    resetArn(): void;
    /**
     * @stability stable
     */
    get arnInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface CloudwatchEventTargetEcsTargetNetworkConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#assign_public_ip CloudwatchEventTarget#assign_public_ip}.
     *
     * @stability stable
     */
    readonly assignPublicIp?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#security_groups CloudwatchEventTarget#security_groups}.
     *
     * @stability stable
     */
    readonly securityGroups?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#subnets CloudwatchEventTarget#subnets}.
     *
     * @stability stable
     */
    readonly subnets: string[];
}
export declare function cloudwatchEventTargetEcsTargetNetworkConfigurationToTerraform(struct?: CloudwatchEventTargetEcsTargetNetworkConfigurationOutputReference | CloudwatchEventTargetEcsTargetNetworkConfiguration): any;
/**
 * @stability stable
 */
export declare class CloudwatchEventTargetEcsTargetNetworkConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudwatchEventTargetEcsTargetNetworkConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudwatchEventTargetEcsTargetNetworkConfiguration | undefined);
    private _assignPublicIp?;
    /**
     * @stability stable
     */
    get assignPublicIp(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set assignPublicIp(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAssignPublicIp(): void;
    /**
     * @stability stable
     */
    get assignPublicIpInput(): boolean | cdktf.IResolvable | undefined;
    private _securityGroups?;
    /**
     * @stability stable
     */
    get securityGroups(): string[];
    /**
     * @stability stable
     */
    set securityGroups(value: string[]);
    /**
     * @stability stable
     */
    resetSecurityGroups(): void;
    /**
     * @stability stable
     */
    get securityGroupsInput(): string[] | undefined;
    private _subnets?;
    /**
     * @stability stable
     */
    get subnets(): string[];
    /**
     * @stability stable
     */
    set subnets(value: string[]);
    /**
     * @stability stable
     */
    get subnetsInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface CloudwatchEventTargetEcsTargetPlacementConstraint {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#expression CloudwatchEventTarget#expression}.
     *
     * @stability stable
     */
    readonly expression?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#type CloudwatchEventTarget#type}.
     *
     * @stability stable
     */
    readonly type: string;
}
export declare function cloudwatchEventTargetEcsTargetPlacementConstraintToTerraform(struct?: CloudwatchEventTargetEcsTargetPlacementConstraint): any;
/**
 * @stability stable
 */
export interface CloudwatchEventTargetEcsTarget {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#enable_ecs_managed_tags CloudwatchEventTarget#enable_ecs_managed_tags}.
     *
     * @stability stable
     */
    readonly enableEcsManagedTags?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#enable_execute_command CloudwatchEventTarget#enable_execute_command}.
     *
     * @stability stable
     */
    readonly enableExecuteCommand?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#group CloudwatchEventTarget#group}.
     *
     * @stability stable
     */
    readonly group?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#launch_type CloudwatchEventTarget#launch_type}.
     *
     * @stability stable
     */
    readonly launchType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#platform_version CloudwatchEventTarget#platform_version}.
     *
     * @stability stable
     */
    readonly platformVersion?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#propagate_tags CloudwatchEventTarget#propagate_tags}.
     *
     * @stability stable
     */
    readonly propagateTags?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#tags CloudwatchEventTarget#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#task_count CloudwatchEventTarget#task_count}.
     *
     * @stability stable
     */
    readonly taskCount?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#task_definition_arn CloudwatchEventTarget#task_definition_arn}.
     *
     * @stability stable
     */
    readonly taskDefinitionArn: string;
    /**
     * network_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#network_configuration CloudwatchEventTarget#network_configuration}
     *
     * @stability stable
     */
    readonly networkConfiguration?: CloudwatchEventTargetEcsTargetNetworkConfiguration;
    /**
     * placement_constraint block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#placement_constraint CloudwatchEventTarget#placement_constraint}
     *
     * @stability stable
     */
    readonly placementConstraint?: CloudwatchEventTargetEcsTargetPlacementConstraint[];
}
export declare function cloudwatchEventTargetEcsTargetToTerraform(struct?: CloudwatchEventTargetEcsTargetOutputReference | CloudwatchEventTargetEcsTarget): any;
/**
 * @stability stable
 */
export declare class CloudwatchEventTargetEcsTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudwatchEventTargetEcsTarget | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudwatchEventTargetEcsTarget | undefined);
    private _enableEcsManagedTags?;
    /**
     * @stability stable
     */
    get enableEcsManagedTags(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableEcsManagedTags(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableEcsManagedTags(): void;
    /**
     * @stability stable
     */
    get enableEcsManagedTagsInput(): boolean | cdktf.IResolvable | undefined;
    private _enableExecuteCommand?;
    /**
     * @stability stable
     */
    get enableExecuteCommand(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableExecuteCommand(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableExecuteCommand(): void;
    /**
     * @stability stable
     */
    get enableExecuteCommandInput(): boolean | cdktf.IResolvable | undefined;
    private _group?;
    /**
     * @stability stable
     */
    get group(): string;
    /**
     * @stability stable
     */
    set group(value: string);
    /**
     * @stability stable
     */
    resetGroup(): void;
    /**
     * @stability stable
     */
    get groupInput(): string | undefined;
    private _launchType?;
    /**
     * @stability stable
     */
    get launchType(): string;
    /**
     * @stability stable
     */
    set launchType(value: string);
    /**
     * @stability stable
     */
    resetLaunchType(): void;
    /**
     * @stability stable
     */
    get launchTypeInput(): string | undefined;
    private _platformVersion?;
    /**
     * @stability stable
     */
    get platformVersion(): string;
    /**
     * @stability stable
     */
    set platformVersion(value: string);
    /**
     * @stability stable
     */
    resetPlatformVersion(): void;
    /**
     * @stability stable
     */
    get platformVersionInput(): string | undefined;
    private _propagateTags?;
    /**
     * @stability stable
     */
    get propagateTags(): string;
    /**
     * @stability stable
     */
    set propagateTags(value: string);
    /**
     * @stability stable
     */
    resetPropagateTags(): void;
    /**
     * @stability stable
     */
    get propagateTagsInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _taskCount?;
    /**
     * @stability stable
     */
    get taskCount(): number;
    /**
     * @stability stable
     */
    set taskCount(value: number);
    /**
     * @stability stable
     */
    resetTaskCount(): void;
    /**
     * @stability stable
     */
    get taskCountInput(): number | undefined;
    private _taskDefinitionArn?;
    /**
     * @stability stable
     */
    get taskDefinitionArn(): string;
    /**
     * @stability stable
     */
    set taskDefinitionArn(value: string);
    /**
     * @stability stable
     */
    get taskDefinitionArnInput(): string | undefined;
    private _networkConfiguration;
    /**
     * @stability stable
     */
    get networkConfiguration(): CloudwatchEventTargetEcsTargetNetworkConfigurationOutputReference;
    /**
     * @stability stable
     */
    putNetworkConfiguration(value: CloudwatchEventTargetEcsTargetNetworkConfiguration): void;
    /**
     * @stability stable
     */
    resetNetworkConfiguration(): void;
    /**
     * @stability stable
     */
    get networkConfigurationInput(): CloudwatchEventTargetEcsTargetNetworkConfiguration | undefined;
    private _placementConstraint?;
    /**
     * @stability stable
     */
    get placementConstraint(): CloudwatchEventTargetEcsTargetPlacementConstraint[];
    /**
     * @stability stable
     */
    set placementConstraint(value: CloudwatchEventTargetEcsTargetPlacementConstraint[]);
    /**
     * @stability stable
     */
    resetPlacementConstraint(): void;
    /**
     * @stability stable
     */
    get placementConstraintInput(): CloudwatchEventTargetEcsTargetPlacementConstraint[] | undefined;
}
/**
 * @stability stable
 */
export interface CloudwatchEventTargetHttpTarget {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#header_parameters CloudwatchEventTarget#header_parameters}.
     *
     * @stability stable
     */
    readonly headerParameters?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#path_parameter_values CloudwatchEventTarget#path_parameter_values}.
     *
     * @stability stable
     */
    readonly pathParameterValues?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#query_string_parameters CloudwatchEventTarget#query_string_parameters}.
     *
     * @stability stable
     */
    readonly queryStringParameters?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
export declare function cloudwatchEventTargetHttpTargetToTerraform(struct?: CloudwatchEventTargetHttpTargetOutputReference | CloudwatchEventTargetHttpTarget): any;
/**
 * @stability stable
 */
export declare class CloudwatchEventTargetHttpTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudwatchEventTargetHttpTarget | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudwatchEventTargetHttpTarget | undefined);
    private _headerParameters?;
    /**
     * @stability stable
     */
    get headerParameters(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set headerParameters(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHeaderParameters(): void;
    /**
     * @stability stable
     */
    get headerParametersInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _pathParameterValues?;
    /**
     * @stability stable
     */
    get pathParameterValues(): string[];
    /**
     * @stability stable
     */
    set pathParameterValues(value: string[]);
    /**
     * @stability stable
     */
    resetPathParameterValues(): void;
    /**
     * @stability stable
     */
    get pathParameterValuesInput(): string[] | undefined;
    private _queryStringParameters?;
    /**
     * @stability stable
     */
    get queryStringParameters(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set queryStringParameters(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetQueryStringParameters(): void;
    /**
     * @stability stable
     */
    get queryStringParametersInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
}
/**
 * @stability stable
 */
export interface CloudwatchEventTargetInputTransformer {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#input_paths CloudwatchEventTarget#input_paths}.
     *
     * @stability stable
     */
    readonly inputPaths?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#input_template CloudwatchEventTarget#input_template}.
     *
     * @stability stable
     */
    readonly inputTemplate: string;
}
export declare function cloudwatchEventTargetInputTransformerToTerraform(struct?: CloudwatchEventTargetInputTransformerOutputReference | CloudwatchEventTargetInputTransformer): any;
/**
 * @stability stable
 */
export declare class CloudwatchEventTargetInputTransformerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudwatchEventTargetInputTransformer | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudwatchEventTargetInputTransformer | undefined);
    private _inputPaths?;
    /**
     * @stability stable
     */
    get inputPaths(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set inputPaths(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetInputPaths(): void;
    /**
     * @stability stable
     */
    get inputPathsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _inputTemplate?;
    /**
     * @stability stable
     */
    get inputTemplate(): string;
    /**
     * @stability stable
     */
    set inputTemplate(value: string);
    /**
     * @stability stable
     */
    get inputTemplateInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface CloudwatchEventTargetKinesisTarget {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#partition_key_path CloudwatchEventTarget#partition_key_path}.
     *
     * @stability stable
     */
    readonly partitionKeyPath?: string;
}
export declare function cloudwatchEventTargetKinesisTargetToTerraform(struct?: CloudwatchEventTargetKinesisTargetOutputReference | CloudwatchEventTargetKinesisTarget): any;
/**
 * @stability stable
 */
export declare class CloudwatchEventTargetKinesisTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudwatchEventTargetKinesisTarget | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudwatchEventTargetKinesisTarget | undefined);
    private _partitionKeyPath?;
    /**
     * @stability stable
     */
    get partitionKeyPath(): string;
    /**
     * @stability stable
     */
    set partitionKeyPath(value: string);
    /**
     * @stability stable
     */
    resetPartitionKeyPath(): void;
    /**
     * @stability stable
     */
    get partitionKeyPathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface CloudwatchEventTargetRedshiftTarget {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#database CloudwatchEventTarget#database}.
     *
     * @stability stable
     */
    readonly database: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#db_user CloudwatchEventTarget#db_user}.
     *
     * @stability stable
     */
    readonly dbUser?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#secrets_manager_arn CloudwatchEventTarget#secrets_manager_arn}.
     *
     * @stability stable
     */
    readonly secretsManagerArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#sql CloudwatchEventTarget#sql}.
     *
     * @stability stable
     */
    readonly sql?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#statement_name CloudwatchEventTarget#statement_name}.
     *
     * @stability stable
     */
    readonly statementName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#with_event CloudwatchEventTarget#with_event}.
     *
     * @stability stable
     */
    readonly withEvent?: boolean | cdktf.IResolvable;
}
export declare function cloudwatchEventTargetRedshiftTargetToTerraform(struct?: CloudwatchEventTargetRedshiftTargetOutputReference | CloudwatchEventTargetRedshiftTarget): any;
/**
 * @stability stable
 */
export declare class CloudwatchEventTargetRedshiftTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudwatchEventTargetRedshiftTarget | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudwatchEventTargetRedshiftTarget | undefined);
    private _database?;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    get databaseInput(): string | undefined;
    private _dbUser?;
    /**
     * @stability stable
     */
    get dbUser(): string;
    /**
     * @stability stable
     */
    set dbUser(value: string);
    /**
     * @stability stable
     */
    resetDbUser(): void;
    /**
     * @stability stable
     */
    get dbUserInput(): string | undefined;
    private _secretsManagerArn?;
    /**
     * @stability stable
     */
    get secretsManagerArn(): string;
    /**
     * @stability stable
     */
    set secretsManagerArn(value: string);
    /**
     * @stability stable
     */
    resetSecretsManagerArn(): void;
    /**
     * @stability stable
     */
    get secretsManagerArnInput(): string | undefined;
    private _sql?;
    /**
     * @stability stable
     */
    get sql(): string;
    /**
     * @stability stable
     */
    set sql(value: string);
    /**
     * @stability stable
     */
    resetSql(): void;
    /**
     * @stability stable
     */
    get sqlInput(): string | undefined;
    private _statementName?;
    /**
     * @stability stable
     */
    get statementName(): string;
    /**
     * @stability stable
     */
    set statementName(value: string);
    /**
     * @stability stable
     */
    resetStatementName(): void;
    /**
     * @stability stable
     */
    get statementNameInput(): string | undefined;
    private _withEvent?;
    /**
     * @stability stable
     */
    get withEvent(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set withEvent(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetWithEvent(): void;
    /**
     * @stability stable
     */
    get withEventInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface CloudwatchEventTargetRetryPolicy {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#maximum_event_age_in_seconds CloudwatchEventTarget#maximum_event_age_in_seconds}.
     *
     * @stability stable
     */
    readonly maximumEventAgeInSeconds?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#maximum_retry_attempts CloudwatchEventTarget#maximum_retry_attempts}.
     *
     * @stability stable
     */
    readonly maximumRetryAttempts?: number;
}
export declare function cloudwatchEventTargetRetryPolicyToTerraform(struct?: CloudwatchEventTargetRetryPolicyOutputReference | CloudwatchEventTargetRetryPolicy): any;
/**
 * @stability stable
 */
export declare class CloudwatchEventTargetRetryPolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudwatchEventTargetRetryPolicy | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudwatchEventTargetRetryPolicy | undefined);
    private _maximumEventAgeInSeconds?;
    /**
     * @stability stable
     */
    get maximumEventAgeInSeconds(): number;
    /**
     * @stability stable
     */
    set maximumEventAgeInSeconds(value: number);
    /**
     * @stability stable
     */
    resetMaximumEventAgeInSeconds(): void;
    /**
     * @stability stable
     */
    get maximumEventAgeInSecondsInput(): number | undefined;
    private _maximumRetryAttempts?;
    /**
     * @stability stable
     */
    get maximumRetryAttempts(): number;
    /**
     * @stability stable
     */
    set maximumRetryAttempts(value: number);
    /**
     * @stability stable
     */
    resetMaximumRetryAttempts(): void;
    /**
     * @stability stable
     */
    get maximumRetryAttemptsInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface CloudwatchEventTargetRunCommandTargets {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#key CloudwatchEventTarget#key}.
     *
     * @stability stable
     */
    readonly key: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#values CloudwatchEventTarget#values}.
     *
     * @stability stable
     */
    readonly values: string[];
}
export declare function cloudwatchEventTargetRunCommandTargetsToTerraform(struct?: CloudwatchEventTargetRunCommandTargets): any;
/**
 * @stability stable
 */
export interface CloudwatchEventTargetSqsTarget {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target#message_group_id CloudwatchEventTarget#message_group_id}.
     *
     * @stability stable
     */
    readonly messageGroupId?: string;
}
export declare function cloudwatchEventTargetSqsTargetToTerraform(struct?: CloudwatchEventTargetSqsTargetOutputReference | CloudwatchEventTargetSqsTarget): any;
/**
 * @stability stable
 */
export declare class CloudwatchEventTargetSqsTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudwatchEventTargetSqsTarget | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudwatchEventTargetSqsTarget | undefined);
    private _messageGroupId?;
    /**
     * @stability stable
     */
    get messageGroupId(): string;
    /**
     * @stability stable
     */
    set messageGroupId(value: string);
    /**
     * @stability stable
     */
    resetMessageGroupId(): void;
    /**
     * @stability stable
     */
    get messageGroupIdInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target aws_cloudwatch_event_target}.
 *
 * @stability stable
 */
export declare class CloudwatchEventTarget extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_event_target aws_cloudwatch_event_target} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CloudwatchEventTargetConfig);
    private _arn?;
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    set arn(value: string);
    /**
     * @stability stable
     */
    get arnInput(): string | undefined;
    private _eventBusName?;
    /**
     * @stability stable
     */
    get eventBusName(): string;
    /**
     * @stability stable
     */
    set eventBusName(value: string);
    /**
     * @stability stable
     */
    resetEventBusName(): void;
    /**
     * @stability stable
     */
    get eventBusNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _input?;
    /**
     * @stability stable
     */
    get input(): string;
    /**
     * @stability stable
     */
    set input(value: string);
    /**
     * @stability stable
     */
    resetInput(): void;
    /**
     * @stability stable
     */
    get inputInput(): string | undefined;
    private _inputPath?;
    /**
     * @stability stable
     */
    get inputPath(): string;
    /**
     * @stability stable
     */
    set inputPath(value: string);
    /**
     * @stability stable
     */
    resetInputPath(): void;
    /**
     * @stability stable
     */
    get inputPathInput(): string | undefined;
    private _roleArn?;
    /**
     * @stability stable
     */
    get roleArn(): string;
    /**
     * @stability stable
     */
    set roleArn(value: string);
    /**
     * @stability stable
     */
    resetRoleArn(): void;
    /**
     * @stability stable
     */
    get roleArnInput(): string | undefined;
    private _rule?;
    /**
     * @stability stable
     */
    get rule(): string;
    /**
     * @stability stable
     */
    set rule(value: string);
    /**
     * @stability stable
     */
    get ruleInput(): string | undefined;
    private _targetId?;
    /**
     * @stability stable
     */
    get targetId(): string;
    /**
     * @stability stable
     */
    set targetId(value: string);
    /**
     * @stability stable
     */
    resetTargetId(): void;
    /**
     * @stability stable
     */
    get targetIdInput(): string | undefined;
    private _batchTarget;
    /**
     * @stability stable
     */
    get batchTarget(): CloudwatchEventTargetBatchTargetOutputReference;
    /**
     * @stability stable
     */
    putBatchTarget(value: CloudwatchEventTargetBatchTarget): void;
    /**
     * @stability stable
     */
    resetBatchTarget(): void;
    /**
     * @stability stable
     */
    get batchTargetInput(): CloudwatchEventTargetBatchTarget | undefined;
    private _deadLetterConfig;
    /**
     * @stability stable
     */
    get deadLetterConfig(): CloudwatchEventTargetDeadLetterConfigOutputReference;
    /**
     * @stability stable
     */
    putDeadLetterConfig(value: CloudwatchEventTargetDeadLetterConfig): void;
    /**
     * @stability stable
     */
    resetDeadLetterConfig(): void;
    /**
     * @stability stable
     */
    get deadLetterConfigInput(): CloudwatchEventTargetDeadLetterConfig | undefined;
    private _ecsTarget;
    /**
     * @stability stable
     */
    get ecsTarget(): CloudwatchEventTargetEcsTargetOutputReference;
    /**
     * @stability stable
     */
    putEcsTarget(value: CloudwatchEventTargetEcsTarget): void;
    /**
     * @stability stable
     */
    resetEcsTarget(): void;
    /**
     * @stability stable
     */
    get ecsTargetInput(): CloudwatchEventTargetEcsTarget | undefined;
    private _httpTarget;
    /**
     * @stability stable
     */
    get httpTarget(): CloudwatchEventTargetHttpTargetOutputReference;
    /**
     * @stability stable
     */
    putHttpTarget(value: CloudwatchEventTargetHttpTarget): void;
    /**
     * @stability stable
     */
    resetHttpTarget(): void;
    /**
     * @stability stable
     */
    get httpTargetInput(): CloudwatchEventTargetHttpTarget | undefined;
    private _inputTransformer;
    /**
     * @stability stable
     */
    get inputTransformer(): CloudwatchEventTargetInputTransformerOutputReference;
    /**
     * @stability stable
     */
    putInputTransformer(value: CloudwatchEventTargetInputTransformer): void;
    /**
     * @stability stable
     */
    resetInputTransformer(): void;
    /**
     * @stability stable
     */
    get inputTransformerInput(): CloudwatchEventTargetInputTransformer | undefined;
    private _kinesisTarget;
    /**
     * @stability stable
     */
    get kinesisTarget(): CloudwatchEventTargetKinesisTargetOutputReference;
    /**
     * @stability stable
     */
    putKinesisTarget(value: CloudwatchEventTargetKinesisTarget): void;
    /**
     * @stability stable
     */
    resetKinesisTarget(): void;
    /**
     * @stability stable
     */
    get kinesisTargetInput(): CloudwatchEventTargetKinesisTarget | undefined;
    private _redshiftTarget;
    /**
     * @stability stable
     */
    get redshiftTarget(): CloudwatchEventTargetRedshiftTargetOutputReference;
    /**
     * @stability stable
     */
    putRedshiftTarget(value: CloudwatchEventTargetRedshiftTarget): void;
    /**
     * @stability stable
     */
    resetRedshiftTarget(): void;
    /**
     * @stability stable
     */
    get redshiftTargetInput(): CloudwatchEventTargetRedshiftTarget | undefined;
    private _retryPolicy;
    /**
     * @stability stable
     */
    get retryPolicy(): CloudwatchEventTargetRetryPolicyOutputReference;
    /**
     * @stability stable
     */
    putRetryPolicy(value: CloudwatchEventTargetRetryPolicy): void;
    /**
     * @stability stable
     */
    resetRetryPolicy(): void;
    /**
     * @stability stable
     */
    get retryPolicyInput(): CloudwatchEventTargetRetryPolicy | undefined;
    private _runCommandTargets?;
    /**
     * @stability stable
     */
    get runCommandTargets(): CloudwatchEventTargetRunCommandTargets[];
    /**
     * @stability stable
     */
    set runCommandTargets(value: CloudwatchEventTargetRunCommandTargets[]);
    /**
     * @stability stable
     */
    resetRunCommandTargets(): void;
    /**
     * @stability stable
     */
    get runCommandTargetsInput(): CloudwatchEventTargetRunCommandTargets[] | undefined;
    private _sqsTarget;
    /**
     * @stability stable
     */
    get sqsTarget(): CloudwatchEventTargetSqsTargetOutputReference;
    /**
     * @stability stable
     */
    putSqsTarget(value: CloudwatchEventTargetSqsTarget): void;
    /**
     * @stability stable
     */
    resetSqsTarget(): void;
    /**
     * @stability stable
     */
    get sqsTargetInput(): CloudwatchEventTargetSqsTarget | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
