import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Glue.
 *
 * @stability stable
 */
export interface GluePartitionIndexConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition_index#catalog_id GluePartitionIndex#catalog_id}.
     *
     * @stability stable
     */
    readonly catalogId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition_index#database_name GluePartitionIndex#database_name}.
     *
     * @stability stable
     */
    readonly databaseName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition_index#table_name GluePartitionIndex#table_name}.
     *
     * @stability stable
     */
    readonly tableName: string;
    /**
     * partition_index block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition_index#partition_index GluePartitionIndex#partition_index}
     *
     * @stability stable
     */
    readonly partitionIndex: GluePartitionIndexPartitionIndex;
}
/**
 * @stability stable
 */
export interface GluePartitionIndexPartitionIndex {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition_index#index_name GluePartitionIndex#index_name}.
     *
     * @stability stable
     */
    readonly indexName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition_index#keys GluePartitionIndex#keys}.
     *
     * @stability stable
     */
    readonly keys?: string[];
}
export declare function gluePartitionIndexPartitionIndexToTerraform(struct?: GluePartitionIndexPartitionIndexOutputReference | GluePartitionIndexPartitionIndex): any;
/**
 * @stability stable
 */
export declare class GluePartitionIndexPartitionIndexOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): GluePartitionIndexPartitionIndex | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: GluePartitionIndexPartitionIndex | undefined);
    private _indexName?;
    /**
     * @stability stable
     */
    get indexName(): string;
    /**
     * @stability stable
     */
    set indexName(value: string);
    /**
     * @stability stable
     */
    resetIndexName(): void;
    /**
     * @stability stable
     */
    get indexNameInput(): string | undefined;
    private _keys?;
    /**
     * @stability stable
     */
    get keys(): string[];
    /**
     * @stability stable
     */
    set keys(value: string[]);
    /**
     * @stability stable
     */
    resetKeys(): void;
    /**
     * @stability stable
     */
    get keysInput(): string[] | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_partition_index aws_glue_partition_index}.
 *
 * @stability stable
 */
export declare class GluePartitionIndex extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_partition_index aws_glue_partition_index} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: GluePartitionIndexConfig);
    private _catalogId?;
    /**
     * @stability stable
     */
    get catalogId(): string;
    /**
     * @stability stable
     */
    set catalogId(value: string);
    /**
     * @stability stable
     */
    resetCatalogId(): void;
    /**
     * @stability stable
     */
    get catalogIdInput(): string | undefined;
    private _databaseName?;
    /**
     * @stability stable
     */
    get databaseName(): string;
    /**
     * @stability stable
     */
    set databaseName(value: string);
    /**
     * @stability stable
     */
    get databaseNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _tableName?;
    /**
     * @stability stable
     */
    get tableName(): string;
    /**
     * @stability stable
     */
    set tableName(value: string);
    /**
     * @stability stable
     */
    get tableNameInput(): string | undefined;
    private _partitionIndex;
    /**
     * @stability stable
     */
    get partitionIndex(): GluePartitionIndexPartitionIndexOutputReference;
    /**
     * @stability stable
     */
    putPartitionIndex(value: GluePartitionIndexPartitionIndex): void;
    /**
     * @stability stable
     */
    get partitionIndexInput(): GluePartitionIndexPartitionIndex | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
