import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS GuardDuty.
 *
 * @stability stable
 */
export interface GuarddutyOrganizationConfigurationConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#auto_enable GuarddutyOrganizationConfiguration#auto_enable}.
     *
     * @stability stable
     */
    readonly autoEnable: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#detector_id GuarddutyOrganizationConfiguration#detector_id}.
     *
     * @stability stable
     */
    readonly detectorId: string;
    /**
     * datasources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#datasources GuarddutyOrganizationConfiguration#datasources}
     *
     * @stability stable
     */
    readonly datasources?: GuarddutyOrganizationConfigurationDatasources;
}
/**
 * @stability stable
 */
export interface GuarddutyOrganizationConfigurationDatasourcesS3Logs {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#auto_enable GuarddutyOrganizationConfiguration#auto_enable}.
     *
     * @stability stable
     */
    readonly autoEnable: boolean | cdktf.IResolvable;
}
export declare function guarddutyOrganizationConfigurationDatasourcesS3LogsToTerraform(struct?: GuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference | GuarddutyOrganizationConfigurationDatasourcesS3Logs): any;
/**
 * @stability stable
 */
export declare class GuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): GuarddutyOrganizationConfigurationDatasourcesS3Logs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: GuarddutyOrganizationConfigurationDatasourcesS3Logs | undefined);
    private _autoEnable?;
    /**
     * @stability stable
     */
    get autoEnable(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set autoEnable(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get autoEnableInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface GuarddutyOrganizationConfigurationDatasources {
    /**
     * s3_logs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#s3_logs GuarddutyOrganizationConfiguration#s3_logs}
     *
     * @stability stable
     */
    readonly s3Logs?: GuarddutyOrganizationConfigurationDatasourcesS3Logs;
}
export declare function guarddutyOrganizationConfigurationDatasourcesToTerraform(struct?: GuarddutyOrganizationConfigurationDatasourcesOutputReference | GuarddutyOrganizationConfigurationDatasources): any;
/**
 * @stability stable
 */
export declare class GuarddutyOrganizationConfigurationDatasourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): GuarddutyOrganizationConfigurationDatasources | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: GuarddutyOrganizationConfigurationDatasources | undefined);
    private _s3Logs;
    /**
     * @stability stable
     */
    get s3Logs(): GuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference;
    /**
     * @stability stable
     */
    putS3Logs(value: GuarddutyOrganizationConfigurationDatasourcesS3Logs): void;
    /**
     * @stability stable
     */
    resetS3Logs(): void;
    /**
     * @stability stable
     */
    get s3LogsInput(): GuarddutyOrganizationConfigurationDatasourcesS3Logs | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration aws_guardduty_organization_configuration}.
 *
 * @stability stable
 */
export declare class GuarddutyOrganizationConfiguration extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration aws_guardduty_organization_configuration} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: GuarddutyOrganizationConfigurationConfig);
    private _autoEnable?;
    /**
     * @stability stable
     */
    get autoEnable(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set autoEnable(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get autoEnableInput(): boolean | cdktf.IResolvable | undefined;
    private _detectorId?;
    /**
     * @stability stable
     */
    get detectorId(): string;
    /**
     * @stability stable
     */
    set detectorId(value: string);
    /**
     * @stability stable
     */
    get detectorIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _datasources;
    /**
     * @stability stable
     */
    get datasources(): GuarddutyOrganizationConfigurationDatasourcesOutputReference;
    /**
     * @stability stable
     */
    putDatasources(value: GuarddutyOrganizationConfigurationDatasources): void;
    /**
     * @stability stable
     */
    resetDatasources(): void;
    /**
     * @stability stable
     */
    get datasourcesInput(): GuarddutyOrganizationConfigurationDatasources | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
