import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Identity and Access Management.
 *
 * @stability stable
 */
export interface IamRoleConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role#assume_role_policy IamRole#assume_role_policy}.
     *
     * @stability stable
     */
    readonly assumeRolePolicy: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role#description IamRole#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role#force_detach_policies IamRole#force_detach_policies}.
     *
     * @stability stable
     */
    readonly forceDetachPolicies?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role#managed_policy_arns IamRole#managed_policy_arns}.
     *
     * @stability stable
     */
    readonly managedPolicyArns?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role#max_session_duration IamRole#max_session_duration}.
     *
     * @stability stable
     */
    readonly maxSessionDuration?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role#name IamRole#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role#name_prefix IamRole#name_prefix}.
     *
     * @stability stable
     */
    readonly namePrefix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role#path IamRole#path}.
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role#permissions_boundary IamRole#permissions_boundary}.
     *
     * @stability stable
     */
    readonly permissionsBoundary?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role#tags IamRole#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role#tags_all IamRole#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * inline_policy block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role#inline_policy IamRole#inline_policy}
     *
     * @stability stable
     */
    readonly inlinePolicy?: IamRoleInlinePolicy[];
}
/**
 * @stability stable
 */
export interface IamRoleInlinePolicy {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role#name IamRole#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role#policy IamRole#policy}.
     *
     * @stability stable
     */
    readonly policy?: string;
}
export declare function iamRoleInlinePolicyToTerraform(struct?: IamRoleInlinePolicy): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_role aws_iam_role}.
 *
 * @stability stable
 */
export declare class IamRole extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_role aws_iam_role} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: IamRoleConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _assumeRolePolicy?;
    /**
     * @stability stable
     */
    get assumeRolePolicy(): string;
    /**
     * @stability stable
     */
    set assumeRolePolicy(value: string);
    /**
     * @stability stable
     */
    get assumeRolePolicyInput(): string | undefined;
    /**
     * @stability stable
     */
    get createDate(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _forceDetachPolicies?;
    /**
     * @stability stable
     */
    get forceDetachPolicies(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set forceDetachPolicies(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetForceDetachPolicies(): void;
    /**
     * @stability stable
     */
    get forceDetachPoliciesInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _managedPolicyArns?;
    /**
     * @stability stable
     */
    get managedPolicyArns(): string[];
    /**
     * @stability stable
     */
    set managedPolicyArns(value: string[]);
    /**
     * @stability stable
     */
    resetManagedPolicyArns(): void;
    /**
     * @stability stable
     */
    get managedPolicyArnsInput(): string[] | undefined;
    private _maxSessionDuration?;
    /**
     * @stability stable
     */
    get maxSessionDuration(): number;
    /**
     * @stability stable
     */
    set maxSessionDuration(value: number);
    /**
     * @stability stable
     */
    resetMaxSessionDuration(): void;
    /**
     * @stability stable
     */
    get maxSessionDurationInput(): number | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namePrefix?;
    /**
     * @stability stable
     */
    get namePrefix(): string;
    /**
     * @stability stable
     */
    set namePrefix(value: string);
    /**
     * @stability stable
     */
    resetNamePrefix(): void;
    /**
     * @stability stable
     */
    get namePrefixInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _permissionsBoundary?;
    /**
     * @stability stable
     */
    get permissionsBoundary(): string;
    /**
     * @stability stable
     */
    set permissionsBoundary(value: string);
    /**
     * @stability stable
     */
    resetPermissionsBoundary(): void;
    /**
     * @stability stable
     */
    get permissionsBoundaryInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get uniqueId(): string;
    private _inlinePolicy?;
    /**
     * @stability stable
     */
    get inlinePolicy(): IamRoleInlinePolicy[];
    /**
     * @stability stable
     */
    set inlinePolicy(value: IamRoleInlinePolicy[]);
    /**
     * @stability stable
     */
    resetInlinePolicy(): void;
    /**
     * @stability stable
     */
    get inlinePolicyInput(): IamRoleInlinePolicy[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
