import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Kinesis.
 *
 * @stability stable
 */
export interface KinesisStreamConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kinesis_stream#encryption_type KinesisStream#encryption_type}.
     *
     * @stability stable
     */
    readonly encryptionType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kinesis_stream#enforce_consumer_deletion KinesisStream#enforce_consumer_deletion}.
     *
     * @stability stable
     */
    readonly enforceConsumerDeletion?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kinesis_stream#kms_key_id KinesisStream#kms_key_id}.
     *
     * @stability stable
     */
    readonly kmsKeyId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kinesis_stream#name KinesisStream#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kinesis_stream#retention_period KinesisStream#retention_period}.
     *
     * @stability stable
     */
    readonly retentionPeriod?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kinesis_stream#shard_count KinesisStream#shard_count}.
     *
     * @stability stable
     */
    readonly shardCount?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kinesis_stream#shard_level_metrics KinesisStream#shard_level_metrics}.
     *
     * @stability stable
     */
    readonly shardLevelMetrics?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kinesis_stream#tags KinesisStream#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kinesis_stream#tags_all KinesisStream#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * stream_mode_details block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kinesis_stream#stream_mode_details KinesisStream#stream_mode_details}
     *
     * @stability stable
     */
    readonly streamModeDetails?: KinesisStreamStreamModeDetails;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kinesis_stream#timeouts KinesisStream#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: KinesisStreamTimeouts;
}
/**
 * @stability stable
 */
export interface KinesisStreamStreamModeDetails {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kinesis_stream#stream_mode KinesisStream#stream_mode}.
     *
     * @stability stable
     */
    readonly streamMode: string;
}
export declare function kinesisStreamStreamModeDetailsToTerraform(struct?: KinesisStreamStreamModeDetailsOutputReference | KinesisStreamStreamModeDetails): any;
/**
 * @stability stable
 */
export declare class KinesisStreamStreamModeDetailsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): KinesisStreamStreamModeDetails | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: KinesisStreamStreamModeDetails | undefined);
    private _streamMode?;
    /**
     * @stability stable
     */
    get streamMode(): string;
    /**
     * @stability stable
     */
    set streamMode(value: string);
    /**
     * @stability stable
     */
    get streamModeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface KinesisStreamTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kinesis_stream#create KinesisStream#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kinesis_stream#delete KinesisStream#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kinesis_stream#update KinesisStream#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function kinesisStreamTimeoutsToTerraform(struct?: KinesisStreamTimeoutsOutputReference | KinesisStreamTimeouts): any;
/**
 * @stability stable
 */
export declare class KinesisStreamTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): KinesisStreamTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: KinesisStreamTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/kinesis_stream aws_kinesis_stream}.
 *
 * @stability stable
 */
export declare class KinesisStream extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/kinesis_stream aws_kinesis_stream} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: KinesisStreamConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _encryptionType?;
    /**
     * @stability stable
     */
    get encryptionType(): string;
    /**
     * @stability stable
     */
    set encryptionType(value: string);
    /**
     * @stability stable
     */
    resetEncryptionType(): void;
    /**
     * @stability stable
     */
    get encryptionTypeInput(): string | undefined;
    private _enforceConsumerDeletion?;
    /**
     * @stability stable
     */
    get enforceConsumerDeletion(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enforceConsumerDeletion(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnforceConsumerDeletion(): void;
    /**
     * @stability stable
     */
    get enforceConsumerDeletionInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _kmsKeyId?;
    /**
     * @stability stable
     */
    get kmsKeyId(): string;
    /**
     * @stability stable
     */
    set kmsKeyId(value: string);
    /**
     * @stability stable
     */
    resetKmsKeyId(): void;
    /**
     * @stability stable
     */
    get kmsKeyIdInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _retentionPeriod?;
    /**
     * @stability stable
     */
    get retentionPeriod(): number;
    /**
     * @stability stable
     */
    set retentionPeriod(value: number);
    /**
     * @stability stable
     */
    resetRetentionPeriod(): void;
    /**
     * @stability stable
     */
    get retentionPeriodInput(): number | undefined;
    private _shardCount?;
    /**
     * @stability stable
     */
    get shardCount(): number;
    /**
     * @stability stable
     */
    set shardCount(value: number);
    /**
     * @stability stable
     */
    resetShardCount(): void;
    /**
     * @stability stable
     */
    get shardCountInput(): number | undefined;
    private _shardLevelMetrics?;
    /**
     * @stability stable
     */
    get shardLevelMetrics(): string[];
    /**
     * @stability stable
     */
    set shardLevelMetrics(value: string[]);
    /**
     * @stability stable
     */
    resetShardLevelMetrics(): void;
    /**
     * @stability stable
     */
    get shardLevelMetricsInput(): string[] | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _streamModeDetails;
    /**
     * @stability stable
     */
    get streamModeDetails(): KinesisStreamStreamModeDetailsOutputReference;
    /**
     * @stability stable
     */
    putStreamModeDetails(value: KinesisStreamStreamModeDetails): void;
    /**
     * @stability stable
     */
    resetStreamModeDetails(): void;
    /**
     * @stability stable
     */
    get streamModeDetailsInput(): KinesisStreamStreamModeDetails | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): KinesisStreamTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: KinesisStreamTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): KinesisStreamTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
