import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Lambda.
 *
 * @stability stable
 */
export interface LambdaLayerVersionConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version#compatible_architectures LambdaLayerVersion#compatible_architectures}.
     *
     * @stability stable
     */
    readonly compatibleArchitectures?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version#compatible_runtimes LambdaLayerVersion#compatible_runtimes}.
     *
     * @stability stable
     */
    readonly compatibleRuntimes?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version#description LambdaLayerVersion#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version#filename LambdaLayerVersion#filename}.
     *
     * @stability stable
     */
    readonly filename?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version#layer_name LambdaLayerVersion#layer_name}.
     *
     * @stability stable
     */
    readonly layerName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version#license_info LambdaLayerVersion#license_info}.
     *
     * @stability stable
     */
    readonly licenseInfo?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version#s3_bucket LambdaLayerVersion#s3_bucket}.
     *
     * @stability stable
     */
    readonly s3Bucket?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version#s3_key LambdaLayerVersion#s3_key}.
     *
     * @stability stable
     */
    readonly s3Key?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version#s3_object_version LambdaLayerVersion#s3_object_version}.
     *
     * @stability stable
     */
    readonly s3ObjectVersion?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version#skip_destroy LambdaLayerVersion#skip_destroy}.
     *
     * @stability stable
     */
    readonly skipDestroy?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version#source_code_hash LambdaLayerVersion#source_code_hash}.
     *
     * @stability stable
     */
    readonly sourceCodeHash?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version aws_lambda_layer_version}.
 *
 * @stability stable
 */
export declare class LambdaLayerVersion extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version aws_lambda_layer_version} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: LambdaLayerVersionConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _compatibleArchitectures?;
    /**
     * @stability stable
     */
    get compatibleArchitectures(): string[];
    /**
     * @stability stable
     */
    set compatibleArchitectures(value: string[]);
    /**
     * @stability stable
     */
    resetCompatibleArchitectures(): void;
    /**
     * @stability stable
     */
    get compatibleArchitecturesInput(): string[] | undefined;
    private _compatibleRuntimes?;
    /**
     * @stability stable
     */
    get compatibleRuntimes(): string[];
    /**
     * @stability stable
     */
    set compatibleRuntimes(value: string[]);
    /**
     * @stability stable
     */
    resetCompatibleRuntimes(): void;
    /**
     * @stability stable
     */
    get compatibleRuntimesInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get createdDate(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _filename?;
    /**
     * @stability stable
     */
    get filename(): string;
    /**
     * @stability stable
     */
    set filename(value: string);
    /**
     * @stability stable
     */
    resetFilename(): void;
    /**
     * @stability stable
     */
    get filenameInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get layerArn(): string;
    private _layerName?;
    /**
     * @stability stable
     */
    get layerName(): string;
    /**
     * @stability stable
     */
    set layerName(value: string);
    /**
     * @stability stable
     */
    get layerNameInput(): string | undefined;
    private _licenseInfo?;
    /**
     * @stability stable
     */
    get licenseInfo(): string;
    /**
     * @stability stable
     */
    set licenseInfo(value: string);
    /**
     * @stability stable
     */
    resetLicenseInfo(): void;
    /**
     * @stability stable
     */
    get licenseInfoInput(): string | undefined;
    private _s3Bucket?;
    /**
     * @stability stable
     */
    get s3Bucket(): string;
    /**
     * @stability stable
     */
    set s3Bucket(value: string);
    /**
     * @stability stable
     */
    resetS3Bucket(): void;
    /**
     * @stability stable
     */
    get s3BucketInput(): string | undefined;
    private _s3Key?;
    /**
     * @stability stable
     */
    get s3Key(): string;
    /**
     * @stability stable
     */
    set s3Key(value: string);
    /**
     * @stability stable
     */
    resetS3Key(): void;
    /**
     * @stability stable
     */
    get s3KeyInput(): string | undefined;
    private _s3ObjectVersion?;
    /**
     * @stability stable
     */
    get s3ObjectVersion(): string;
    /**
     * @stability stable
     */
    set s3ObjectVersion(value: string);
    /**
     * @stability stable
     */
    resetS3ObjectVersion(): void;
    /**
     * @stability stable
     */
    get s3ObjectVersionInput(): string | undefined;
    /**
     * @stability stable
     */
    get signingJobArn(): string;
    /**
     * @stability stable
     */
    get signingProfileVersionArn(): string;
    private _skipDestroy?;
    /**
     * @stability stable
     */
    get skipDestroy(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set skipDestroy(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetSkipDestroy(): void;
    /**
     * @stability stable
     */
    get skipDestroyInput(): boolean | cdktf.IResolvable | undefined;
    private _sourceCodeHash?;
    /**
     * @stability stable
     */
    get sourceCodeHash(): string;
    /**
     * @stability stable
     */
    set sourceCodeHash(value: string);
    /**
     * @stability stable
     */
    resetSourceCodeHash(): void;
    /**
     * @stability stable
     */
    get sourceCodeHashInput(): string | undefined;
    /**
     * @stability stable
     */
    get sourceCodeSize(): number;
    /**
     * @stability stable
     */
    get version(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
