import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Managed Streaming for Kafka.
 *
 * @stability stable
 */
export interface MskClusterConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#cluster_name MskCluster#cluster_name}.
     *
     * @stability stable
     */
    readonly clusterName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#enhanced_monitoring MskCluster#enhanced_monitoring}.
     *
     * @stability stable
     */
    readonly enhancedMonitoring?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#kafka_version MskCluster#kafka_version}.
     *
     * @stability stable
     */
    readonly kafkaVersion: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#number_of_broker_nodes MskCluster#number_of_broker_nodes}.
     *
     * @stability stable
     */
    readonly numberOfBrokerNodes: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#tags MskCluster#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#tags_all MskCluster#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * broker_node_group_info block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#broker_node_group_info MskCluster#broker_node_group_info}
     *
     * @stability stable
     */
    readonly brokerNodeGroupInfo: MskClusterBrokerNodeGroupInfo;
    /**
     * client_authentication block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#client_authentication MskCluster#client_authentication}
     *
     * @stability stable
     */
    readonly clientAuthentication?: MskClusterClientAuthentication;
    /**
     * configuration_info block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#configuration_info MskCluster#configuration_info}
     *
     * @stability stable
     */
    readonly configurationInfo?: MskClusterConfigurationInfo;
    /**
     * encryption_info block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#encryption_info MskCluster#encryption_info}
     *
     * @stability stable
     */
    readonly encryptionInfo?: MskClusterEncryptionInfo;
    /**
     * logging_info block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#logging_info MskCluster#logging_info}
     *
     * @stability stable
     */
    readonly loggingInfo?: MskClusterLoggingInfo;
    /**
     * open_monitoring block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#open_monitoring MskCluster#open_monitoring}
     *
     * @stability stable
     */
    readonly openMonitoring?: MskClusterOpenMonitoring;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#timeouts MskCluster#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: MskClusterTimeouts;
}
/**
 * @stability stable
 */
export interface MskClusterBrokerNodeGroupInfo {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#az_distribution MskCluster#az_distribution}.
     *
     * @stability stable
     */
    readonly azDistribution?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#client_subnets MskCluster#client_subnets}.
     *
     * @stability stable
     */
    readonly clientSubnets: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#ebs_volume_size MskCluster#ebs_volume_size}.
     *
     * @stability stable
     */
    readonly ebsVolumeSize: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#instance_type MskCluster#instance_type}.
     *
     * @stability stable
     */
    readonly instanceType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#security_groups MskCluster#security_groups}.
     *
     * @stability stable
     */
    readonly securityGroups: string[];
}
export declare function mskClusterBrokerNodeGroupInfoToTerraform(struct?: MskClusterBrokerNodeGroupInfoOutputReference | MskClusterBrokerNodeGroupInfo): any;
/**
 * @stability stable
 */
export declare class MskClusterBrokerNodeGroupInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MskClusterBrokerNodeGroupInfo | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MskClusterBrokerNodeGroupInfo | undefined);
    private _azDistribution?;
    /**
     * @stability stable
     */
    get azDistribution(): string;
    /**
     * @stability stable
     */
    set azDistribution(value: string);
    /**
     * @stability stable
     */
    resetAzDistribution(): void;
    /**
     * @stability stable
     */
    get azDistributionInput(): string | undefined;
    private _clientSubnets?;
    /**
     * @stability stable
     */
    get clientSubnets(): string[];
    /**
     * @stability stable
     */
    set clientSubnets(value: string[]);
    /**
     * @stability stable
     */
    get clientSubnetsInput(): string[] | undefined;
    private _ebsVolumeSize?;
    /**
     * @stability stable
     */
    get ebsVolumeSize(): number;
    /**
     * @stability stable
     */
    set ebsVolumeSize(value: number);
    /**
     * @stability stable
     */
    get ebsVolumeSizeInput(): number | undefined;
    private _instanceType?;
    /**
     * @stability stable
     */
    get instanceType(): string;
    /**
     * @stability stable
     */
    set instanceType(value: string);
    /**
     * @stability stable
     */
    get instanceTypeInput(): string | undefined;
    private _securityGroups?;
    /**
     * @stability stable
     */
    get securityGroups(): string[];
    /**
     * @stability stable
     */
    set securityGroups(value: string[]);
    /**
     * @stability stable
     */
    get securityGroupsInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface MskClusterClientAuthenticationSasl {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#iam MskCluster#iam}.
     *
     * @stability stable
     */
    readonly iam?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#scram MskCluster#scram}.
     *
     * @stability stable
     */
    readonly scram?: boolean | cdktf.IResolvable;
}
export declare function mskClusterClientAuthenticationSaslToTerraform(struct?: MskClusterClientAuthenticationSaslOutputReference | MskClusterClientAuthenticationSasl): any;
/**
 * @stability stable
 */
export declare class MskClusterClientAuthenticationSaslOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MskClusterClientAuthenticationSasl | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MskClusterClientAuthenticationSasl | undefined);
    private _iam?;
    /**
     * @stability stable
     */
    get iam(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set iam(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIam(): void;
    /**
     * @stability stable
     */
    get iamInput(): boolean | cdktf.IResolvable | undefined;
    private _scram?;
    /**
     * @stability stable
     */
    get scram(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set scram(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetScram(): void;
    /**
     * @stability stable
     */
    get scramInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface MskClusterClientAuthenticationTls {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#certificate_authority_arns MskCluster#certificate_authority_arns}.
     *
     * @stability stable
     */
    readonly certificateAuthorityArns?: string[];
}
export declare function mskClusterClientAuthenticationTlsToTerraform(struct?: MskClusterClientAuthenticationTlsOutputReference | MskClusterClientAuthenticationTls): any;
/**
 * @stability stable
 */
export declare class MskClusterClientAuthenticationTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MskClusterClientAuthenticationTls | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MskClusterClientAuthenticationTls | undefined);
    private _certificateAuthorityArns?;
    /**
     * @stability stable
     */
    get certificateAuthorityArns(): string[];
    /**
     * @stability stable
     */
    set certificateAuthorityArns(value: string[]);
    /**
     * @stability stable
     */
    resetCertificateAuthorityArns(): void;
    /**
     * @stability stable
     */
    get certificateAuthorityArnsInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface MskClusterClientAuthentication {
    /**
     * sasl block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#sasl MskCluster#sasl}
     *
     * @stability stable
     */
    readonly sasl?: MskClusterClientAuthenticationSasl;
    /**
     * tls block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#tls MskCluster#tls}
     *
     * @stability stable
     */
    readonly tls?: MskClusterClientAuthenticationTls;
}
export declare function mskClusterClientAuthenticationToTerraform(struct?: MskClusterClientAuthenticationOutputReference | MskClusterClientAuthentication): any;
/**
 * @stability stable
 */
export declare class MskClusterClientAuthenticationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MskClusterClientAuthentication | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MskClusterClientAuthentication | undefined);
    private _sasl;
    /**
     * @stability stable
     */
    get sasl(): MskClusterClientAuthenticationSaslOutputReference;
    /**
     * @stability stable
     */
    putSasl(value: MskClusterClientAuthenticationSasl): void;
    /**
     * @stability stable
     */
    resetSasl(): void;
    /**
     * @stability stable
     */
    get saslInput(): MskClusterClientAuthenticationSasl | undefined;
    private _tls;
    /**
     * @stability stable
     */
    get tls(): MskClusterClientAuthenticationTlsOutputReference;
    /**
     * @stability stable
     */
    putTls(value: MskClusterClientAuthenticationTls): void;
    /**
     * @stability stable
     */
    resetTls(): void;
    /**
     * @stability stable
     */
    get tlsInput(): MskClusterClientAuthenticationTls | undefined;
}
/**
 * @stability stable
 */
export interface MskClusterConfigurationInfo {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#arn MskCluster#arn}.
     *
     * @stability stable
     */
    readonly arn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#revision MskCluster#revision}.
     *
     * @stability stable
     */
    readonly revision: number;
}
export declare function mskClusterConfigurationInfoToTerraform(struct?: MskClusterConfigurationInfoOutputReference | MskClusterConfigurationInfo): any;
/**
 * @stability stable
 */
export declare class MskClusterConfigurationInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MskClusterConfigurationInfo | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MskClusterConfigurationInfo | undefined);
    private _arn?;
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    set arn(value: string);
    /**
     * @stability stable
     */
    get arnInput(): string | undefined;
    private _revision?;
    /**
     * @stability stable
     */
    get revision(): number;
    /**
     * @stability stable
     */
    set revision(value: number);
    /**
     * @stability stable
     */
    get revisionInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface MskClusterEncryptionInfoEncryptionInTransit {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#client_broker MskCluster#client_broker}.
     *
     * @stability stable
     */
    readonly clientBroker?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#in_cluster MskCluster#in_cluster}.
     *
     * @stability stable
     */
    readonly inCluster?: boolean | cdktf.IResolvable;
}
export declare function mskClusterEncryptionInfoEncryptionInTransitToTerraform(struct?: MskClusterEncryptionInfoEncryptionInTransitOutputReference | MskClusterEncryptionInfoEncryptionInTransit): any;
/**
 * @stability stable
 */
export declare class MskClusterEncryptionInfoEncryptionInTransitOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MskClusterEncryptionInfoEncryptionInTransit | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MskClusterEncryptionInfoEncryptionInTransit | undefined);
    private _clientBroker?;
    /**
     * @stability stable
     */
    get clientBroker(): string;
    /**
     * @stability stable
     */
    set clientBroker(value: string);
    /**
     * @stability stable
     */
    resetClientBroker(): void;
    /**
     * @stability stable
     */
    get clientBrokerInput(): string | undefined;
    private _inCluster?;
    /**
     * @stability stable
     */
    get inCluster(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set inCluster(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetInCluster(): void;
    /**
     * @stability stable
     */
    get inClusterInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface MskClusterEncryptionInfo {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#encryption_at_rest_kms_key_arn MskCluster#encryption_at_rest_kms_key_arn}.
     *
     * @stability stable
     */
    readonly encryptionAtRestKmsKeyArn?: string;
    /**
     * encryption_in_transit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#encryption_in_transit MskCluster#encryption_in_transit}
     *
     * @stability stable
     */
    readonly encryptionInTransit?: MskClusterEncryptionInfoEncryptionInTransit;
}
export declare function mskClusterEncryptionInfoToTerraform(struct?: MskClusterEncryptionInfoOutputReference | MskClusterEncryptionInfo): any;
/**
 * @stability stable
 */
export declare class MskClusterEncryptionInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MskClusterEncryptionInfo | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MskClusterEncryptionInfo | undefined);
    private _encryptionAtRestKmsKeyArn?;
    /**
     * @stability stable
     */
    get encryptionAtRestKmsKeyArn(): string;
    /**
     * @stability stable
     */
    set encryptionAtRestKmsKeyArn(value: string);
    /**
     * @stability stable
     */
    resetEncryptionAtRestKmsKeyArn(): void;
    /**
     * @stability stable
     */
    get encryptionAtRestKmsKeyArnInput(): string | undefined;
    private _encryptionInTransit;
    /**
     * @stability stable
     */
    get encryptionInTransit(): MskClusterEncryptionInfoEncryptionInTransitOutputReference;
    /**
     * @stability stable
     */
    putEncryptionInTransit(value: MskClusterEncryptionInfoEncryptionInTransit): void;
    /**
     * @stability stable
     */
    resetEncryptionInTransit(): void;
    /**
     * @stability stable
     */
    get encryptionInTransitInput(): MskClusterEncryptionInfoEncryptionInTransit | undefined;
}
/**
 * @stability stable
 */
export interface MskClusterLoggingInfoBrokerLogsCloudwatchLogs {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#enabled MskCluster#enabled}.
     *
     * @stability stable
     */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#log_group MskCluster#log_group}.
     *
     * @stability stable
     */
    readonly logGroup?: string;
}
export declare function mskClusterLoggingInfoBrokerLogsCloudwatchLogsToTerraform(struct?: MskClusterLoggingInfoBrokerLogsCloudwatchLogsOutputReference | MskClusterLoggingInfoBrokerLogsCloudwatchLogs): any;
/**
 * @stability stable
 */
export declare class MskClusterLoggingInfoBrokerLogsCloudwatchLogsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MskClusterLoggingInfoBrokerLogsCloudwatchLogs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MskClusterLoggingInfoBrokerLogsCloudwatchLogs | undefined);
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _logGroup?;
    /**
     * @stability stable
     */
    get logGroup(): string;
    /**
     * @stability stable
     */
    set logGroup(value: string);
    /**
     * @stability stable
     */
    resetLogGroup(): void;
    /**
     * @stability stable
     */
    get logGroupInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface MskClusterLoggingInfoBrokerLogsFirehose {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#delivery_stream MskCluster#delivery_stream}.
     *
     * @stability stable
     */
    readonly deliveryStream?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#enabled MskCluster#enabled}.
     *
     * @stability stable
     */
    readonly enabled: boolean | cdktf.IResolvable;
}
export declare function mskClusterLoggingInfoBrokerLogsFirehoseToTerraform(struct?: MskClusterLoggingInfoBrokerLogsFirehoseOutputReference | MskClusterLoggingInfoBrokerLogsFirehose): any;
/**
 * @stability stable
 */
export declare class MskClusterLoggingInfoBrokerLogsFirehoseOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MskClusterLoggingInfoBrokerLogsFirehose | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MskClusterLoggingInfoBrokerLogsFirehose | undefined);
    private _deliveryStream?;
    /**
     * @stability stable
     */
    get deliveryStream(): string;
    /**
     * @stability stable
     */
    set deliveryStream(value: string);
    /**
     * @stability stable
     */
    resetDeliveryStream(): void;
    /**
     * @stability stable
     */
    get deliveryStreamInput(): string | undefined;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface MskClusterLoggingInfoBrokerLogsS3 {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#bucket MskCluster#bucket}.
     *
     * @stability stable
     */
    readonly bucket?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#enabled MskCluster#enabled}.
     *
     * @stability stable
     */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#prefix MskCluster#prefix}.
     *
     * @stability stable
     */
    readonly prefix?: string;
}
export declare function mskClusterLoggingInfoBrokerLogsS3ToTerraform(struct?: MskClusterLoggingInfoBrokerLogsS3OutputReference | MskClusterLoggingInfoBrokerLogsS3): any;
/**
 * @stability stable
 */
export declare class MskClusterLoggingInfoBrokerLogsS3OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MskClusterLoggingInfoBrokerLogsS3 | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MskClusterLoggingInfoBrokerLogsS3 | undefined);
    private _bucket?;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    resetBucket(): void;
    /**
     * @stability stable
     */
    get bucketInput(): string | undefined;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _prefix?;
    /**
     * @stability stable
     */
    get prefix(): string;
    /**
     * @stability stable
     */
    set prefix(value: string);
    /**
     * @stability stable
     */
    resetPrefix(): void;
    /**
     * @stability stable
     */
    get prefixInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface MskClusterLoggingInfoBrokerLogs {
    /**
     * cloudwatch_logs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#cloudwatch_logs MskCluster#cloudwatch_logs}
     *
     * @stability stable
     */
    readonly cloudwatchLogs?: MskClusterLoggingInfoBrokerLogsCloudwatchLogs;
    /**
     * firehose block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#firehose MskCluster#firehose}
     *
     * @stability stable
     */
    readonly firehose?: MskClusterLoggingInfoBrokerLogsFirehose;
    /**
     * s3 block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#s3 MskCluster#s3}
     *
     * @stability stable
     */
    readonly s3?: MskClusterLoggingInfoBrokerLogsS3;
}
export declare function mskClusterLoggingInfoBrokerLogsToTerraform(struct?: MskClusterLoggingInfoBrokerLogsOutputReference | MskClusterLoggingInfoBrokerLogs): any;
/**
 * @stability stable
 */
export declare class MskClusterLoggingInfoBrokerLogsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MskClusterLoggingInfoBrokerLogs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MskClusterLoggingInfoBrokerLogs | undefined);
    private _cloudwatchLogs;
    /**
     * @stability stable
     */
    get cloudwatchLogs(): MskClusterLoggingInfoBrokerLogsCloudwatchLogsOutputReference;
    /**
     * @stability stable
     */
    putCloudwatchLogs(value: MskClusterLoggingInfoBrokerLogsCloudwatchLogs): void;
    /**
     * @stability stable
     */
    resetCloudwatchLogs(): void;
    /**
     * @stability stable
     */
    get cloudwatchLogsInput(): MskClusterLoggingInfoBrokerLogsCloudwatchLogs | undefined;
    private _firehose;
    /**
     * @stability stable
     */
    get firehose(): MskClusterLoggingInfoBrokerLogsFirehoseOutputReference;
    /**
     * @stability stable
     */
    putFirehose(value: MskClusterLoggingInfoBrokerLogsFirehose): void;
    /**
     * @stability stable
     */
    resetFirehose(): void;
    /**
     * @stability stable
     */
    get firehoseInput(): MskClusterLoggingInfoBrokerLogsFirehose | undefined;
    private _s3;
    /**
     * @stability stable
     */
    get s3(): MskClusterLoggingInfoBrokerLogsS3OutputReference;
    /**
     * @stability stable
     */
    putS3(value: MskClusterLoggingInfoBrokerLogsS3): void;
    /**
     * @stability stable
     */
    resetS3(): void;
    /**
     * @stability stable
     */
    get s3Input(): MskClusterLoggingInfoBrokerLogsS3 | undefined;
}
/**
 * @stability stable
 */
export interface MskClusterLoggingInfo {
    /**
     * broker_logs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#broker_logs MskCluster#broker_logs}
     *
     * @stability stable
     */
    readonly brokerLogs: MskClusterLoggingInfoBrokerLogs;
}
export declare function mskClusterLoggingInfoToTerraform(struct?: MskClusterLoggingInfoOutputReference | MskClusterLoggingInfo): any;
/**
 * @stability stable
 */
export declare class MskClusterLoggingInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MskClusterLoggingInfo | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MskClusterLoggingInfo | undefined);
    private _brokerLogs;
    /**
     * @stability stable
     */
    get brokerLogs(): MskClusterLoggingInfoBrokerLogsOutputReference;
    /**
     * @stability stable
     */
    putBrokerLogs(value: MskClusterLoggingInfoBrokerLogs): void;
    /**
     * @stability stable
     */
    get brokerLogsInput(): MskClusterLoggingInfoBrokerLogs | undefined;
}
/**
 * @stability stable
 */
export interface MskClusterOpenMonitoringPrometheusJmxExporter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#enabled_in_broker MskCluster#enabled_in_broker}.
     *
     * @stability stable
     */
    readonly enabledInBroker: boolean | cdktf.IResolvable;
}
export declare function mskClusterOpenMonitoringPrometheusJmxExporterToTerraform(struct?: MskClusterOpenMonitoringPrometheusJmxExporterOutputReference | MskClusterOpenMonitoringPrometheusJmxExporter): any;
/**
 * @stability stable
 */
export declare class MskClusterOpenMonitoringPrometheusJmxExporterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MskClusterOpenMonitoringPrometheusJmxExporter | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MskClusterOpenMonitoringPrometheusJmxExporter | undefined);
    private _enabledInBroker?;
    /**
     * @stability stable
     */
    get enabledInBroker(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabledInBroker(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get enabledInBrokerInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface MskClusterOpenMonitoringPrometheusNodeExporter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#enabled_in_broker MskCluster#enabled_in_broker}.
     *
     * @stability stable
     */
    readonly enabledInBroker: boolean | cdktf.IResolvable;
}
export declare function mskClusterOpenMonitoringPrometheusNodeExporterToTerraform(struct?: MskClusterOpenMonitoringPrometheusNodeExporterOutputReference | MskClusterOpenMonitoringPrometheusNodeExporter): any;
/**
 * @stability stable
 */
export declare class MskClusterOpenMonitoringPrometheusNodeExporterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MskClusterOpenMonitoringPrometheusNodeExporter | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MskClusterOpenMonitoringPrometheusNodeExporter | undefined);
    private _enabledInBroker?;
    /**
     * @stability stable
     */
    get enabledInBroker(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabledInBroker(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get enabledInBrokerInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface MskClusterOpenMonitoringPrometheus {
    /**
     * jmx_exporter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#jmx_exporter MskCluster#jmx_exporter}
     *
     * @stability stable
     */
    readonly jmxExporter?: MskClusterOpenMonitoringPrometheusJmxExporter;
    /**
     * node_exporter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#node_exporter MskCluster#node_exporter}
     *
     * @stability stable
     */
    readonly nodeExporter?: MskClusterOpenMonitoringPrometheusNodeExporter;
}
export declare function mskClusterOpenMonitoringPrometheusToTerraform(struct?: MskClusterOpenMonitoringPrometheusOutputReference | MskClusterOpenMonitoringPrometheus): any;
/**
 * @stability stable
 */
export declare class MskClusterOpenMonitoringPrometheusOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MskClusterOpenMonitoringPrometheus | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MskClusterOpenMonitoringPrometheus | undefined);
    private _jmxExporter;
    /**
     * @stability stable
     */
    get jmxExporter(): MskClusterOpenMonitoringPrometheusJmxExporterOutputReference;
    /**
     * @stability stable
     */
    putJmxExporter(value: MskClusterOpenMonitoringPrometheusJmxExporter): void;
    /**
     * @stability stable
     */
    resetJmxExporter(): void;
    /**
     * @stability stable
     */
    get jmxExporterInput(): MskClusterOpenMonitoringPrometheusJmxExporter | undefined;
    private _nodeExporter;
    /**
     * @stability stable
     */
    get nodeExporter(): MskClusterOpenMonitoringPrometheusNodeExporterOutputReference;
    /**
     * @stability stable
     */
    putNodeExporter(value: MskClusterOpenMonitoringPrometheusNodeExporter): void;
    /**
     * @stability stable
     */
    resetNodeExporter(): void;
    /**
     * @stability stable
     */
    get nodeExporterInput(): MskClusterOpenMonitoringPrometheusNodeExporter | undefined;
}
/**
 * @stability stable
 */
export interface MskClusterOpenMonitoring {
    /**
     * prometheus block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#prometheus MskCluster#prometheus}
     *
     * @stability stable
     */
    readonly prometheus: MskClusterOpenMonitoringPrometheus;
}
export declare function mskClusterOpenMonitoringToTerraform(struct?: MskClusterOpenMonitoringOutputReference | MskClusterOpenMonitoring): any;
/**
 * @stability stable
 */
export declare class MskClusterOpenMonitoringOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MskClusterOpenMonitoring | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MskClusterOpenMonitoring | undefined);
    private _prometheus;
    /**
     * @stability stable
     */
    get prometheus(): MskClusterOpenMonitoringPrometheusOutputReference;
    /**
     * @stability stable
     */
    putPrometheus(value: MskClusterOpenMonitoringPrometheus): void;
    /**
     * @stability stable
     */
    get prometheusInput(): MskClusterOpenMonitoringPrometheus | undefined;
}
/**
 * @stability stable
 */
export interface MskClusterTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#create MskCluster#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#delete MskCluster#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#update MskCluster#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function mskClusterTimeoutsToTerraform(struct?: MskClusterTimeoutsOutputReference | MskClusterTimeouts): any;
/**
 * @stability stable
 */
export declare class MskClusterTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MskClusterTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MskClusterTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster aws_msk_cluster}.
 *
 * @stability stable
 */
export declare class MskCluster extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster aws_msk_cluster} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: MskClusterConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get bootstrapBrokers(): string;
    /**
     * @stability stable
     */
    get bootstrapBrokersSaslIam(): string;
    /**
     * @stability stable
     */
    get bootstrapBrokersSaslScram(): string;
    /**
     * @stability stable
     */
    get bootstrapBrokersTls(): string;
    private _clusterName?;
    /**
     * @stability stable
     */
    get clusterName(): string;
    /**
     * @stability stable
     */
    set clusterName(value: string);
    /**
     * @stability stable
     */
    get clusterNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get currentVersion(): string;
    private _enhancedMonitoring?;
    /**
     * @stability stable
     */
    get enhancedMonitoring(): string;
    /**
     * @stability stable
     */
    set enhancedMonitoring(value: string);
    /**
     * @stability stable
     */
    resetEnhancedMonitoring(): void;
    /**
     * @stability stable
     */
    get enhancedMonitoringInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _kafkaVersion?;
    /**
     * @stability stable
     */
    get kafkaVersion(): string;
    /**
     * @stability stable
     */
    set kafkaVersion(value: string);
    /**
     * @stability stable
     */
    get kafkaVersionInput(): string | undefined;
    private _numberOfBrokerNodes?;
    /**
     * @stability stable
     */
    get numberOfBrokerNodes(): number;
    /**
     * @stability stable
     */
    set numberOfBrokerNodes(value: number);
    /**
     * @stability stable
     */
    get numberOfBrokerNodesInput(): number | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get zookeeperConnectString(): string;
    /**
     * @stability stable
     */
    get zookeeperConnectStringTls(): string;
    private _brokerNodeGroupInfo;
    /**
     * @stability stable
     */
    get brokerNodeGroupInfo(): MskClusterBrokerNodeGroupInfoOutputReference;
    /**
     * @stability stable
     */
    putBrokerNodeGroupInfo(value: MskClusterBrokerNodeGroupInfo): void;
    /**
     * @stability stable
     */
    get brokerNodeGroupInfoInput(): MskClusterBrokerNodeGroupInfo | undefined;
    private _clientAuthentication;
    /**
     * @stability stable
     */
    get clientAuthentication(): MskClusterClientAuthenticationOutputReference;
    /**
     * @stability stable
     */
    putClientAuthentication(value: MskClusterClientAuthentication): void;
    /**
     * @stability stable
     */
    resetClientAuthentication(): void;
    /**
     * @stability stable
     */
    get clientAuthenticationInput(): MskClusterClientAuthentication | undefined;
    private _configurationInfo;
    /**
     * @stability stable
     */
    get configurationInfo(): MskClusterConfigurationInfoOutputReference;
    /**
     * @stability stable
     */
    putConfigurationInfo(value: MskClusterConfigurationInfo): void;
    /**
     * @stability stable
     */
    resetConfigurationInfo(): void;
    /**
     * @stability stable
     */
    get configurationInfoInput(): MskClusterConfigurationInfo | undefined;
    private _encryptionInfo;
    /**
     * @stability stable
     */
    get encryptionInfo(): MskClusterEncryptionInfoOutputReference;
    /**
     * @stability stable
     */
    putEncryptionInfo(value: MskClusterEncryptionInfo): void;
    /**
     * @stability stable
     */
    resetEncryptionInfo(): void;
    /**
     * @stability stable
     */
    get encryptionInfoInput(): MskClusterEncryptionInfo | undefined;
    private _loggingInfo;
    /**
     * @stability stable
     */
    get loggingInfo(): MskClusterLoggingInfoOutputReference;
    /**
     * @stability stable
     */
    putLoggingInfo(value: MskClusterLoggingInfo): void;
    /**
     * @stability stable
     */
    resetLoggingInfo(): void;
    /**
     * @stability stable
     */
    get loggingInfoInput(): MskClusterLoggingInfo | undefined;
    private _openMonitoring;
    /**
     * @stability stable
     */
    get openMonitoring(): MskClusterOpenMonitoringOutputReference;
    /**
     * @stability stable
     */
    putOpenMonitoring(value: MskClusterOpenMonitoring): void;
    /**
     * @stability stable
     */
    resetOpenMonitoring(): void;
    /**
     * @stability stable
     */
    get openMonitoringInput(): MskClusterOpenMonitoring | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): MskClusterTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: MskClusterTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): MskClusterTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
