import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Simple Storage Service.
 *
 * @stability stable
 */
export interface S3BucketNotificationConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#bucket S3BucketNotification#bucket}.
     *
     * @stability stable
     */
    readonly bucket: string;
    /**
     * lambda_function block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#lambda_function S3BucketNotification#lambda_function}
     *
     * @stability stable
     */
    readonly lambdaFunction?: S3BucketNotificationLambdaFunction[];
    /**
     * queue block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#queue S3BucketNotification#queue}
     *
     * @stability stable
     */
    readonly queue?: S3BucketNotificationQueue[];
    /**
     * topic block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#topic S3BucketNotification#topic}
     *
     * @stability stable
     */
    readonly topic?: S3BucketNotificationTopic[];
}
/**
 * @stability stable
 */
export interface S3BucketNotificationLambdaFunction {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#events S3BucketNotification#events}.
     *
     * @stability stable
     */
    readonly events: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#filter_prefix S3BucketNotification#filter_prefix}.
     *
     * @stability stable
     */
    readonly filterPrefix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#filter_suffix S3BucketNotification#filter_suffix}.
     *
     * @stability stable
     */
    readonly filterSuffix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#id S3BucketNotification#id}.
     *
     * @stability stable
     */
    readonly id?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#lambda_function_arn S3BucketNotification#lambda_function_arn}.
     *
     * @stability stable
     */
    readonly lambdaFunctionArn?: string;
}
export declare function s3BucketNotificationLambdaFunctionToTerraform(struct?: S3BucketNotificationLambdaFunction): any;
/**
 * @stability stable
 */
export interface S3BucketNotificationQueue {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#events S3BucketNotification#events}.
     *
     * @stability stable
     */
    readonly events: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#filter_prefix S3BucketNotification#filter_prefix}.
     *
     * @stability stable
     */
    readonly filterPrefix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#filter_suffix S3BucketNotification#filter_suffix}.
     *
     * @stability stable
     */
    readonly filterSuffix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#id S3BucketNotification#id}.
     *
     * @stability stable
     */
    readonly id?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#queue_arn S3BucketNotification#queue_arn}.
     *
     * @stability stable
     */
    readonly queueArn: string;
}
export declare function s3BucketNotificationQueueToTerraform(struct?: S3BucketNotificationQueue): any;
/**
 * @stability stable
 */
export interface S3BucketNotificationTopic {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#events S3BucketNotification#events}.
     *
     * @stability stable
     */
    readonly events: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#filter_prefix S3BucketNotification#filter_prefix}.
     *
     * @stability stable
     */
    readonly filterPrefix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#filter_suffix S3BucketNotification#filter_suffix}.
     *
     * @stability stable
     */
    readonly filterSuffix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#id S3BucketNotification#id}.
     *
     * @stability stable
     */
    readonly id?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification#topic_arn S3BucketNotification#topic_arn}.
     *
     * @stability stable
     */
    readonly topicArn: string;
}
export declare function s3BucketNotificationTopicToTerraform(struct?: S3BucketNotificationTopic): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification aws_s3_bucket_notification}.
 *
 * @stability stable
 */
export declare class S3BucketNotification extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification aws_s3_bucket_notification} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: S3BucketNotificationConfig);
    private _bucket?;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    get bucketInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _lambdaFunction?;
    /**
     * @stability stable
     */
    get lambdaFunction(): S3BucketNotificationLambdaFunction[];
    /**
     * @stability stable
     */
    set lambdaFunction(value: S3BucketNotificationLambdaFunction[]);
    /**
     * @stability stable
     */
    resetLambdaFunction(): void;
    /**
     * @stability stable
     */
    get lambdaFunctionInput(): S3BucketNotificationLambdaFunction[] | undefined;
    private _queue?;
    /**
     * @stability stable
     */
    get queue(): S3BucketNotificationQueue[];
    /**
     * @stability stable
     */
    set queue(value: S3BucketNotificationQueue[]);
    /**
     * @stability stable
     */
    resetQueue(): void;
    /**
     * @stability stable
     */
    get queueInput(): S3BucketNotificationQueue[] | undefined;
    private _topic?;
    /**
     * @stability stable
     */
    get topic(): S3BucketNotificationTopic[];
    /**
     * @stability stable
     */
    set topic(value: S3BucketNotificationTopic[]);
    /**
     * @stability stable
     */
    resetTopic(): void;
    /**
     * @stability stable
     */
    get topicInput(): S3BucketNotificationTopic[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
