import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS SageMaker.
 *
 * @stability stable
 */
export interface SagemakerAppConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app#app_name SagemakerApp#app_name}.
     *
     * @stability stable
     */
    readonly appName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app#app_type SagemakerApp#app_type}.
     *
     * @stability stable
     */
    readonly appType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app#domain_id SagemakerApp#domain_id}.
     *
     * @stability stable
     */
    readonly domainId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app#tags SagemakerApp#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app#tags_all SagemakerApp#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app#user_profile_name SagemakerApp#user_profile_name}.
     *
     * @stability stable
     */
    readonly userProfileName: string;
    /**
     * resource_spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app#resource_spec SagemakerApp#resource_spec}
     *
     * @stability stable
     */
    readonly resourceSpec?: SagemakerAppResourceSpec;
}
/**
 * @stability stable
 */
export interface SagemakerAppResourceSpec {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app#instance_type SagemakerApp#instance_type}.
     *
     * @stability stable
     */
    readonly instanceType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app#lifecycle_config_arn SagemakerApp#lifecycle_config_arn}.
     *
     * @stability stable
     */
    readonly lifecycleConfigArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app#sagemaker_image_arn SagemakerApp#sagemaker_image_arn}.
     *
     * @stability stable
     */
    readonly sagemakerImageArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app#sagemaker_image_version_arn SagemakerApp#sagemaker_image_version_arn}.
     *
     * @stability stable
     */
    readonly sagemakerImageVersionArn?: string;
}
export declare function sagemakerAppResourceSpecToTerraform(struct?: SagemakerAppResourceSpecOutputReference | SagemakerAppResourceSpec): any;
/**
 * @stability stable
 */
export declare class SagemakerAppResourceSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SagemakerAppResourceSpec | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SagemakerAppResourceSpec | undefined);
    private _instanceType?;
    /**
     * @stability stable
     */
    get instanceType(): string;
    /**
     * @stability stable
     */
    set instanceType(value: string);
    /**
     * @stability stable
     */
    resetInstanceType(): void;
    /**
     * @stability stable
     */
    get instanceTypeInput(): string | undefined;
    private _lifecycleConfigArn?;
    /**
     * @stability stable
     */
    get lifecycleConfigArn(): string;
    /**
     * @stability stable
     */
    set lifecycleConfigArn(value: string);
    /**
     * @stability stable
     */
    resetLifecycleConfigArn(): void;
    /**
     * @stability stable
     */
    get lifecycleConfigArnInput(): string | undefined;
    private _sagemakerImageArn?;
    /**
     * @stability stable
     */
    get sagemakerImageArn(): string;
    /**
     * @stability stable
     */
    set sagemakerImageArn(value: string);
    /**
     * @stability stable
     */
    resetSagemakerImageArn(): void;
    /**
     * @stability stable
     */
    get sagemakerImageArnInput(): string | undefined;
    private _sagemakerImageVersionArn?;
    /**
     * @stability stable
     */
    get sagemakerImageVersionArn(): string;
    /**
     * @stability stable
     */
    set sagemakerImageVersionArn(value: string);
    /**
     * @stability stable
     */
    resetSagemakerImageVersionArn(): void;
    /**
     * @stability stable
     */
    get sagemakerImageVersionArnInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app aws_sagemaker_app}.
 *
 * @stability stable
 */
export declare class SagemakerApp extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app aws_sagemaker_app} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SagemakerAppConfig);
    private _appName?;
    /**
     * @stability stable
     */
    get appName(): string;
    /**
     * @stability stable
     */
    set appName(value: string);
    /**
     * @stability stable
     */
    get appNameInput(): string | undefined;
    private _appType?;
    /**
     * @stability stable
     */
    get appType(): string;
    /**
     * @stability stable
     */
    set appType(value: string);
    /**
     * @stability stable
     */
    get appTypeInput(): string | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    private _domainId?;
    /**
     * @stability stable
     */
    get domainId(): string;
    /**
     * @stability stable
     */
    set domainId(value: string);
    /**
     * @stability stable
     */
    get domainIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _userProfileName?;
    /**
     * @stability stable
     */
    get userProfileName(): string;
    /**
     * @stability stable
     */
    set userProfileName(value: string);
    /**
     * @stability stable
     */
    get userProfileNameInput(): string | undefined;
    private _resourceSpec;
    /**
     * @stability stable
     */
    get resourceSpec(): SagemakerAppResourceSpecOutputReference;
    /**
     * @stability stable
     */
    putResourceSpec(value: SagemakerAppResourceSpec): void;
    /**
     * @stability stable
     */
    resetResourceSpec(): void;
    /**
     * @stability stable
     */
    get resourceSpecInput(): SagemakerAppResourceSpec | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
