import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS SageMaker.
 *
 * @stability stable
 */
export interface SagemakerCodeRepositoryConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_code_repository#code_repository_name SagemakerCodeRepository#code_repository_name}.
     *
     * @stability stable
     */
    readonly codeRepositoryName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_code_repository#tags SagemakerCodeRepository#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_code_repository#tags_all SagemakerCodeRepository#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * git_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_code_repository#git_config SagemakerCodeRepository#git_config}
     *
     * @stability stable
     */
    readonly gitConfig: SagemakerCodeRepositoryGitConfig;
}
/**
 * @stability stable
 */
export interface SagemakerCodeRepositoryGitConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_code_repository#branch SagemakerCodeRepository#branch}.
     *
     * @stability stable
     */
    readonly branch?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_code_repository#repository_url SagemakerCodeRepository#repository_url}.
     *
     * @stability stable
     */
    readonly repositoryUrl: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_code_repository#secret_arn SagemakerCodeRepository#secret_arn}.
     *
     * @stability stable
     */
    readonly secretArn?: string;
}
export declare function sagemakerCodeRepositoryGitConfigToTerraform(struct?: SagemakerCodeRepositoryGitConfigOutputReference | SagemakerCodeRepositoryGitConfig): any;
/**
 * @stability stable
 */
export declare class SagemakerCodeRepositoryGitConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SagemakerCodeRepositoryGitConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SagemakerCodeRepositoryGitConfig | undefined);
    private _branch?;
    /**
     * @stability stable
     */
    get branch(): string;
    /**
     * @stability stable
     */
    set branch(value: string);
    /**
     * @stability stable
     */
    resetBranch(): void;
    /**
     * @stability stable
     */
    get branchInput(): string | undefined;
    private _repositoryUrl?;
    /**
     * @stability stable
     */
    get repositoryUrl(): string;
    /**
     * @stability stable
     */
    set repositoryUrl(value: string);
    /**
     * @stability stable
     */
    get repositoryUrlInput(): string | undefined;
    private _secretArn?;
    /**
     * @stability stable
     */
    get secretArn(): string;
    /**
     * @stability stable
     */
    set secretArn(value: string);
    /**
     * @stability stable
     */
    resetSecretArn(): void;
    /**
     * @stability stable
     */
    get secretArnInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_code_repository aws_sagemaker_code_repository}.
 *
 * @stability stable
 */
export declare class SagemakerCodeRepository extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_code_repository aws_sagemaker_code_repository} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SagemakerCodeRepositoryConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _codeRepositoryName?;
    /**
     * @stability stable
     */
    get codeRepositoryName(): string;
    /**
     * @stability stable
     */
    set codeRepositoryName(value: string);
    /**
     * @stability stable
     */
    get codeRepositoryNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _gitConfig;
    /**
     * @stability stable
     */
    get gitConfig(): SagemakerCodeRepositoryGitConfigOutputReference;
    /**
     * @stability stable
     */
    putGitConfig(value: SagemakerCodeRepositoryGitConfig): void;
    /**
     * @stability stable
     */
    get gitConfigInput(): SagemakerCodeRepositoryGitConfig | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
