import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS SageMaker.
 *
 * @stability stable
 */
export interface SagemakerWorkforceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#workforce_name SagemakerWorkforce#workforce_name}.
     *
     * @stability stable
     */
    readonly workforceName: string;
    /**
     * cognito_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#cognito_config SagemakerWorkforce#cognito_config}
     *
     * @stability stable
     */
    readonly cognitoConfig?: SagemakerWorkforceCognitoConfig;
    /**
     * oidc_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#oidc_config SagemakerWorkforce#oidc_config}
     *
     * @stability stable
     */
    readonly oidcConfig?: SagemakerWorkforceOidcConfig;
    /**
     * source_ip_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#source_ip_config SagemakerWorkforce#source_ip_config}
     *
     * @stability stable
     */
    readonly sourceIpConfig?: SagemakerWorkforceSourceIpConfig;
}
/**
 * @stability stable
 */
export interface SagemakerWorkforceCognitoConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#client_id SagemakerWorkforce#client_id}.
     *
     * @stability stable
     */
    readonly clientId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#user_pool SagemakerWorkforce#user_pool}.
     *
     * @stability stable
     */
    readonly userPool: string;
}
export declare function sagemakerWorkforceCognitoConfigToTerraform(struct?: SagemakerWorkforceCognitoConfigOutputReference | SagemakerWorkforceCognitoConfig): any;
/**
 * @stability stable
 */
export declare class SagemakerWorkforceCognitoConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SagemakerWorkforceCognitoConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SagemakerWorkforceCognitoConfig | undefined);
    private _clientId?;
    /**
     * @stability stable
     */
    get clientId(): string;
    /**
     * @stability stable
     */
    set clientId(value: string);
    /**
     * @stability stable
     */
    get clientIdInput(): string | undefined;
    private _userPool?;
    /**
     * @stability stable
     */
    get userPool(): string;
    /**
     * @stability stable
     */
    set userPool(value: string);
    /**
     * @stability stable
     */
    get userPoolInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface SagemakerWorkforceOidcConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#authorization_endpoint SagemakerWorkforce#authorization_endpoint}.
     *
     * @stability stable
     */
    readonly authorizationEndpoint: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#client_id SagemakerWorkforce#client_id}.
     *
     * @stability stable
     */
    readonly clientId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#client_secret SagemakerWorkforce#client_secret}.
     *
     * @stability stable
     */
    readonly clientSecret: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#issuer SagemakerWorkforce#issuer}.
     *
     * @stability stable
     */
    readonly issuer: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#jwks_uri SagemakerWorkforce#jwks_uri}.
     *
     * @stability stable
     */
    readonly jwksUri: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#logout_endpoint SagemakerWorkforce#logout_endpoint}.
     *
     * @stability stable
     */
    readonly logoutEndpoint: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#token_endpoint SagemakerWorkforce#token_endpoint}.
     *
     * @stability stable
     */
    readonly tokenEndpoint: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#user_info_endpoint SagemakerWorkforce#user_info_endpoint}.
     *
     * @stability stable
     */
    readonly userInfoEndpoint: string;
}
export declare function sagemakerWorkforceOidcConfigToTerraform(struct?: SagemakerWorkforceOidcConfigOutputReference | SagemakerWorkforceOidcConfig): any;
/**
 * @stability stable
 */
export declare class SagemakerWorkforceOidcConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SagemakerWorkforceOidcConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SagemakerWorkforceOidcConfig | undefined);
    private _authorizationEndpoint?;
    /**
     * @stability stable
     */
    get authorizationEndpoint(): string;
    /**
     * @stability stable
     */
    set authorizationEndpoint(value: string);
    /**
     * @stability stable
     */
    get authorizationEndpointInput(): string | undefined;
    private _clientId?;
    /**
     * @stability stable
     */
    get clientId(): string;
    /**
     * @stability stable
     */
    set clientId(value: string);
    /**
     * @stability stable
     */
    get clientIdInput(): string | undefined;
    private _clientSecret?;
    /**
     * @stability stable
     */
    get clientSecret(): string;
    /**
     * @stability stable
     */
    set clientSecret(value: string);
    /**
     * @stability stable
     */
    get clientSecretInput(): string | undefined;
    private _issuer?;
    /**
     * @stability stable
     */
    get issuer(): string;
    /**
     * @stability stable
     */
    set issuer(value: string);
    /**
     * @stability stable
     */
    get issuerInput(): string | undefined;
    private _jwksUri?;
    /**
     * @stability stable
     */
    get jwksUri(): string;
    /**
     * @stability stable
     */
    set jwksUri(value: string);
    /**
     * @stability stable
     */
    get jwksUriInput(): string | undefined;
    private _logoutEndpoint?;
    /**
     * @stability stable
     */
    get logoutEndpoint(): string;
    /**
     * @stability stable
     */
    set logoutEndpoint(value: string);
    /**
     * @stability stable
     */
    get logoutEndpointInput(): string | undefined;
    private _tokenEndpoint?;
    /**
     * @stability stable
     */
    get tokenEndpoint(): string;
    /**
     * @stability stable
     */
    set tokenEndpoint(value: string);
    /**
     * @stability stable
     */
    get tokenEndpointInput(): string | undefined;
    private _userInfoEndpoint?;
    /**
     * @stability stable
     */
    get userInfoEndpoint(): string;
    /**
     * @stability stable
     */
    set userInfoEndpoint(value: string);
    /**
     * @stability stable
     */
    get userInfoEndpointInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface SagemakerWorkforceSourceIpConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#cidrs SagemakerWorkforce#cidrs}.
     *
     * @stability stable
     */
    readonly cidrs: string[];
}
export declare function sagemakerWorkforceSourceIpConfigToTerraform(struct?: SagemakerWorkforceSourceIpConfigOutputReference | SagemakerWorkforceSourceIpConfig): any;
/**
 * @stability stable
 */
export declare class SagemakerWorkforceSourceIpConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SagemakerWorkforceSourceIpConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SagemakerWorkforceSourceIpConfig | undefined);
    private _cidrs?;
    /**
     * @stability stable
     */
    get cidrs(): string[];
    /**
     * @stability stable
     */
    set cidrs(value: string[]);
    /**
     * @stability stable
     */
    get cidrsInput(): string[] | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce aws_sagemaker_workforce}.
 *
 * @stability stable
 */
export declare class SagemakerWorkforce extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce aws_sagemaker_workforce} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SagemakerWorkforceConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get subdomain(): string;
    private _workforceName?;
    /**
     * @stability stable
     */
    get workforceName(): string;
    /**
     * @stability stable
     */
    set workforceName(value: string);
    /**
     * @stability stable
     */
    get workforceNameInput(): string | undefined;
    private _cognitoConfig;
    /**
     * @stability stable
     */
    get cognitoConfig(): SagemakerWorkforceCognitoConfigOutputReference;
    /**
     * @stability stable
     */
    putCognitoConfig(value: SagemakerWorkforceCognitoConfig): void;
    /**
     * @stability stable
     */
    resetCognitoConfig(): void;
    /**
     * @stability stable
     */
    get cognitoConfigInput(): SagemakerWorkforceCognitoConfig | undefined;
    private _oidcConfig;
    /**
     * @stability stable
     */
    get oidcConfig(): SagemakerWorkforceOidcConfigOutputReference;
    /**
     * @stability stable
     */
    putOidcConfig(value: SagemakerWorkforceOidcConfig): void;
    /**
     * @stability stable
     */
    resetOidcConfig(): void;
    /**
     * @stability stable
     */
    get oidcConfigInput(): SagemakerWorkforceOidcConfig | undefined;
    private _sourceIpConfig;
    /**
     * @stability stable
     */
    get sourceIpConfig(): SagemakerWorkforceSourceIpConfigOutputReference;
    /**
     * @stability stable
     */
    putSourceIpConfig(value: SagemakerWorkforceSourceIpConfig): void;
    /**
     * @stability stable
     */
    resetSourceIpConfig(): void;
    /**
     * @stability stable
     */
    get sourceIpConfigInput(): SagemakerWorkforceSourceIpConfig | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
