import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Service Discovery.
 *
 * @stability stable
 */
export interface ServiceDiscoveryServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#description ServiceDiscoveryService#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#force_destroy ServiceDiscoveryService#force_destroy}.
     *
     * @stability stable
     */
    readonly forceDestroy?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#name ServiceDiscoveryService#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#namespace_id ServiceDiscoveryService#namespace_id}.
     *
     * @stability stable
     */
    readonly namespaceId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#tags ServiceDiscoveryService#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#tags_all ServiceDiscoveryService#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * dns_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#dns_config ServiceDiscoveryService#dns_config}
     *
     * @stability stable
     */
    readonly dnsConfig?: ServiceDiscoveryServiceDnsConfig;
    /**
     * health_check_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#health_check_config ServiceDiscoveryService#health_check_config}
     *
     * @stability stable
     */
    readonly healthCheckConfig?: ServiceDiscoveryServiceHealthCheckConfig;
    /**
     * health_check_custom_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#health_check_custom_config ServiceDiscoveryService#health_check_custom_config}
     *
     * @stability stable
     */
    readonly healthCheckCustomConfig?: ServiceDiscoveryServiceHealthCheckCustomConfig;
}
/**
 * @stability stable
 */
export interface ServiceDiscoveryServiceDnsConfigDnsRecords {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#ttl ServiceDiscoveryService#ttl}.
     *
     * @stability stable
     */
    readonly ttl: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#type ServiceDiscoveryService#type}.
     *
     * @stability stable
     */
    readonly type: string;
}
export declare function serviceDiscoveryServiceDnsConfigDnsRecordsToTerraform(struct?: ServiceDiscoveryServiceDnsConfigDnsRecords): any;
/**
 * @stability stable
 */
export interface ServiceDiscoveryServiceDnsConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#namespace_id ServiceDiscoveryService#namespace_id}.
     *
     * @stability stable
     */
    readonly namespaceId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#routing_policy ServiceDiscoveryService#routing_policy}.
     *
     * @stability stable
     */
    readonly routingPolicy?: string;
    /**
     * dns_records block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#dns_records ServiceDiscoveryService#dns_records}
     *
     * @stability stable
     */
    readonly dnsRecords: ServiceDiscoveryServiceDnsConfigDnsRecords[];
}
export declare function serviceDiscoveryServiceDnsConfigToTerraform(struct?: ServiceDiscoveryServiceDnsConfigOutputReference | ServiceDiscoveryServiceDnsConfig): any;
/**
 * @stability stable
 */
export declare class ServiceDiscoveryServiceDnsConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceDiscoveryServiceDnsConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceDiscoveryServiceDnsConfig | undefined);
    private _namespaceId?;
    /**
     * @stability stable
     */
    get namespaceId(): string;
    /**
     * @stability stable
     */
    set namespaceId(value: string);
    /**
     * @stability stable
     */
    get namespaceIdInput(): string | undefined;
    private _routingPolicy?;
    /**
     * @stability stable
     */
    get routingPolicy(): string;
    /**
     * @stability stable
     */
    set routingPolicy(value: string);
    /**
     * @stability stable
     */
    resetRoutingPolicy(): void;
    /**
     * @stability stable
     */
    get routingPolicyInput(): string | undefined;
    private _dnsRecords?;
    /**
     * @stability stable
     */
    get dnsRecords(): ServiceDiscoveryServiceDnsConfigDnsRecords[];
    /**
     * @stability stable
     */
    set dnsRecords(value: ServiceDiscoveryServiceDnsConfigDnsRecords[]);
    /**
     * @stability stable
     */
    get dnsRecordsInput(): ServiceDiscoveryServiceDnsConfigDnsRecords[] | undefined;
}
/**
 * @stability stable
 */
export interface ServiceDiscoveryServiceHealthCheckConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#failure_threshold ServiceDiscoveryService#failure_threshold}.
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#resource_path ServiceDiscoveryService#resource_path}.
     *
     * @stability stable
     */
    readonly resourcePath?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#type ServiceDiscoveryService#type}.
     *
     * @stability stable
     */
    readonly type?: string;
}
export declare function serviceDiscoveryServiceHealthCheckConfigToTerraform(struct?: ServiceDiscoveryServiceHealthCheckConfigOutputReference | ServiceDiscoveryServiceHealthCheckConfig): any;
/**
 * @stability stable
 */
export declare class ServiceDiscoveryServiceHealthCheckConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceDiscoveryServiceHealthCheckConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceDiscoveryServiceHealthCheckConfig | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
    private _resourcePath?;
    /**
     * @stability stable
     */
    get resourcePath(): string;
    /**
     * @stability stable
     */
    set resourcePath(value: string);
    /**
     * @stability stable
     */
    resetResourcePath(): void;
    /**
     * @stability stable
     */
    get resourcePathInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ServiceDiscoveryServiceHealthCheckCustomConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#failure_threshold ServiceDiscoveryService#failure_threshold}.
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
}
export declare function serviceDiscoveryServiceHealthCheckCustomConfigToTerraform(struct?: ServiceDiscoveryServiceHealthCheckCustomConfigOutputReference | ServiceDiscoveryServiceHealthCheckCustomConfig): any;
/**
 * @stability stable
 */
export declare class ServiceDiscoveryServiceHealthCheckCustomConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ServiceDiscoveryServiceHealthCheckCustomConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ServiceDiscoveryServiceHealthCheckCustomConfig | undefined);
    private _failureThreshold?;
    /**
     * @stability stable
     */
    get failureThreshold(): number;
    /**
     * @stability stable
     */
    set failureThreshold(value: number);
    /**
     * @stability stable
     */
    resetFailureThreshold(): void;
    /**
     * @stability stable
     */
    get failureThresholdInput(): number | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service aws_service_discovery_service}.
 *
 * @stability stable
 */
export declare class ServiceDiscoveryService extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service aws_service_discovery_service} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ServiceDiscoveryServiceConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _forceDestroy?;
    /**
     * @stability stable
     */
    get forceDestroy(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set forceDestroy(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetForceDestroy(): void;
    /**
     * @stability stable
     */
    get forceDestroyInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespaceId?;
    /**
     * @stability stable
     */
    get namespaceId(): string;
    /**
     * @stability stable
     */
    set namespaceId(value: string);
    /**
     * @stability stable
     */
    resetNamespaceId(): void;
    /**
     * @stability stable
     */
    get namespaceIdInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _dnsConfig;
    /**
     * @stability stable
     */
    get dnsConfig(): ServiceDiscoveryServiceDnsConfigOutputReference;
    /**
     * @stability stable
     */
    putDnsConfig(value: ServiceDiscoveryServiceDnsConfig): void;
    /**
     * @stability stable
     */
    resetDnsConfig(): void;
    /**
     * @stability stable
     */
    get dnsConfigInput(): ServiceDiscoveryServiceDnsConfig | undefined;
    private _healthCheckConfig;
    /**
     * @stability stable
     */
    get healthCheckConfig(): ServiceDiscoveryServiceHealthCheckConfigOutputReference;
    /**
     * @stability stable
     */
    putHealthCheckConfig(value: ServiceDiscoveryServiceHealthCheckConfig): void;
    /**
     * @stability stable
     */
    resetHealthCheckConfig(): void;
    /**
     * @stability stable
     */
    get healthCheckConfigInput(): ServiceDiscoveryServiceHealthCheckConfig | undefined;
    private _healthCheckCustomConfig;
    /**
     * @stability stable
     */
    get healthCheckCustomConfig(): ServiceDiscoveryServiceHealthCheckCustomConfigOutputReference;
    /**
     * @stability stable
     */
    putHealthCheckCustomConfig(value: ServiceDiscoveryServiceHealthCheckCustomConfig): void;
    /**
     * @stability stable
     */
    resetHealthCheckCustomConfig(): void;
    /**
     * @stability stable
     */
    get healthCheckCustomConfigInput(): ServiceDiscoveryServiceHealthCheckCustomConfig | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
