import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Systems Manager.
 *
 * @stability stable
 */
export interface SsmDocumentConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document#content SsmDocument#content}.
     *
     * @stability stable
     */
    readonly content: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document#document_format SsmDocument#document_format}.
     *
     * @stability stable
     */
    readonly documentFormat?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document#document_type SsmDocument#document_type}.
     *
     * @stability stable
     */
    readonly documentType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document#name SsmDocument#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document#permissions SsmDocument#permissions}.
     *
     * @stability stable
     */
    readonly permissions?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document#tags SsmDocument#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document#tags_all SsmDocument#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document#target_type SsmDocument#target_type}.
     *
     * @stability stable
     */
    readonly targetType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document#version_name SsmDocument#version_name}.
     *
     * @stability stable
     */
    readonly versionName?: string;
    /**
     * attachments_source block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document#attachments_source SsmDocument#attachments_source}
     *
     * @stability stable
     */
    readonly attachmentsSource?: SsmDocumentAttachmentsSource[];
}
/**
 * @stability stable
 */
export declare class SsmDocumentParameter extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get defaultValue(): string;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get type(): string;
}
/**
 * @stability stable
 */
export interface SsmDocumentAttachmentsSource {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document#key SsmDocument#key}.
     *
     * @stability stable
     */
    readonly key: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document#name SsmDocument#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document#values SsmDocument#values}.
     *
     * @stability stable
     */
    readonly values: string[];
}
export declare function ssmDocumentAttachmentsSourceToTerraform(struct?: SsmDocumentAttachmentsSource): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ssm_document aws_ssm_document}.
 *
 * @stability stable
 */
export declare class SsmDocument extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ssm_document aws_ssm_document} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SsmDocumentConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _content?;
    /**
     * @stability stable
     */
    get content(): string;
    /**
     * @stability stable
     */
    set content(value: string);
    /**
     * @stability stable
     */
    get contentInput(): string | undefined;
    /**
     * @stability stable
     */
    get createdDate(): string;
    /**
     * @stability stable
     */
    get defaultVersion(): string;
    /**
     * @stability stable
     */
    get description(): string;
    private _documentFormat?;
    /**
     * @stability stable
     */
    get documentFormat(): string;
    /**
     * @stability stable
     */
    set documentFormat(value: string);
    /**
     * @stability stable
     */
    resetDocumentFormat(): void;
    /**
     * @stability stable
     */
    get documentFormatInput(): string | undefined;
    private _documentType?;
    /**
     * @stability stable
     */
    get documentType(): string;
    /**
     * @stability stable
     */
    set documentType(value: string);
    /**
     * @stability stable
     */
    get documentTypeInput(): string | undefined;
    /**
     * @stability stable
     */
    get documentVersion(): string;
    /**
     * @stability stable
     */
    get hash(): string;
    /**
     * @stability stable
     */
    get hashType(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get latestVersion(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get owner(): string;
    /**
     * @stability stable
     */
    parameter(index: string): SsmDocumentParameter;
    private _permissions?;
    /**
     * @stability stable
     */
    get permissions(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set permissions(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPermissions(): void;
    /**
     * @stability stable
     */
    get permissionsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get platformTypes(): string[];
    /**
     * @stability stable
     */
    get schemaVersion(): string;
    /**
     * @stability stable
     */
    get status(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _targetType?;
    /**
     * @stability stable
     */
    get targetType(): string;
    /**
     * @stability stable
     */
    set targetType(value: string);
    /**
     * @stability stable
     */
    resetTargetType(): void;
    /**
     * @stability stable
     */
    get targetTypeInput(): string | undefined;
    private _versionName?;
    /**
     * @stability stable
     */
    get versionName(): string;
    /**
     * @stability stable
     */
    set versionName(value: string);
    /**
     * @stability stable
     */
    resetVersionName(): void;
    /**
     * @stability stable
     */
    get versionNameInput(): string | undefined;
    private _attachmentsSource?;
    /**
     * @stability stable
     */
    get attachmentsSource(): SsmDocumentAttachmentsSource[];
    /**
     * @stability stable
     */
    set attachmentsSource(value: SsmDocumentAttachmentsSource[]);
    /**
     * @stability stable
     */
    resetAttachmentsSource(): void;
    /**
     * @stability stable
     */
    get attachmentsSourceInput(): SsmDocumentAttachmentsSource[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
