import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Systems Manager.
 *
 * @stability stable
 */
export interface SsmPatchBaselineConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#approved_patches SsmPatchBaseline#approved_patches}.
     *
     * @stability stable
     */
    readonly approvedPatches?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#approved_patches_compliance_level SsmPatchBaseline#approved_patches_compliance_level}.
     *
     * @stability stable
     */
    readonly approvedPatchesComplianceLevel?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#approved_patches_enable_non_security SsmPatchBaseline#approved_patches_enable_non_security}.
     *
     * @stability stable
     */
    readonly approvedPatchesEnableNonSecurity?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#description SsmPatchBaseline#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#name SsmPatchBaseline#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#operating_system SsmPatchBaseline#operating_system}.
     *
     * @stability stable
     */
    readonly operatingSystem?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#rejected_patches SsmPatchBaseline#rejected_patches}.
     *
     * @stability stable
     */
    readonly rejectedPatches?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#rejected_patches_action SsmPatchBaseline#rejected_patches_action}.
     *
     * @stability stable
     */
    readonly rejectedPatchesAction?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#tags SsmPatchBaseline#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#tags_all SsmPatchBaseline#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * approval_rule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#approval_rule SsmPatchBaseline#approval_rule}
     *
     * @stability stable
     */
    readonly approvalRule?: SsmPatchBaselineApprovalRule[];
    /**
     * global_filter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#global_filter SsmPatchBaseline#global_filter}
     *
     * @stability stable
     */
    readonly globalFilter?: SsmPatchBaselineGlobalFilter[];
    /**
     * source block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#source SsmPatchBaseline#source}
     *
     * @stability stable
     */
    readonly source?: SsmPatchBaselineSource[];
}
/**
 * @stability stable
 */
export interface SsmPatchBaselineApprovalRulePatchFilter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#key SsmPatchBaseline#key}.
     *
     * @stability stable
     */
    readonly key: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#values SsmPatchBaseline#values}.
     *
     * @stability stable
     */
    readonly values: string[];
}
export declare function ssmPatchBaselineApprovalRulePatchFilterToTerraform(struct?: SsmPatchBaselineApprovalRulePatchFilter): any;
/**
 * @stability stable
 */
export interface SsmPatchBaselineApprovalRule {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#approve_after_days SsmPatchBaseline#approve_after_days}.
     *
     * @stability stable
     */
    readonly approveAfterDays?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#approve_until_date SsmPatchBaseline#approve_until_date}.
     *
     * @stability stable
     */
    readonly approveUntilDate?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#compliance_level SsmPatchBaseline#compliance_level}.
     *
     * @stability stable
     */
    readonly complianceLevel?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#enable_non_security SsmPatchBaseline#enable_non_security}.
     *
     * @stability stable
     */
    readonly enableNonSecurity?: boolean | cdktf.IResolvable;
    /**
     * patch_filter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#patch_filter SsmPatchBaseline#patch_filter}
     *
     * @stability stable
     */
    readonly patchFilter: SsmPatchBaselineApprovalRulePatchFilter[];
}
export declare function ssmPatchBaselineApprovalRuleToTerraform(struct?: SsmPatchBaselineApprovalRule): any;
/**
 * @stability stable
 */
export interface SsmPatchBaselineGlobalFilter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#key SsmPatchBaseline#key}.
     *
     * @stability stable
     */
    readonly key: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#values SsmPatchBaseline#values}.
     *
     * @stability stable
     */
    readonly values: string[];
}
export declare function ssmPatchBaselineGlobalFilterToTerraform(struct?: SsmPatchBaselineGlobalFilter): any;
/**
 * @stability stable
 */
export interface SsmPatchBaselineSource {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#configuration SsmPatchBaseline#configuration}.
     *
     * @stability stable
     */
    readonly configuration: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#name SsmPatchBaseline#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline#products SsmPatchBaseline#products}.
     *
     * @stability stable
     */
    readonly products: string[];
}
export declare function ssmPatchBaselineSourceToTerraform(struct?: SsmPatchBaselineSource): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline aws_ssm_patch_baseline}.
 *
 * @stability stable
 */
export declare class SsmPatchBaseline extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline aws_ssm_patch_baseline} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SsmPatchBaselineConfig);
    private _approvedPatches?;
    /**
     * @stability stable
     */
    get approvedPatches(): string[];
    /**
     * @stability stable
     */
    set approvedPatches(value: string[]);
    /**
     * @stability stable
     */
    resetApprovedPatches(): void;
    /**
     * @stability stable
     */
    get approvedPatchesInput(): string[] | undefined;
    private _approvedPatchesComplianceLevel?;
    /**
     * @stability stable
     */
    get approvedPatchesComplianceLevel(): string;
    /**
     * @stability stable
     */
    set approvedPatchesComplianceLevel(value: string);
    /**
     * @stability stable
     */
    resetApprovedPatchesComplianceLevel(): void;
    /**
     * @stability stable
     */
    get approvedPatchesComplianceLevelInput(): string | undefined;
    private _approvedPatchesEnableNonSecurity?;
    /**
     * @stability stable
     */
    get approvedPatchesEnableNonSecurity(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set approvedPatchesEnableNonSecurity(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetApprovedPatchesEnableNonSecurity(): void;
    /**
     * @stability stable
     */
    get approvedPatchesEnableNonSecurityInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _operatingSystem?;
    /**
     * @stability stable
     */
    get operatingSystem(): string;
    /**
     * @stability stable
     */
    set operatingSystem(value: string);
    /**
     * @stability stable
     */
    resetOperatingSystem(): void;
    /**
     * @stability stable
     */
    get operatingSystemInput(): string | undefined;
    private _rejectedPatches?;
    /**
     * @stability stable
     */
    get rejectedPatches(): string[];
    /**
     * @stability stable
     */
    set rejectedPatches(value: string[]);
    /**
     * @stability stable
     */
    resetRejectedPatches(): void;
    /**
     * @stability stable
     */
    get rejectedPatchesInput(): string[] | undefined;
    private _rejectedPatchesAction?;
    /**
     * @stability stable
     */
    get rejectedPatchesAction(): string;
    /**
     * @stability stable
     */
    set rejectedPatchesAction(value: string);
    /**
     * @stability stable
     */
    resetRejectedPatchesAction(): void;
    /**
     * @stability stable
     */
    get rejectedPatchesActionInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _approvalRule?;
    /**
     * @stability stable
     */
    get approvalRule(): SsmPatchBaselineApprovalRule[];
    /**
     * @stability stable
     */
    set approvalRule(value: SsmPatchBaselineApprovalRule[]);
    /**
     * @stability stable
     */
    resetApprovalRule(): void;
    /**
     * @stability stable
     */
    get approvalRuleInput(): SsmPatchBaselineApprovalRule[] | undefined;
    private _globalFilter?;
    /**
     * @stability stable
     */
    get globalFilter(): SsmPatchBaselineGlobalFilter[];
    /**
     * @stability stable
     */
    set globalFilter(value: SsmPatchBaselineGlobalFilter[]);
    /**
     * @stability stable
     */
    resetGlobalFilter(): void;
    /**
     * @stability stable
     */
    get globalFilterInput(): SsmPatchBaselineGlobalFilter[] | undefined;
    private _source?;
    /**
     * @stability stable
     */
    get source(): SsmPatchBaselineSource[];
    /**
     * @stability stable
     */
    set source(value: SsmPatchBaselineSource[]);
    /**
     * @stability stable
     */
    resetSource(): void;
    /**
     * @stability stable
     */
    get sourceInput(): SsmPatchBaselineSource[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
