import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Synthetics.
 *
 * @stability stable
 */
export interface SyntheticsCanaryConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#artifact_s3_location SyntheticsCanary#artifact_s3_location}.
     *
     * @stability stable
     */
    readonly artifactS3Location: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#execution_role_arn SyntheticsCanary#execution_role_arn}.
     *
     * @stability stable
     */
    readonly executionRoleArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#failure_retention_period SyntheticsCanary#failure_retention_period}.
     *
     * @stability stable
     */
    readonly failureRetentionPeriod?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#handler SyntheticsCanary#handler}.
     *
     * @stability stable
     */
    readonly handler: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#name SyntheticsCanary#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#runtime_version SyntheticsCanary#runtime_version}.
     *
     * @stability stable
     */
    readonly runtimeVersion: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#s3_bucket SyntheticsCanary#s3_bucket}.
     *
     * @stability stable
     */
    readonly s3Bucket?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#s3_key SyntheticsCanary#s3_key}.
     *
     * @stability stable
     */
    readonly s3Key?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#s3_version SyntheticsCanary#s3_version}.
     *
     * @stability stable
     */
    readonly s3Version?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#start_canary SyntheticsCanary#start_canary}.
     *
     * @stability stable
     */
    readonly startCanary?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#success_retention_period SyntheticsCanary#success_retention_period}.
     *
     * @stability stable
     */
    readonly successRetentionPeriod?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#tags SyntheticsCanary#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#tags_all SyntheticsCanary#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#zip_file SyntheticsCanary#zip_file}.
     *
     * @stability stable
     */
    readonly zipFile?: string;
    /**
     * artifact_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#artifact_config SyntheticsCanary#artifact_config}
     *
     * @stability stable
     */
    readonly artifactConfig?: SyntheticsCanaryArtifactConfig;
    /**
     * run_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#run_config SyntheticsCanary#run_config}
     *
     * @stability stable
     */
    readonly runConfig?: SyntheticsCanaryRunConfig;
    /**
     * schedule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#schedule SyntheticsCanary#schedule}
     *
     * @stability stable
     */
    readonly schedule: SyntheticsCanarySchedule;
    /**
     * vpc_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#vpc_config SyntheticsCanary#vpc_config}
     *
     * @stability stable
     */
    readonly vpcConfig?: SyntheticsCanaryVpcConfig;
}
/**
 * @stability stable
 */
export declare class SyntheticsCanaryTimeline extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get created(): string;
    /**
     * @stability stable
     */
    get lastModified(): string;
    /**
     * @stability stable
     */
    get lastStarted(): string;
    /**
     * @stability stable
     */
    get lastStopped(): string;
}
/**
 * @stability stable
 */
export interface SyntheticsCanaryArtifactConfigS3Encryption {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#encryption_mode SyntheticsCanary#encryption_mode}.
     *
     * @stability stable
     */
    readonly encryptionMode?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#kms_key_arn SyntheticsCanary#kms_key_arn}.
     *
     * @stability stable
     */
    readonly kmsKeyArn?: string;
}
export declare function syntheticsCanaryArtifactConfigS3EncryptionToTerraform(struct?: SyntheticsCanaryArtifactConfigS3EncryptionOutputReference | SyntheticsCanaryArtifactConfigS3Encryption): any;
/**
 * @stability stable
 */
export declare class SyntheticsCanaryArtifactConfigS3EncryptionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SyntheticsCanaryArtifactConfigS3Encryption | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SyntheticsCanaryArtifactConfigS3Encryption | undefined);
    private _encryptionMode?;
    /**
     * @stability stable
     */
    get encryptionMode(): string;
    /**
     * @stability stable
     */
    set encryptionMode(value: string);
    /**
     * @stability stable
     */
    resetEncryptionMode(): void;
    /**
     * @stability stable
     */
    get encryptionModeInput(): string | undefined;
    private _kmsKeyArn?;
    /**
     * @stability stable
     */
    get kmsKeyArn(): string;
    /**
     * @stability stable
     */
    set kmsKeyArn(value: string);
    /**
     * @stability stable
     */
    resetKmsKeyArn(): void;
    /**
     * @stability stable
     */
    get kmsKeyArnInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface SyntheticsCanaryArtifactConfig {
    /**
     * s3_encryption block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#s3_encryption SyntheticsCanary#s3_encryption}
     *
     * @stability stable
     */
    readonly s3Encryption?: SyntheticsCanaryArtifactConfigS3Encryption;
}
export declare function syntheticsCanaryArtifactConfigToTerraform(struct?: SyntheticsCanaryArtifactConfigOutputReference | SyntheticsCanaryArtifactConfig): any;
/**
 * @stability stable
 */
export declare class SyntheticsCanaryArtifactConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SyntheticsCanaryArtifactConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SyntheticsCanaryArtifactConfig | undefined);
    private _s3Encryption;
    /**
     * @stability stable
     */
    get s3Encryption(): SyntheticsCanaryArtifactConfigS3EncryptionOutputReference;
    /**
     * @stability stable
     */
    putS3Encryption(value: SyntheticsCanaryArtifactConfigS3Encryption): void;
    /**
     * @stability stable
     */
    resetS3Encryption(): void;
    /**
     * @stability stable
     */
    get s3EncryptionInput(): SyntheticsCanaryArtifactConfigS3Encryption | undefined;
}
/**
 * @stability stable
 */
export interface SyntheticsCanaryRunConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#active_tracing SyntheticsCanary#active_tracing}.
     *
     * @stability stable
     */
    readonly activeTracing?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#memory_in_mb SyntheticsCanary#memory_in_mb}.
     *
     * @stability stable
     */
    readonly memoryInMb?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#timeout_in_seconds SyntheticsCanary#timeout_in_seconds}.
     *
     * @stability stable
     */
    readonly timeoutInSeconds?: number;
}
export declare function syntheticsCanaryRunConfigToTerraform(struct?: SyntheticsCanaryRunConfigOutputReference | SyntheticsCanaryRunConfig): any;
/**
 * @stability stable
 */
export declare class SyntheticsCanaryRunConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SyntheticsCanaryRunConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SyntheticsCanaryRunConfig | undefined);
    private _activeTracing?;
    /**
     * @stability stable
     */
    get activeTracing(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set activeTracing(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetActiveTracing(): void;
    /**
     * @stability stable
     */
    get activeTracingInput(): boolean | cdktf.IResolvable | undefined;
    private _memoryInMb?;
    /**
     * @stability stable
     */
    get memoryInMb(): number;
    /**
     * @stability stable
     */
    set memoryInMb(value: number);
    /**
     * @stability stable
     */
    resetMemoryInMb(): void;
    /**
     * @stability stable
     */
    get memoryInMbInput(): number | undefined;
    private _timeoutInSeconds?;
    /**
     * @stability stable
     */
    get timeoutInSeconds(): number;
    /**
     * @stability stable
     */
    set timeoutInSeconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutInSeconds(): void;
    /**
     * @stability stable
     */
    get timeoutInSecondsInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface SyntheticsCanarySchedule {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#duration_in_seconds SyntheticsCanary#duration_in_seconds}.
     *
     * @stability stable
     */
    readonly durationInSeconds?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#expression SyntheticsCanary#expression}.
     *
     * @stability stable
     */
    readonly expression: string;
}
export declare function syntheticsCanaryScheduleToTerraform(struct?: SyntheticsCanaryScheduleOutputReference | SyntheticsCanarySchedule): any;
/**
 * @stability stable
 */
export declare class SyntheticsCanaryScheduleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SyntheticsCanarySchedule | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SyntheticsCanarySchedule | undefined);
    private _durationInSeconds?;
    /**
     * @stability stable
     */
    get durationInSeconds(): number;
    /**
     * @stability stable
     */
    set durationInSeconds(value: number);
    /**
     * @stability stable
     */
    resetDurationInSeconds(): void;
    /**
     * @stability stable
     */
    get durationInSecondsInput(): number | undefined;
    private _expression?;
    /**
     * @stability stable
     */
    get expression(): string;
    /**
     * @stability stable
     */
    set expression(value: string);
    /**
     * @stability stable
     */
    get expressionInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface SyntheticsCanaryVpcConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#security_group_ids SyntheticsCanary#security_group_ids}.
     *
     * @stability stable
     */
    readonly securityGroupIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#subnet_ids SyntheticsCanary#subnet_ids}.
     *
     * @stability stable
     */
    readonly subnetIds?: string[];
}
export declare function syntheticsCanaryVpcConfigToTerraform(struct?: SyntheticsCanaryVpcConfigOutputReference | SyntheticsCanaryVpcConfig): any;
/**
 * @stability stable
 */
export declare class SyntheticsCanaryVpcConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SyntheticsCanaryVpcConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SyntheticsCanaryVpcConfig | undefined);
    private _securityGroupIds?;
    /**
     * @stability stable
     */
    get securityGroupIds(): string[];
    /**
     * @stability stable
     */
    set securityGroupIds(value: string[]);
    /**
     * @stability stable
     */
    resetSecurityGroupIds(): void;
    /**
     * @stability stable
     */
    get securityGroupIdsInput(): string[] | undefined;
    private _subnetIds?;
    /**
     * @stability stable
     */
    get subnetIds(): string[];
    /**
     * @stability stable
     */
    set subnetIds(value: string[]);
    /**
     * @stability stable
     */
    resetSubnetIds(): void;
    /**
     * @stability stable
     */
    get subnetIdsInput(): string[] | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary aws_synthetics_canary}.
 *
 * @stability stable
 */
export declare class SyntheticsCanary extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary aws_synthetics_canary} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SyntheticsCanaryConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _artifactS3Location?;
    /**
     * @stability stable
     */
    get artifactS3Location(): string;
    /**
     * @stability stable
     */
    set artifactS3Location(value: string);
    /**
     * @stability stable
     */
    get artifactS3LocationInput(): string | undefined;
    /**
     * @stability stable
     */
    get engineArn(): string;
    private _executionRoleArn?;
    /**
     * @stability stable
     */
    get executionRoleArn(): string;
    /**
     * @stability stable
     */
    set executionRoleArn(value: string);
    /**
     * @stability stable
     */
    get executionRoleArnInput(): string | undefined;
    private _failureRetentionPeriod?;
    /**
     * @stability stable
     */
    get failureRetentionPeriod(): number;
    /**
     * @stability stable
     */
    set failureRetentionPeriod(value: number);
    /**
     * @stability stable
     */
    resetFailureRetentionPeriod(): void;
    /**
     * @stability stable
     */
    get failureRetentionPeriodInput(): number | undefined;
    private _handler?;
    /**
     * @stability stable
     */
    get handler(): string;
    /**
     * @stability stable
     */
    set handler(value: string);
    /**
     * @stability stable
     */
    get handlerInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _runtimeVersion?;
    /**
     * @stability stable
     */
    get runtimeVersion(): string;
    /**
     * @stability stable
     */
    set runtimeVersion(value: string);
    /**
     * @stability stable
     */
    get runtimeVersionInput(): string | undefined;
    private _s3Bucket?;
    /**
     * @stability stable
     */
    get s3Bucket(): string;
    /**
     * @stability stable
     */
    set s3Bucket(value: string);
    /**
     * @stability stable
     */
    resetS3Bucket(): void;
    /**
     * @stability stable
     */
    get s3BucketInput(): string | undefined;
    private _s3Key?;
    /**
     * @stability stable
     */
    get s3Key(): string;
    /**
     * @stability stable
     */
    set s3Key(value: string);
    /**
     * @stability stable
     */
    resetS3Key(): void;
    /**
     * @stability stable
     */
    get s3KeyInput(): string | undefined;
    private _s3Version?;
    /**
     * @stability stable
     */
    get s3Version(): string;
    /**
     * @stability stable
     */
    set s3Version(value: string);
    /**
     * @stability stable
     */
    resetS3Version(): void;
    /**
     * @stability stable
     */
    get s3VersionInput(): string | undefined;
    /**
     * @stability stable
     */
    get sourceLocationArn(): string;
    private _startCanary?;
    /**
     * @stability stable
     */
    get startCanary(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set startCanary(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetStartCanary(): void;
    /**
     * @stability stable
     */
    get startCanaryInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get status(): string;
    private _successRetentionPeriod?;
    /**
     * @stability stable
     */
    get successRetentionPeriod(): number;
    /**
     * @stability stable
     */
    set successRetentionPeriod(value: number);
    /**
     * @stability stable
     */
    resetSuccessRetentionPeriod(): void;
    /**
     * @stability stable
     */
    get successRetentionPeriodInput(): number | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    timeline(index: string): SyntheticsCanaryTimeline;
    private _zipFile?;
    /**
     * @stability stable
     */
    get zipFile(): string;
    /**
     * @stability stable
     */
    set zipFile(value: string);
    /**
     * @stability stable
     */
    resetZipFile(): void;
    /**
     * @stability stable
     */
    get zipFileInput(): string | undefined;
    private _artifactConfig;
    /**
     * @stability stable
     */
    get artifactConfig(): SyntheticsCanaryArtifactConfigOutputReference;
    /**
     * @stability stable
     */
    putArtifactConfig(value: SyntheticsCanaryArtifactConfig): void;
    /**
     * @stability stable
     */
    resetArtifactConfig(): void;
    /**
     * @stability stable
     */
    get artifactConfigInput(): SyntheticsCanaryArtifactConfig | undefined;
    private _runConfig;
    /**
     * @stability stable
     */
    get runConfig(): SyntheticsCanaryRunConfigOutputReference;
    /**
     * @stability stable
     */
    putRunConfig(value: SyntheticsCanaryRunConfig): void;
    /**
     * @stability stable
     */
    resetRunConfig(): void;
    /**
     * @stability stable
     */
    get runConfigInput(): SyntheticsCanaryRunConfig | undefined;
    private _schedule;
    /**
     * @stability stable
     */
    get schedule(): SyntheticsCanaryScheduleOutputReference;
    /**
     * @stability stable
     */
    putSchedule(value: SyntheticsCanarySchedule): void;
    /**
     * @stability stable
     */
    get scheduleInput(): SyntheticsCanarySchedule | undefined;
    private _vpcConfig;
    /**
     * @stability stable
     */
    get vpcConfig(): SyntheticsCanaryVpcConfigOutputReference;
    /**
     * @stability stable
     */
    putVpcConfig(value: SyntheticsCanaryVpcConfig): void;
    /**
     * @stability stable
     */
    resetVpcConfig(): void;
    /**
     * @stability stable
     */
    get vpcConfigInput(): SyntheticsCanaryVpcConfig | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
