import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Transfer.
 *
 * @stability stable
 */
export interface TransferServerConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#certificate TransferServer#certificate}.
     *
     * @stability stable
     */
    readonly certificate?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#directory_id TransferServer#directory_id}.
     *
     * @stability stable
     */
    readonly directoryId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#domain TransferServer#domain}.
     *
     * @stability stable
     */
    readonly domain?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#endpoint_type TransferServer#endpoint_type}.
     *
     * @stability stable
     */
    readonly endpointType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#force_destroy TransferServer#force_destroy}.
     *
     * @stability stable
     */
    readonly forceDestroy?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#function TransferServer#function}.
     *
     * @stability stable
     */
    readonly function?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#host_key TransferServer#host_key}.
     *
     * @stability stable
     */
    readonly hostKey?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#identity_provider_type TransferServer#identity_provider_type}.
     *
     * @stability stable
     */
    readonly identityProviderType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#invocation_role TransferServer#invocation_role}.
     *
     * @stability stable
     */
    readonly invocationRole?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#logging_role TransferServer#logging_role}.
     *
     * @stability stable
     */
    readonly loggingRole?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#protocols TransferServer#protocols}.
     *
     * @stability stable
     */
    readonly protocols?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#security_policy_name TransferServer#security_policy_name}.
     *
     * @stability stable
     */
    readonly securityPolicyName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#tags TransferServer#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#tags_all TransferServer#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#url TransferServer#url}.
     *
     * @stability stable
     */
    readonly url?: string;
    /**
     * endpoint_details block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#endpoint_details TransferServer#endpoint_details}
     *
     * @stability stable
     */
    readonly endpointDetails?: TransferServerEndpointDetails;
}
/**
 * @stability stable
 */
export interface TransferServerEndpointDetails {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#address_allocation_ids TransferServer#address_allocation_ids}.
     *
     * @stability stable
     */
    readonly addressAllocationIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#security_group_ids TransferServer#security_group_ids}.
     *
     * @stability stable
     */
    readonly securityGroupIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#subnet_ids TransferServer#subnet_ids}.
     *
     * @stability stable
     */
    readonly subnetIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#vpc_endpoint_id TransferServer#vpc_endpoint_id}.
     *
     * @stability stable
     */
    readonly vpcEndpointId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server#vpc_id TransferServer#vpc_id}.
     *
     * @stability stable
     */
    readonly vpcId?: string;
}
export declare function transferServerEndpointDetailsToTerraform(struct?: TransferServerEndpointDetailsOutputReference | TransferServerEndpointDetails): any;
/**
 * @stability stable
 */
export declare class TransferServerEndpointDetailsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): TransferServerEndpointDetails | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: TransferServerEndpointDetails | undefined);
    private _addressAllocationIds?;
    /**
     * @stability stable
     */
    get addressAllocationIds(): string[];
    /**
     * @stability stable
     */
    set addressAllocationIds(value: string[]);
    /**
     * @stability stable
     */
    resetAddressAllocationIds(): void;
    /**
     * @stability stable
     */
    get addressAllocationIdsInput(): string[] | undefined;
    private _securityGroupIds?;
    /**
     * @stability stable
     */
    get securityGroupIds(): string[];
    /**
     * @stability stable
     */
    set securityGroupIds(value: string[]);
    /**
     * @stability stable
     */
    resetSecurityGroupIds(): void;
    /**
     * @stability stable
     */
    get securityGroupIdsInput(): string[] | undefined;
    private _subnetIds?;
    /**
     * @stability stable
     */
    get subnetIds(): string[];
    /**
     * @stability stable
     */
    set subnetIds(value: string[]);
    /**
     * @stability stable
     */
    resetSubnetIds(): void;
    /**
     * @stability stable
     */
    get subnetIdsInput(): string[] | undefined;
    private _vpcEndpointId?;
    /**
     * @stability stable
     */
    get vpcEndpointId(): string;
    /**
     * @stability stable
     */
    set vpcEndpointId(value: string);
    /**
     * @stability stable
     */
    resetVpcEndpointId(): void;
    /**
     * @stability stable
     */
    get vpcEndpointIdInput(): string | undefined;
    private _vpcId?;
    /**
     * @stability stable
     */
    get vpcId(): string;
    /**
     * @stability stable
     */
    set vpcId(value: string);
    /**
     * @stability stable
     */
    resetVpcId(): void;
    /**
     * @stability stable
     */
    get vpcIdInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/transfer_server aws_transfer_server}.
 *
 * @stability stable
 */
export declare class TransferServer extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/transfer_server aws_transfer_server} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: TransferServerConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _certificate?;
    /**
     * @stability stable
     */
    get certificate(): string;
    /**
     * @stability stable
     */
    set certificate(value: string);
    /**
     * @stability stable
     */
    resetCertificate(): void;
    /**
     * @stability stable
     */
    get certificateInput(): string | undefined;
    private _directoryId?;
    /**
     * @stability stable
     */
    get directoryId(): string;
    /**
     * @stability stable
     */
    set directoryId(value: string);
    /**
     * @stability stable
     */
    resetDirectoryId(): void;
    /**
     * @stability stable
     */
    get directoryIdInput(): string | undefined;
    private _domain?;
    /**
     * @stability stable
     */
    get domain(): string;
    /**
     * @stability stable
     */
    set domain(value: string);
    /**
     * @stability stable
     */
    resetDomain(): void;
    /**
     * @stability stable
     */
    get domainInput(): string | undefined;
    /**
     * @stability stable
     */
    get endpoint(): string;
    private _endpointType?;
    /**
     * @stability stable
     */
    get endpointType(): string;
    /**
     * @stability stable
     */
    set endpointType(value: string);
    /**
     * @stability stable
     */
    resetEndpointType(): void;
    /**
     * @stability stable
     */
    get endpointTypeInput(): string | undefined;
    private _forceDestroy?;
    /**
     * @stability stable
     */
    get forceDestroy(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set forceDestroy(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetForceDestroy(): void;
    /**
     * @stability stable
     */
    get forceDestroyInput(): boolean | cdktf.IResolvable | undefined;
    private _function?;
    /**
     * @stability stable
     */
    get function(): string;
    /**
     * @stability stable
     */
    set function(value: string);
    /**
     * @stability stable
     */
    resetFunction(): void;
    /**
     * @stability stable
     */
    get functionInput(): string | undefined;
    private _hostKey?;
    /**
     * @stability stable
     */
    get hostKey(): string;
    /**
     * @stability stable
     */
    set hostKey(value: string);
    /**
     * @stability stable
     */
    resetHostKey(): void;
    /**
     * @stability stable
     */
    get hostKeyInput(): string | undefined;
    /**
     * @stability stable
     */
    get hostKeyFingerprint(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _identityProviderType?;
    /**
     * @stability stable
     */
    get identityProviderType(): string;
    /**
     * @stability stable
     */
    set identityProviderType(value: string);
    /**
     * @stability stable
     */
    resetIdentityProviderType(): void;
    /**
     * @stability stable
     */
    get identityProviderTypeInput(): string | undefined;
    private _invocationRole?;
    /**
     * @stability stable
     */
    get invocationRole(): string;
    /**
     * @stability stable
     */
    set invocationRole(value: string);
    /**
     * @stability stable
     */
    resetInvocationRole(): void;
    /**
     * @stability stable
     */
    get invocationRoleInput(): string | undefined;
    private _loggingRole?;
    /**
     * @stability stable
     */
    get loggingRole(): string;
    /**
     * @stability stable
     */
    set loggingRole(value: string);
    /**
     * @stability stable
     */
    resetLoggingRole(): void;
    /**
     * @stability stable
     */
    get loggingRoleInput(): string | undefined;
    private _protocols?;
    /**
     * @stability stable
     */
    get protocols(): string[];
    /**
     * @stability stable
     */
    set protocols(value: string[]);
    /**
     * @stability stable
     */
    resetProtocols(): void;
    /**
     * @stability stable
     */
    get protocolsInput(): string[] | undefined;
    private _securityPolicyName?;
    /**
     * @stability stable
     */
    get securityPolicyName(): string;
    /**
     * @stability stable
     */
    set securityPolicyName(value: string);
    /**
     * @stability stable
     */
    resetSecurityPolicyName(): void;
    /**
     * @stability stable
     */
    get securityPolicyNameInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _url?;
    /**
     * @stability stable
     */
    get url(): string;
    /**
     * @stability stable
     */
    set url(value: string);
    /**
     * @stability stable
     */
    resetUrl(): void;
    /**
     * @stability stable
     */
    get urlInput(): string | undefined;
    private _endpointDetails;
    /**
     * @stability stable
     */
    get endpointDetails(): TransferServerEndpointDetailsOutputReference;
    /**
     * @stability stable
     */
    putEndpointDetails(value: TransferServerEndpointDetails): void;
    /**
     * @stability stable
     */
    resetEndpointDetails(): void;
    /**
     * @stability stable
     */
    get endpointDetailsInput(): TransferServerEndpointDetails | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
