import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS VPC.
 *
 * @stability stable
 */
export interface DataAwsVpcConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc#cidr_block DataAwsVpc#cidr_block}.
     *
     * @stability stable
     */
    readonly cidrBlock?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc#default DataAwsVpc#default}.
     *
     * @stability stable
     */
    readonly default?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc#dhcp_options_id DataAwsVpc#dhcp_options_id}.
     *
     * @stability stable
     */
    readonly dhcpOptionsId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc#state DataAwsVpc#state}.
     *
     * @stability stable
     */
    readonly state?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc#tags DataAwsVpc#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * filter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc#filter DataAwsVpc#filter}
     *
     * @stability stable
     */
    readonly filter?: DataAwsVpcFilter[];
}
/**
 * @stability stable
 */
export declare class DataAwsVpcCidrBlockAssociations extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get associationId(): string;
    /**
     * @stability stable
     */
    get cidrBlock(): string;
    /**
     * @stability stable
     */
    get state(): string;
}
/**
 * @stability stable
 */
export interface DataAwsVpcFilter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc#name DataAwsVpc#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc#values DataAwsVpc#values}.
     *
     * @stability stable
     */
    readonly values: string[];
}
export declare function dataAwsVpcFilterToTerraform(struct?: DataAwsVpcFilter): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/d/vpc aws_vpc}.
 *
 * @stability stable
 */
export declare class DataAwsVpc extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/d/vpc aws_vpc} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: DataAwsVpcConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _cidrBlock?;
    /**
     * @stability stable
     */
    get cidrBlock(): string;
    /**
     * @stability stable
     */
    set cidrBlock(value: string);
    /**
     * @stability stable
     */
    resetCidrBlock(): void;
    /**
     * @stability stable
     */
    get cidrBlockInput(): string | undefined;
    /**
     * @stability stable
     */
    cidrBlockAssociations(index: string): DataAwsVpcCidrBlockAssociations;
    private _default?;
    /**
     * @stability stable
     */
    get default(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set default(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetDefault(): void;
    /**
     * @stability stable
     */
    get defaultInput(): boolean | cdktf.IResolvable | undefined;
    private _dhcpOptionsId?;
    /**
     * @stability stable
     */
    get dhcpOptionsId(): string;
    /**
     * @stability stable
     */
    set dhcpOptionsId(value: string);
    /**
     * @stability stable
     */
    resetDhcpOptionsId(): void;
    /**
     * @stability stable
     */
    get dhcpOptionsIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get enableDnsHostnames(): any;
    /**
     * @stability stable
     */
    get enableDnsSupport(): any;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get instanceTenancy(): string;
    /**
     * @stability stable
     */
    get ipv6AssociationId(): string;
    /**
     * @stability stable
     */
    get ipv6CidrBlock(): string;
    /**
     * @stability stable
     */
    get mainRouteTableId(): string;
    /**
     * @stability stable
     */
    get ownerId(): string;
    private _state?;
    /**
     * @stability stable
     */
    get state(): string;
    /**
     * @stability stable
     */
    set state(value: string);
    /**
     * @stability stable
     */
    resetState(): void;
    /**
     * @stability stable
     */
    get stateInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _filter?;
    /**
     * @stability stable
     */
    get filter(): DataAwsVpcFilter[];
    /**
     * @stability stable
     */
    set filter(value: DataAwsVpcFilter[]);
    /**
     * @stability stable
     */
    resetFilter(): void;
    /**
     * @stability stable
     */
    get filterInput(): DataAwsVpcFilter[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
