import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS VPC.
 *
 * @stability stable
 */
export interface SubnetConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#assign_ipv6_address_on_creation Subnet#assign_ipv6_address_on_creation}.
     *
     * @stability stable
     */
    readonly assignIpv6AddressOnCreation?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#availability_zone Subnet#availability_zone}.
     *
     * @stability stable
     */
    readonly availabilityZone?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#availability_zone_id Subnet#availability_zone_id}.
     *
     * @stability stable
     */
    readonly availabilityZoneId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#cidr_block Subnet#cidr_block}.
     *
     * @stability stable
     */
    readonly cidrBlock?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#customer_owned_ipv4_pool Subnet#customer_owned_ipv4_pool}.
     *
     * @stability stable
     */
    readonly customerOwnedIpv4Pool?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#enable_dns64 Subnet#enable_dns64}.
     *
     * @stability stable
     */
    readonly enableDns64?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#enable_resource_name_dns_a_record_on_launch Subnet#enable_resource_name_dns_a_record_on_launch}.
     *
     * @stability stable
     */
    readonly enableResourceNameDnsARecordOnLaunch?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#enable_resource_name_dns_aaaa_record_on_launch Subnet#enable_resource_name_dns_aaaa_record_on_launch}.
     *
     * @stability stable
     */
    readonly enableResourceNameDnsAaaaRecordOnLaunch?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#ipv6_cidr_block Subnet#ipv6_cidr_block}.
     *
     * @stability stable
     */
    readonly ipv6CidrBlock?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#ipv6_native Subnet#ipv6_native}.
     *
     * @stability stable
     */
    readonly ipv6Native?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#map_customer_owned_ip_on_launch Subnet#map_customer_owned_ip_on_launch}.
     *
     * @stability stable
     */
    readonly mapCustomerOwnedIpOnLaunch?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#map_public_ip_on_launch Subnet#map_public_ip_on_launch}.
     *
     * @stability stable
     */
    readonly mapPublicIpOnLaunch?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#outpost_arn Subnet#outpost_arn}.
     *
     * @stability stable
     */
    readonly outpostArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#private_dns_hostname_type_on_launch Subnet#private_dns_hostname_type_on_launch}.
     *
     * @stability stable
     */
    readonly privateDnsHostnameTypeOnLaunch?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#tags Subnet#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#tags_all Subnet#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#vpc_id Subnet#vpc_id}.
     *
     * @stability stable
     */
    readonly vpcId: string;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#timeouts Subnet#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: SubnetTimeouts;
}
/**
 * @stability stable
 */
export interface SubnetTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#create Subnet#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet#delete Subnet#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
}
export declare function subnetTimeoutsToTerraform(struct?: SubnetTimeoutsOutputReference | SubnetTimeouts): any;
/**
 * @stability stable
 */
export declare class SubnetTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SubnetTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SubnetTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/subnet aws_subnet}.
 *
 * @stability stable
 */
export declare class Subnet extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/subnet aws_subnet} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SubnetConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _assignIpv6AddressOnCreation?;
    /**
     * @stability stable
     */
    get assignIpv6AddressOnCreation(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set assignIpv6AddressOnCreation(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAssignIpv6AddressOnCreation(): void;
    /**
     * @stability stable
     */
    get assignIpv6AddressOnCreationInput(): boolean | cdktf.IResolvable | undefined;
    private _availabilityZone?;
    /**
     * @stability stable
     */
    get availabilityZone(): string;
    /**
     * @stability stable
     */
    set availabilityZone(value: string);
    /**
     * @stability stable
     */
    resetAvailabilityZone(): void;
    /**
     * @stability stable
     */
    get availabilityZoneInput(): string | undefined;
    private _availabilityZoneId?;
    /**
     * @stability stable
     */
    get availabilityZoneId(): string;
    /**
     * @stability stable
     */
    set availabilityZoneId(value: string);
    /**
     * @stability stable
     */
    resetAvailabilityZoneId(): void;
    /**
     * @stability stable
     */
    get availabilityZoneIdInput(): string | undefined;
    private _cidrBlock?;
    /**
     * @stability stable
     */
    get cidrBlock(): string;
    /**
     * @stability stable
     */
    set cidrBlock(value: string);
    /**
     * @stability stable
     */
    resetCidrBlock(): void;
    /**
     * @stability stable
     */
    get cidrBlockInput(): string | undefined;
    private _customerOwnedIpv4Pool?;
    /**
     * @stability stable
     */
    get customerOwnedIpv4Pool(): string;
    /**
     * @stability stable
     */
    set customerOwnedIpv4Pool(value: string);
    /**
     * @stability stable
     */
    resetCustomerOwnedIpv4Pool(): void;
    /**
     * @stability stable
     */
    get customerOwnedIpv4PoolInput(): string | undefined;
    private _enableDns64?;
    /**
     * @stability stable
     */
    get enableDns64(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableDns64(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableDns64(): void;
    /**
     * @stability stable
     */
    get enableDns64Input(): boolean | cdktf.IResolvable | undefined;
    private _enableResourceNameDnsARecordOnLaunch?;
    /**
     * @stability stable
     */
    get enableResourceNameDnsARecordOnLaunch(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableResourceNameDnsARecordOnLaunch(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableResourceNameDnsARecordOnLaunch(): void;
    /**
     * @stability stable
     */
    get enableResourceNameDnsARecordOnLaunchInput(): boolean | cdktf.IResolvable | undefined;
    private _enableResourceNameDnsAaaaRecordOnLaunch?;
    /**
     * @stability stable
     */
    get enableResourceNameDnsAaaaRecordOnLaunch(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableResourceNameDnsAaaaRecordOnLaunch(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableResourceNameDnsAaaaRecordOnLaunch(): void;
    /**
     * @stability stable
     */
    get enableResourceNameDnsAaaaRecordOnLaunchInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _ipv6CidrBlock?;
    /**
     * @stability stable
     */
    get ipv6CidrBlock(): string;
    /**
     * @stability stable
     */
    set ipv6CidrBlock(value: string);
    /**
     * @stability stable
     */
    resetIpv6CidrBlock(): void;
    /**
     * @stability stable
     */
    get ipv6CidrBlockInput(): string | undefined;
    /**
     * @stability stable
     */
    get ipv6CidrBlockAssociationId(): string;
    private _ipv6Native?;
    /**
     * @stability stable
     */
    get ipv6Native(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set ipv6Native(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIpv6Native(): void;
    /**
     * @stability stable
     */
    get ipv6NativeInput(): boolean | cdktf.IResolvable | undefined;
    private _mapCustomerOwnedIpOnLaunch?;
    /**
     * @stability stable
     */
    get mapCustomerOwnedIpOnLaunch(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set mapCustomerOwnedIpOnLaunch(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMapCustomerOwnedIpOnLaunch(): void;
    /**
     * @stability stable
     */
    get mapCustomerOwnedIpOnLaunchInput(): boolean | cdktf.IResolvable | undefined;
    private _mapPublicIpOnLaunch?;
    /**
     * @stability stable
     */
    get mapPublicIpOnLaunch(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set mapPublicIpOnLaunch(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMapPublicIpOnLaunch(): void;
    /**
     * @stability stable
     */
    get mapPublicIpOnLaunchInput(): boolean | cdktf.IResolvable | undefined;
    private _outpostArn?;
    /**
     * @stability stable
     */
    get outpostArn(): string;
    /**
     * @stability stable
     */
    set outpostArn(value: string);
    /**
     * @stability stable
     */
    resetOutpostArn(): void;
    /**
     * @stability stable
     */
    get outpostArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get ownerId(): string;
    private _privateDnsHostnameTypeOnLaunch?;
    /**
     * @stability stable
     */
    get privateDnsHostnameTypeOnLaunch(): string;
    /**
     * @stability stable
     */
    set privateDnsHostnameTypeOnLaunch(value: string);
    /**
     * @stability stable
     */
    resetPrivateDnsHostnameTypeOnLaunch(): void;
    /**
     * @stability stable
     */
    get privateDnsHostnameTypeOnLaunchInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _vpcId?;
    /**
     * @stability stable
     */
    get vpcId(): string;
    /**
     * @stability stable
     */
    set vpcId(value: string);
    /**
     * @stability stable
     */
    get vpcIdInput(): string | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): SubnetTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: SubnetTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): SubnetTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
