import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS VPC.
 *
 * @stability stable
 */
export interface VpcPeeringConnectionOptionsConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#vpc_peering_connection_id VpcPeeringConnectionOptions#vpc_peering_connection_id}.
     *
     * @stability stable
     */
    readonly vpcPeeringConnectionId: string;
    /**
     * accepter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#accepter VpcPeeringConnectionOptions#accepter}
     *
     * @stability stable
     */
    readonly accepter?: VpcPeeringConnectionOptionsAccepter;
    /**
     * requester block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#requester VpcPeeringConnectionOptions#requester}
     *
     * @stability stable
     */
    readonly requester?: VpcPeeringConnectionOptionsRequester;
}
/**
 * @stability stable
 */
export interface VpcPeeringConnectionOptionsAccepter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#allow_classic_link_to_remote_vpc VpcPeeringConnectionOptions#allow_classic_link_to_remote_vpc}.
     *
     * @stability stable
     */
    readonly allowClassicLinkToRemoteVpc?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#allow_remote_vpc_dns_resolution VpcPeeringConnectionOptions#allow_remote_vpc_dns_resolution}.
     *
     * @stability stable
     */
    readonly allowRemoteVpcDnsResolution?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#allow_vpc_to_remote_classic_link VpcPeeringConnectionOptions#allow_vpc_to_remote_classic_link}.
     *
     * @stability stable
     */
    readonly allowVpcToRemoteClassicLink?: boolean | cdktf.IResolvable;
}
export declare function vpcPeeringConnectionOptionsAccepterToTerraform(struct?: VpcPeeringConnectionOptionsAccepterOutputReference | VpcPeeringConnectionOptionsAccepter): any;
/**
 * @stability stable
 */
export declare class VpcPeeringConnectionOptionsAccepterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): VpcPeeringConnectionOptionsAccepter | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: VpcPeeringConnectionOptionsAccepter | undefined);
    private _allowClassicLinkToRemoteVpc?;
    /**
     * @stability stable
     */
    get allowClassicLinkToRemoteVpc(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowClassicLinkToRemoteVpc(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowClassicLinkToRemoteVpc(): void;
    /**
     * @stability stable
     */
    get allowClassicLinkToRemoteVpcInput(): boolean | cdktf.IResolvable | undefined;
    private _allowRemoteVpcDnsResolution?;
    /**
     * @stability stable
     */
    get allowRemoteVpcDnsResolution(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowRemoteVpcDnsResolution(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowRemoteVpcDnsResolution(): void;
    /**
     * @stability stable
     */
    get allowRemoteVpcDnsResolutionInput(): boolean | cdktf.IResolvable | undefined;
    private _allowVpcToRemoteClassicLink?;
    /**
     * @stability stable
     */
    get allowVpcToRemoteClassicLink(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowVpcToRemoteClassicLink(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowVpcToRemoteClassicLink(): void;
    /**
     * @stability stable
     */
    get allowVpcToRemoteClassicLinkInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface VpcPeeringConnectionOptionsRequester {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#allow_classic_link_to_remote_vpc VpcPeeringConnectionOptions#allow_classic_link_to_remote_vpc}.
     *
     * @stability stable
     */
    readonly allowClassicLinkToRemoteVpc?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#allow_remote_vpc_dns_resolution VpcPeeringConnectionOptions#allow_remote_vpc_dns_resolution}.
     *
     * @stability stable
     */
    readonly allowRemoteVpcDnsResolution?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#allow_vpc_to_remote_classic_link VpcPeeringConnectionOptions#allow_vpc_to_remote_classic_link}.
     *
     * @stability stable
     */
    readonly allowVpcToRemoteClassicLink?: boolean | cdktf.IResolvable;
}
export declare function vpcPeeringConnectionOptionsRequesterToTerraform(struct?: VpcPeeringConnectionOptionsRequesterOutputReference | VpcPeeringConnectionOptionsRequester): any;
/**
 * @stability stable
 */
export declare class VpcPeeringConnectionOptionsRequesterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): VpcPeeringConnectionOptionsRequester | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: VpcPeeringConnectionOptionsRequester | undefined);
    private _allowClassicLinkToRemoteVpc?;
    /**
     * @stability stable
     */
    get allowClassicLinkToRemoteVpc(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowClassicLinkToRemoteVpc(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowClassicLinkToRemoteVpc(): void;
    /**
     * @stability stable
     */
    get allowClassicLinkToRemoteVpcInput(): boolean | cdktf.IResolvable | undefined;
    private _allowRemoteVpcDnsResolution?;
    /**
     * @stability stable
     */
    get allowRemoteVpcDnsResolution(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowRemoteVpcDnsResolution(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowRemoteVpcDnsResolution(): void;
    /**
     * @stability stable
     */
    get allowRemoteVpcDnsResolutionInput(): boolean | cdktf.IResolvable | undefined;
    private _allowVpcToRemoteClassicLink?;
    /**
     * @stability stable
     */
    get allowVpcToRemoteClassicLink(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowVpcToRemoteClassicLink(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowVpcToRemoteClassicLink(): void;
    /**
     * @stability stable
     */
    get allowVpcToRemoteClassicLinkInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options aws_vpc_peering_connection_options}.
 *
 * @stability stable
 */
export declare class VpcPeeringConnectionOptions extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options aws_vpc_peering_connection_options} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: VpcPeeringConnectionOptionsConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _vpcPeeringConnectionId?;
    /**
     * @stability stable
     */
    get vpcPeeringConnectionId(): string;
    /**
     * @stability stable
     */
    set vpcPeeringConnectionId(value: string);
    /**
     * @stability stable
     */
    get vpcPeeringConnectionIdInput(): string | undefined;
    private _accepter;
    /**
     * @stability stable
     */
    get accepter(): VpcPeeringConnectionOptionsAccepterOutputReference;
    /**
     * @stability stable
     */
    putAccepter(value: VpcPeeringConnectionOptionsAccepter): void;
    /**
     * @stability stable
     */
    resetAccepter(): void;
    /**
     * @stability stable
     */
    get accepterInput(): VpcPeeringConnectionOptionsAccepter | undefined;
    private _requester;
    /**
     * @stability stable
     */
    get requester(): VpcPeeringConnectionOptionsRequesterOutputReference;
    /**
     * @stability stable
     */
    putRequester(value: VpcPeeringConnectionOptionsRequester): void;
    /**
     * @stability stable
     */
    resetRequester(): void;
    /**
     * @stability stable
     */
    get requesterInput(): VpcPeeringConnectionOptionsRequester | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
